/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
function e(e,t,o,a){var n,r=arguments.length,i=r<3?t:null===a?a=Object.getOwnPropertyDescriptor(t,o):a;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)i=Reflect.decorate(e,t,o,a);else for(var s=e.length-1;s>=0;s--)(n=e[s])&&(i=(r<3?n(i):r>3?n(t,o,i):n(t,o))||i);return r>3&&i&&Object.defineProperty(t,o,i),i
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */}const t=new WeakMap,o=e=>"function"==typeof e&&t.has(e),a=void 0!==window.customElements&&void 0!==window.customElements.polyfillWrapFlushCallback,n=(e,t,o=null)=>{for(;t!==o;){const o=t.nextSibling;e.removeChild(t),t=o}},r={},i={},s=`{{lit-${String(Math.random()).slice(2)}}}`,l=`\x3c!--${s}--\x3e`,c=new RegExp(`${s}|${l}`),d="$lit$";class p{constructor(e,t){this.parts=[],this.element=t;const o=[],a=[],n=document.createTreeWalker(t.content,133,null,!1);let r=0,i=-1,l=0;const{strings:p,values:{length:h}}=e;for(;l<h;){const e=n.nextNode();if(null!==e){if(i++,1===e.nodeType){if(e.hasAttributes()){const t=e.attributes,{length:o}=t;let a=0;for(let e=0;e<o;e++)u(t[e].name,d)&&a++;for(;a-- >0;){const t=p[l],o=m.exec(t)[2],a=o.toLowerCase()+d,n=e.getAttribute(a);e.removeAttribute(a);const r=n.split(c);this.parts.push({type:"attribute",index:i,name:o,strings:r}),l+=r.length-1}}"TEMPLATE"===e.tagName&&(a.push(e),n.currentNode=e.content)}else if(3===e.nodeType){const t=e.data;if(t.indexOf(s)>=0){const a=e.parentNode,n=t.split(c),r=n.length-1;for(let t=0;t<r;t++){let o,r=n[t];if(""===r)o=g();else{const e=m.exec(r);null!==e&&u(e[2],d)&&(r=r.slice(0,e.index)+e[1]+e[2].slice(0,-d.length)+e[3]),o=document.createTextNode(r)}a.insertBefore(o,e),this.parts.push({type:"node",index:++i})}""===n[r]?(a.insertBefore(g(),e),o.push(e)):e.data=n[r],l+=r}}else if(8===e.nodeType)if(e.data===s){const t=e.parentNode;null!==e.previousSibling&&i!==r||(i++,t.insertBefore(g(),e)),r=i,this.parts.push({type:"node",index:i}),null===e.nextSibling?e.data="":(o.push(e),i--),l++}else{let t=-1;for(;-1!==(t=e.data.indexOf(s,t+1));)this.parts.push({type:"node",index:-1}),l++}}else n.currentNode=a.pop()}for(const e of o)e.parentNode.removeChild(e)}}const u=(e,t)=>{const o=e.length-t.length;return o>=0&&e.slice(o)===t},h=e=>-1!==e.index,g=()=>document.createComment(""),m=/([ \x09\x0a\x0c\x0d])([^\0-\x1F\x7F-\x9F "'>=/]+)([ \x09\x0a\x0c\x0d]*=[ \x09\x0a\x0c\x0d]*(?:[^ \x09\x0a\x0c\x0d"'`<>=]*|"[^"]*|'[^']*))$/;
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
class f{constructor(e,t,o){this.__parts=[],this.template=e,this.processor=t,this.options=o}update(e){let t=0;for(const o of this.__parts)void 0!==o&&o.setValue(e[t]),t++;for(const e of this.__parts)void 0!==e&&e.commit()}_clone(){const e=a?this.template.element.content.cloneNode(!0):document.importNode(this.template.element.content,!0),t=[],o=this.template.parts,n=document.createTreeWalker(e,133,null,!1);let r,i=0,s=0,l=n.nextNode();for(;i<o.length;)if(r=o[i],h(r)){for(;s<r.index;)s++,"TEMPLATE"===l.nodeName&&(t.push(l),n.currentNode=l.content),null===(l=n.nextNode())&&(n.currentNode=t.pop(),l=n.nextNode());if("node"===r.type){const e=this.processor.handleTextExpression(this.options);e.insertAfterNode(l.previousSibling),this.__parts.push(e)}else this.__parts.push(...this.processor.handleAttributeExpressions(l,r.name,r.strings,this.options));i++}else this.__parts.push(void 0),i++;return a&&(document.adoptNode(e),customElements.upgrade(e)),e}}
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */const _=` ${s} `;class b{constructor(e,t,o,a){this.strings=e,this.values=t,this.type=o,this.processor=a}getHTML(){const e=this.strings.length-1;let t="",o=!1;for(let a=0;a<e;a++){const e=this.strings[a],n=e.lastIndexOf("\x3c!--");o=(n>-1||o)&&-1===e.indexOf("--\x3e",n+1);const r=m.exec(e);t+=null===r?e+(o?_:l):e.substr(0,r.index)+r[1]+r[2]+d+r[3]+s}return t+=this.strings[e],t}getTemplateElement(){const e=document.createElement("template");return e.innerHTML=this.getHTML(),e}}
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */const y=e=>null===e||!("object"==typeof e||"function"==typeof e),w=e=>Array.isArray(e)||!(!e||!e[Symbol.iterator]);class v{constructor(e,t,o){this.dirty=!0,this.element=e,this.name=t,this.strings=o,this.parts=[];for(let e=0;e<o.length-1;e++)this.parts[e]=this._createPart()}_createPart(){return new k(this)}_getValue(){const e=this.strings,t=e.length-1;let o="";for(let a=0;a<t;a++){o+=e[a];const t=this.parts[a];if(void 0!==t){const e=t.value;if(y(e)||!w(e))o+="string"==typeof e?e:String(e);else for(const t of e)o+="string"==typeof t?t:String(t)}}return o+=e[t],o}commit(){this.dirty&&(this.dirty=!1,this.element.setAttribute(this.name,this._getValue()))}}class k{constructor(e){this.value=void 0,this.committer=e}setValue(e){e===r||y(e)&&e===this.value||(this.value=e,o(e)||(this.committer.dirty=!0))}commit(){for(;o(this.value);){const e=this.value;this.value=r,e(this)}this.value!==r&&this.committer.commit()}}class x{constructor(e){this.value=void 0,this.__pendingValue=void 0,this.options=e}appendInto(e){this.startNode=e.appendChild(g()),this.endNode=e.appendChild(g())}insertAfterNode(e){this.startNode=e,this.endNode=e.nextSibling}appendIntoPart(e){e.__insert(this.startNode=g()),e.__insert(this.endNode=g())}insertAfterPart(e){e.__insert(this.startNode=g()),this.endNode=e.endNode,e.endNode=this.startNode}setValue(e){this.__pendingValue=e}commit(){for(;o(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=r,e(this)}const e=this.__pendingValue;e!==r&&(y(e)?e!==this.value&&this.__commitText(e):e instanceof b?this.__commitTemplateResult(e):e instanceof Node?this.__commitNode(e):w(e)?this.__commitIterable(e):e===i?(this.value=i,this.clear()):this.__commitText(e))}__insert(e){this.endNode.parentNode.insertBefore(e,this.endNode)}__commitNode(e){this.value!==e&&(this.clear(),this.__insert(e),this.value=e)}__commitText(e){const t=this.startNode.nextSibling,o="string"==typeof(e=null==e?"":e)?e:String(e);t===this.endNode.previousSibling&&3===t.nodeType?t.data=o:this.__commitNode(document.createTextNode(o)),this.value=e}__commitTemplateResult(e){const t=this.options.templateFactory(e);if(this.value instanceof f&&this.value.template===t)this.value.update(e.values);else{const o=new f(t,e.processor,this.options),a=o._clone();o.update(e.values),this.__commitNode(a),this.value=o}}__commitIterable(e){Array.isArray(this.value)||(this.value=[],this.clear());const t=this.value;let o,a=0;for(const n of e)o=t[a],void 0===o&&(o=new x(this.options),t.push(o),0===a?o.appendIntoPart(this):o.insertAfterPart(t[a-1])),o.setValue(n),o.commit(),a++;a<t.length&&(t.length=a,this.clear(o&&o.endNode))}clear(e=this.startNode){n(this.startNode.parentNode,e.nextSibling,this.endNode)}}class A{constructor(e,t,o){if(this.value=void 0,this.__pendingValue=void 0,2!==o.length||""!==o[0]||""!==o[1])throw new Error("Boolean attributes can only contain a single expression");this.element=e,this.name=t,this.strings=o}setValue(e){this.__pendingValue=e}commit(){for(;o(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=r,e(this)}if(this.__pendingValue===r)return;const e=!!this.__pendingValue;this.value!==e&&(e?this.element.setAttribute(this.name,""):this.element.removeAttribute(this.name),this.value=e),this.__pendingValue=r}}class S extends v{constructor(e,t,o){super(e,t,o),this.single=2===o.length&&""===o[0]&&""===o[1]}_createPart(){return new j(this)}_getValue(){return this.single?this.parts[0].value:super._getValue()}commit(){this.dirty&&(this.dirty=!1,this.element[this.name]=this._getValue())}}class j extends k{}let E=!1;try{const e={get capture(){return E=!0,!1}};window.addEventListener("test",e,e),window.removeEventListener("test",e,e)}catch(e){}class O{constructor(e,t,o){this.value=void 0,this.__pendingValue=void 0,this.element=e,this.eventName=t,this.eventContext=o,this.__boundHandleEvent=e=>this.handleEvent(e)}setValue(e){this.__pendingValue=e}commit(){for(;o(this.__pendingValue);){const e=this.__pendingValue;this.__pendingValue=r,e(this)}if(this.__pendingValue===r)return;const e=this.__pendingValue,t=this.value,a=null==e||null!=t&&(e.capture!==t.capture||e.once!==t.once||e.passive!==t.passive),n=null!=e&&(null==t||a);a&&this.element.removeEventListener(this.eventName,this.__boundHandleEvent,this.__options),n&&(this.__options=C(e),this.element.addEventListener(this.eventName,this.__boundHandleEvent,this.__options)),this.value=e,this.__pendingValue=r}handleEvent(e){"function"==typeof this.value?this.value.call(this.eventContext||this.element,e):this.value.handleEvent(e)}}const C=e=>e&&(E?{capture:e.capture,passive:e.passive,once:e.once}:e.capture);
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */const z=new class{handleAttributeExpressions(e,t,o,a){const n=t[0];if("."===n){return new S(e,t.slice(1),o).parts}return"@"===n?[new O(e,t.slice(1),a.eventContext)]:"?"===n?[new A(e,t.slice(1),o)]:new v(e,t,o).parts}handleTextExpression(e){return new x(e)}};
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */function T(e){let t=$.get(e.type);void 0===t&&(t={stringsArray:new WeakMap,keyString:new Map},$.set(e.type,t));let o=t.stringsArray.get(e.strings);if(void 0!==o)return o;const a=e.strings.join(s);return o=t.keyString.get(a),void 0===o&&(o=new p(e,e.getTemplateElement()),t.keyString.set(a,o)),t.stringsArray.set(e.strings,o),o}const $=new Map,R=new WeakMap;
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
(window.litHtmlVersions||(window.litHtmlVersions=[])).push("1.1.2");const N=(e,...t)=>new b(e,t,"html",z),I=133;
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */function P(e,t){const{element:{content:o},parts:a}=e,n=document.createTreeWalker(o,I,null,!1);let r=L(a),i=a[r],s=-1,l=0;const c=[];let d=null;for(;n.nextNode();){s++;const e=n.currentNode;for(e.previousSibling===d&&(d=null),t.has(e)&&(c.push(e),null===d&&(d=e)),null!==d&&l++;void 0!==i&&i.index===s;)i.index=null!==d?-1:i.index-l,r=L(a,r),i=a[r]}c.forEach(e=>e.parentNode.removeChild(e))}const M=e=>{let t=11===e.nodeType?0:1;const o=document.createTreeWalker(e,I,null,!1);for(;o.nextNode();)t++;return t},L=(e,t=-1)=>{for(let o=t+1;o<e.length;o++){const t=e[o];if(h(t))return o}return-1};
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
const D=(e,t)=>`${e}--${t}`;let H=!0;void 0===window.ShadyCSS?H=!1:void 0===window.ShadyCSS.prepareTemplateDom&&(console.warn("Incompatible ShadyCSS version detected. Please update to at least @webcomponents/webcomponentsjs@2.0.2 and @webcomponents/shadycss@1.3.1."),H=!1);const B=e=>t=>{const o=D(t.type,e);let a=$.get(o);void 0===a&&(a={stringsArray:new WeakMap,keyString:new Map},$.set(o,a));let n=a.stringsArray.get(t.strings);if(void 0!==n)return n;const r=t.strings.join(s);if(n=a.keyString.get(r),void 0===n){const o=t.getTemplateElement();H&&window.ShadyCSS.prepareTemplateDom(o,e),n=new p(t,o),a.keyString.set(r,n)}return a.stringsArray.set(t.strings,n),n},U=["html","svg"],q=new Set,V=(e,t,o)=>{q.add(e);const a=o?o.element:document.createElement("template"),n=t.querySelectorAll("style"),{length:r}=n;if(0===r)return void window.ShadyCSS.prepareTemplateStyles(a,e);const i=document.createElement("style");for(let e=0;e<r;e++){const t=n[e];t.parentNode.removeChild(t),i.textContent+=t.textContent}(e=>{U.forEach(t=>{const o=$.get(D(t,e));void 0!==o&&o.keyString.forEach(e=>{const{element:{content:t}}=e,o=new Set;Array.from(t.querySelectorAll("style")).forEach(e=>{o.add(e)}),P(e,o)})})})(e);const s=a.content;o?function(e,t,o=null){const{element:{content:a},parts:n}=e;if(null==o)return void a.appendChild(t);const r=document.createTreeWalker(a,I,null,!1);let i=L(n),s=0,l=-1;for(;r.nextNode();){for(l++,r.currentNode===o&&(s=M(t),o.parentNode.insertBefore(t,o));-1!==i&&n[i].index===l;){if(s>0){for(;-1!==i;)n[i].index+=s,i=L(n,i);return}i=L(n,i)}}}(o,i,s.firstChild):s.insertBefore(i,s.firstChild),window.ShadyCSS.prepareTemplateStyles(a,e);const l=s.querySelector("style");if(window.ShadyCSS.nativeShadow&&null!==l)t.insertBefore(l.cloneNode(!0),t.firstChild);else if(o){s.insertBefore(i,s.firstChild);const e=new Set;e.add(i),P(o,e)}};window.JSCompiler_renameProperty=(e,t)=>e;const F={toAttribute(e,t){switch(t){case Boolean:return e?"":null;case Object:case Array:return null==e?e:JSON.stringify(e)}return e},fromAttribute(e,t){switch(t){case Boolean:return null!==e;case Number:return null===e?null:Number(e);case Object:case Array:return JSON.parse(e)}return e}},G=(e,t)=>t!==e&&(t==t||e==e),W={attribute:!0,type:String,converter:F,reflect:!1,hasChanged:G},Y=Promise.resolve(!0),Z=1,K=4,X=8,J=16,Q=32,ee="finalized";class te extends HTMLElement{constructor(){super(),this._updateState=0,this._instanceProperties=void 0,this._updatePromise=Y,this._hasConnectedResolver=void 0,this._changedProperties=new Map,this._reflectingProperties=void 0,this.initialize()}static get observedAttributes(){this.finalize();const e=[];return this._classProperties.forEach((t,o)=>{const a=this._attributeNameForProperty(o,t);void 0!==a&&(this._attributeToPropertyMap.set(a,o),e.push(a))}),e}static _ensureClassProperties(){if(!this.hasOwnProperty(JSCompiler_renameProperty("_classProperties",this))){this._classProperties=new Map;const e=Object.getPrototypeOf(this)._classProperties;void 0!==e&&e.forEach((e,t)=>this._classProperties.set(t,e))}}static createProperty(e,t=W){if(this._ensureClassProperties(),this._classProperties.set(e,t),t.noAccessor||this.prototype.hasOwnProperty(e))return;const o="symbol"==typeof e?Symbol():`__${e}`;Object.defineProperty(this.prototype,e,{get(){return this[o]},set(t){const a=this[e];this[o]=t,this._requestUpdate(e,a)},configurable:!0,enumerable:!0})}static finalize(){const e=Object.getPrototypeOf(this);if(e.hasOwnProperty(ee)||e.finalize(),this[ee]=!0,this._ensureClassProperties(),this._attributeToPropertyMap=new Map,this.hasOwnProperty(JSCompiler_renameProperty("properties",this))){const e=this.properties,t=[...Object.getOwnPropertyNames(e),..."function"==typeof Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(e):[]];for(const o of t)this.createProperty(o,e[o])}}static _attributeNameForProperty(e,t){const o=t.attribute;return!1===o?void 0:"string"==typeof o?o:"string"==typeof e?e.toLowerCase():void 0}static _valueHasChanged(e,t,o=G){return o(e,t)}static _propertyValueFromAttribute(e,t){const o=t.type,a=t.converter||F,n="function"==typeof a?a:a.fromAttribute;return n?n(e,o):e}static _propertyValueToAttribute(e,t){if(void 0===t.reflect)return;const o=t.type,a=t.converter;return(a&&a.toAttribute||F.toAttribute)(e,o)}initialize(){this._saveInstanceProperties(),this._requestUpdate()}_saveInstanceProperties(){this.constructor._classProperties.forEach((e,t)=>{if(this.hasOwnProperty(t)){const e=this[t];delete this[t],this._instanceProperties||(this._instanceProperties=new Map),this._instanceProperties.set(t,e)}})}_applyInstanceProperties(){this._instanceProperties.forEach((e,t)=>this[t]=e),this._instanceProperties=void 0}connectedCallback(){this._updateState=this._updateState|Q,this._hasConnectedResolver&&(this._hasConnectedResolver(),this._hasConnectedResolver=void 0)}disconnectedCallback(){}attributeChangedCallback(e,t,o){t!==o&&this._attributeToProperty(e,o)}_propertyToAttribute(e,t,o=W){const a=this.constructor,n=a._attributeNameForProperty(e,o);if(void 0!==n){const e=a._propertyValueToAttribute(t,o);if(void 0===e)return;this._updateState=this._updateState|X,null==e?this.removeAttribute(n):this.setAttribute(n,e),this._updateState=this._updateState&~X}}_attributeToProperty(e,t){if(this._updateState&X)return;const o=this.constructor,a=o._attributeToPropertyMap.get(e);if(void 0!==a){const e=o._classProperties.get(a)||W;this._updateState=this._updateState|J,this[a]=o._propertyValueFromAttribute(t,e),this._updateState=this._updateState&~J}}_requestUpdate(e,t){let o=!0;if(void 0!==e){const a=this.constructor,n=a._classProperties.get(e)||W;a._valueHasChanged(this[e],t,n.hasChanged)?(this._changedProperties.has(e)||this._changedProperties.set(e,t),!0!==n.reflect||this._updateState&J||(void 0===this._reflectingProperties&&(this._reflectingProperties=new Map),this._reflectingProperties.set(e,n))):o=!1}!this._hasRequestedUpdate&&o&&this._enqueueUpdate()}requestUpdate(e,t){return this._requestUpdate(e,t),this.updateComplete}async _enqueueUpdate(){let e,t;this._updateState=this._updateState|K;const o=this._updatePromise;this._updatePromise=new Promise((o,a)=>{e=o,t=a});try{await o}catch(e){}this._hasConnected||await new Promise(e=>this._hasConnectedResolver=e);try{const e=this.performUpdate();null!=e&&await e}catch(e){t(e)}e(!this._hasRequestedUpdate)}get _hasConnected(){return this._updateState&Q}get _hasRequestedUpdate(){return this._updateState&K}get hasUpdated(){return this._updateState&Z}performUpdate(){this._instanceProperties&&this._applyInstanceProperties();let e=!1;const t=this._changedProperties;try{e=this.shouldUpdate(t),e&&this.update(t)}catch(t){throw e=!1,t}finally{this._markUpdated()}e&&(this._updateState&Z||(this._updateState=this._updateState|Z,this.firstUpdated(t)),this.updated(t))}_markUpdated(){this._changedProperties=new Map,this._updateState=this._updateState&~K}get updateComplete(){return this._getUpdateComplete()}_getUpdateComplete(){return this._updatePromise}shouldUpdate(e){return!0}update(e){void 0!==this._reflectingProperties&&this._reflectingProperties.size>0&&(this._reflectingProperties.forEach((e,t)=>this._propertyToAttribute(t,this[t],e)),this._reflectingProperties=void 0)}updated(e){}firstUpdated(e){}}te[ee]=!0;
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
const oe=e=>t=>"function"==typeof t?((e,t)=>(window.customElements.define(e,t),t))(e,t):((e,t)=>{const{kind:o,elements:a}=t;return{kind:o,elements:a,finisher(t){window.customElements.define(e,t)}}})(e,t),ae=(e,t)=>"method"!==t.kind||!t.descriptor||"value"in t.descriptor?{kind:"field",key:Symbol(),placement:"own",descriptor:{},initializer(){"function"==typeof t.initializer&&(this[t.key]=t.initializer.call(this))},finisher(o){o.createProperty(t.key,e)}}:Object.assign({},t,{finisher(o){o.createProperty(t.key,e)}}),ne=(e,t,o)=>{t.constructor.createProperty(o,e)};function re(e){return(t,o)=>void 0!==o?ne(e,t,o):ae(e,t)}
/**
@license
Copyright (c) 2019 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at
http://polymer.github.io/LICENSE.txt The complete set of authors may be found at
http://polymer.github.io/AUTHORS.txt The complete set of contributors may be
found at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as
part of the polymer project is also subject to an additional IP rights grant
found at http://polymer.github.io/PATENTS.txt
*/const ie="adoptedStyleSheets"in Document.prototype&&"replace"in CSSStyleSheet.prototype,se=Symbol();class le{constructor(e,t){if(t!==se)throw new Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");this.cssText=e}get styleSheet(){return void 0===this._styleSheet&&(ie?(this._styleSheet=new CSSStyleSheet,this._styleSheet.replaceSync(this.cssText)):this._styleSheet=null),this._styleSheet}toString(){return this.cssText}}const ce=(e,...t)=>{const o=t.reduce((t,o,a)=>t+(e=>{if(e instanceof le)return e.cssText;if("number"==typeof e)return e;throw new Error(`Value passed to 'css' function must be a 'css' function result: ${e}. Use 'unsafeCSS' to pass non-literal values, but\n            take care to ensure page security.`)})(o)+e[a+1],e[0]);return new le(o,se)};
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
(window.litElementVersions||(window.litElementVersions=[])).push("2.2.1");const de=e=>e.flat?e.flat(1/0):function e(t,o=[]){for(let a=0,n=t.length;a<n;a++){const n=t[a];Array.isArray(n)?e(n,o):o.push(n)}return o}(e);class pe extends te{static finalize(){super.finalize.call(this),this._styles=this.hasOwnProperty(JSCompiler_renameProperty("styles",this))?this._getUniqueStyles():this._styles||[]}static _getUniqueStyles(){const e=this.styles,t=[];if(Array.isArray(e)){de(e).reduceRight((e,t)=>(e.add(t),e),new Set).forEach(e=>t.unshift(e))}else e&&t.push(e);return t}initialize(){super.initialize(),this.renderRoot=this.createRenderRoot(),window.ShadowRoot&&this.renderRoot instanceof window.ShadowRoot&&this.adoptStyles()}createRenderRoot(){return this.attachShadow({mode:"open"})}adoptStyles(){const e=this.constructor._styles;0!==e.length&&(void 0===window.ShadyCSS||window.ShadyCSS.nativeShadow?ie?this.renderRoot.adoptedStyleSheets=e.map(e=>e.styleSheet):this._needsShimAdoptedStyleSheets=!0:window.ShadyCSS.ScopingShim.prepareAdoptedCssText(e.map(e=>e.cssText),this.localName))}connectedCallback(){super.connectedCallback(),this.hasUpdated&&void 0!==window.ShadyCSS&&window.ShadyCSS.styleElement(this)}update(e){super.update(e);const t=this.render();t instanceof b&&this.constructor.render(t,this.renderRoot,{scopeName:this.localName,eventContext:this}),this._needsShimAdoptedStyleSheets&&(this._needsShimAdoptedStyleSheets=!1,this.constructor._styles.forEach(e=>{const t=document.createElement("style");t.textContent=e.cssText,this.renderRoot.appendChild(t)}))}render(){}}function ue(){if(customElements.get("hui-view"))return!0;const e=document.createElement("partial-panel-resolver");e.hass=document.querySelector("home-assistant").hass,e.route={path:"/lovelace/"};try{document.querySelector("home-assistant").appendChild(e).catch(e=>{})}catch(t){document.querySelector("home-assistant").removeChild(e)}return!!customElements.get("hui-view")}pe.finalized=!0,pe.render=(e,t,o)=>{if(!o||"object"!=typeof o||!o.scopeName)throw new Error("The `scopeName` option is required.");const a=o.scopeName,r=R.has(t),i=H&&11===t.nodeType&&!!t.host,s=i&&!q.has(a),l=s?document.createDocumentFragment():t;if(((e,t,o)=>{let a=R.get(t);void 0===a&&(n(t,t.firstChild),R.set(t,a=new x(Object.assign({templateFactory:T},o))),a.appendInto(t)),a.setValue(e),a.commit()})(e,l,Object.assign({templateFactory:B(a)},o)),s){const e=R.get(l);R.delete(l);const o=e.value instanceof f?e.value.template:void 0;V(a,l,o),n(t,t.firstChild),t.appendChild(l),R.set(t,e)}!r&&i&&window.ShadyCSS.styleElement(t.host)};const he=(e,t)=>{history.pushState(null,"",t)},ge=[ce`
  :host {
    @apply --paper-font-body1;
  }

  app-header-layout,
  ha-app-layout {
    background-color: var(--primary-background-color);
  }

  app-header,
  app-toolbar {
    background-color: var(--primary-color);
    font-weight: 400;
    color: var(--text-primary-color, white);
  }

  app-toolbar ha-menu-button + [main-title],
  app-toolbar ha-paper-icon-button-arrow-prev + [main-title],
  app-toolbar paper-icon-button + [main-title] {
    margin-left: 24px;
  }

  button.link {
    background: none;
    color: inherit;
    border: none;
    padding: 0;
    font: inherit;
    text-align: left;
    text-decoration: underline;
    cursor: pointer;
  }

  .card-actions a {
    text-decoration: none;
  }

  .card-actions .warning {
    --mdc-theme-primary: var(--google-red-500);
  }
`,ce`
  :host {
    font-family: var(--paper-font-body1_-_font-family);
    -webkit-font-smoothing: var(--paper-font-body1_-_-webkit-font-smoothing);
    font-size: var(--paper-font-body1_-_font-size);
    font-weight: var(--paper-font-body1_-_font-weight);
    line-height: var(--paper-font-body1_-_line-height);
  }

  app-header-layout,
  ha-app-layout {
    background-color: var(--primary-background-color);
  }

  app-header,
  app-toolbar,
  paper-tabs {
    background-color: var(--primary-color);
    font-weight: 400;
    text-transform: uppercase;
    color: var(--text-primary-color, white);
  }

  paper-tabs {
    --paper-tabs-selection-bar-color: #fff;
    margin-left: 12px;
  }

  app-toolbar ha-menu-button + [main-title],
  app-toolbar ha-paper-icon-button-arrow-prev + [main-title],
  app-toolbar paper-icon-button + [main-title] {
    margin-left: 24px;
  }
`,ce`
  :root {
    font-family: var(--paper-font-body1_-_font-family);
    -webkit-font-smoothing: var(--paper-font-body1_-_-webkit-font-smoothing);
    font-size: var(--paper-font-body1_-_font-size);
    font-weight: var(--paper-font-body1_-_font-weight);
    line-height: var(--paper-font-body1_-_line-height);
  }
  a {
    text-decoration: none;
    color: var(--link-text-color, var(--accent-color));
  }
  h1 {
    font-family: var(--paper-font-title_-_font-family);
    -webkit-font-smoothing: var(--paper-font-title_-_-webkit-font-smoothing);
    white-space: var(--paper-font-title_-_white-space);
    overflow: var(--paper-font-title_-_overflow);
    text-overflow: var(--paper-font-title_-_text-overflow);
    font-size: var(--paper-font-title_-_font-size);
    font-weight: var(--paper-font-title_-_font-weight);
    line-height: var(--paper-font-title_-_line-height);
    @apply --paper-font-title;
  }
  .title {
    margin-bottom: 8px;
    padding-top: 4px;
    color: var(--primary-text-color);
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden;
    width: calc(100% - 48px) !important;
  }
  .addition {
    color: var(--secondary-text-color);
    position: relative;
    width: 100% !important;
    height: auto;
    line-height: 1.2em;
    text-overflow: ellipsis;
    overflow: hidden;
  }
  ha-card {
    margin: 8px;
  }
  ha-icon {
    height: 24px;
    width: 24px;
    margin-right: 16px;
    float: left;
    color: var(--primary-text-color);
  }
  .installed {
    color: var(--hacs-status-installed, #126e15);
  }
  .pending-upgrade {
    color: var(--hacs-status-pending-update, #ffab40);
  }
  .pending-restart {
    color: var(--hacs-status-pending-restart, var(--google-red-500));
  }
  .not-loaded {
    color: var(--hacs-status-not-loaded, var(--google-red-500));
  }
  .new {
    color: var(--hacs-badge-color, var(--primary-color));
  }
  .card-group {
    margin-top: 24px;
  }

  .card-group {
    color: var(--primary-text-color);
    margin-bottom: 12px;
  }

  ha-card.compact {
    height: 80px !important;
  }

  ha-card.compact .addition {
    height: 1.2em;
    white-space: preliine !important;
  }

  ha-card.compact .title {
    height: 1.2em;
    white-space: preliine !important;
  }

  paper-item.compact {
    margin-bottom: 2px !important;
    white-space: nowrap !important;
  }

  .card-group ha-card {
    --card-group-columns: 5;
    width: calc(
      (100% - 12px * var(--card-group-columns)) / var(--card-group-columns)
    );
    margin: 4px;
    vertical-align: top;
    height: 136px;
  }

  @media screen and (max-width: 2400px) and (min-width: 1801px) {
    .card-group ha-card {
      --card-group-columns: 4;
    }
  }

  @media screen and (max-width: 1800px) and (min-width: 1201px) {
    .card-group ha-card {
      --card-group-columns: 3;
    }
  }

  @media screen and (max-width: 1200px) and (min-width: 601px) {
    .card-group ha-card {
      --card-group-columns: 2;
    }
  }

  @media screen and (max-width: 600px) and (min-width: 0) {
    .card-group ha-card {
      width: 100%;
      margin: 4px 0;
    }
    .content {
      padding: 0;
    }
  }
  hr {
    border-color: var(--accent-color);
  }
  .leftspace {
    margin-left: 8px !important;
  }
  .disabled-button {
    --mdc-theme-primary: var(--disabled-text-color);
  }
  .uninstall-button {
    --mdc-theme-primary: var(--google-red-500);
  }
  .red-button {
    --mdc-theme-primary: var(--google-red-500);
  }
  .link {
    color: var(--link-text-color, var(--accent-color));
    font-weight: 600;
    text-decoration: none;
  }
  paper-item {
    border-radius: var(--ha-card-border-radius);
    background: var(--primary-background-color);
    display: block;
    cursor: pointer;
    margin-bottom: 12px;
  }
  paper-item.list {
    margin-bottom: 24px;
  }
  paper-item:hover {
    outline: 0;
    background: var(--table-row-alternative-background-color);
  }
  .right {
    float: right;
  }
  .griddy {
    display: grid;
  }
  .flexy {
    display: flex;
  }
  .flowroot {
    display: flow-root;
  }
`,ce`
  @media screen and (max-width: 600px) and (min-width: 0) {
    .MobileHide {
      display: none !important;
    }
    .MobileGrid {
      display: grid !important;
      text-align: center;
      position: initial !important;
      width: 100% !important;
      padding-left: 0px !important;
      padding-right: 0px !important;
    }
    hacs-help-button {
      display: none;
    }
  }
`];function me(e,t,o,a){let n;n=void 0!==a?{type:"hacs/repository/data",action:o,repository:t,data:a}:{type:"hacs/repository",action:o,repository:t},e.connection.sendMessage(n)}var fe={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apps",background_task:"Hintergrundprozess läuft. Diese Seite lädt neu, sobald dieser fertig ist.",installed:"Installiert",integration:"Integration",integrations:"Integrationen",plugin:"Plugin",plugins:"Plugins",python_script:"Python Skript",python_scripts:"Python Skripte",repositories:"Repositories",settings:"Einstellungen",theme:"Theme",themes:"Themes",version:"Version"},_e={abort:{single_instance_allowed:"Es ist nur eine einzelne HACS-Instanz erlaubt."},error:{auth:"Persönliches Zugriffstoken ist falsch."},step:{user:{data:{appdaemon:"AppDaemon App-Discovery & Tracking aktivieren",python_script:"Python Script-Discovery & Tracking aktivieren",sidepanel_icon:"Sidepanel Symbol",sidepanel_title:"Sidepanel Titel",theme:"Theme-Discovery & Tracking aktivieren",token:"Persönliches GitHub Zugriffstoken"},description:"Wenn du Hilfe mit den Einstellungen brauchst, kannst du hier nachsehen: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},be={add_to_lovelace:"Möchtest du dies wirklich zu deinen Lovelace-Ressourcen hinzufügen?",bg_task:"Die Aktion ist deaktiviert, während Hintergrundprozesse ausgeführt werden.",cancel:"Abbrechen",continue:"Bist du dir sicher, dass du fortfahren möchtest?",delete:'Möchtest du "{item}" wirklich löschen?',generic:"Bist du dir sicher?",no:"Nein",no_upgrades:"Keine Upgrades ausstehend",ok:"OK",overwrite:"Dadurch wird die Datei überschrieben.",uninstall:'Möchtest du "{item}" wirklich löschen?',upgrade_all:"Hier durch werden all diese Repositorys aktualisiert. Stelle sicher, dass du die Versionshinweise vorher gelesen hast.",yes:"Ja"},ye={step:{user:{data:{country:"Nach Ländercode filtern.",debug:"Debug aktivieren.",experimental:"Experimentelle Funktionen aktivieren",release_limit:"Anzahl anzuzeigender Releases."}}}},we={integration_not_loaded:"Diese Integration ist in Home Assistant nicht geladen.",not_loaded:"Nicht geladen",plugin_not_loaded:"Dieses Plugin wurde deinen Lovelace-Ressourcen nicht hinzugefügt.",restart:"Du musst Home Assistant neu starten.",restart_pending:"Neustart ausstehend"},ve={add_to_lovelace:"Zu Lovelace hinzufügen",authors:"Autoren",available:"Verfügbar",back_to:"Zurück zu",changelog:"Änderungsprotokoll",flag_this:"Melden",hide:"Verstecken",hide_beta:"Beta verstecken",install:"Installieren",installed:"Installiert",lovelace_copy_example:"Beispiel in die Zwischenablage kopieren",lovelace_instruction:"Zum Hinzufügen zu deinen Lovelace-Einstellungen, benutze Folgendes",lovelace_no_js_type:"Konnte die Art dieses Plugins nicht erkennen. Prüfe das Repository.",newest:"neueste",note_appdaemon:"du musst es dann noch in die Datei 'apps.yaml' hinzufügen",note_installed:"Wird installiert nach",note_integration:"du musst es dann noch in die Datei 'configuration.yaml' hinzufügen",note_plugin:"du musst es dann noch in deine Lovelace-Einstellungen ('ui-lovelace.yaml' oder im Raw-Konfigurationseditor) hinzufügen",open_issue:"Problem melden",open_plugin:"Plugin öffnen",reinstall:"Neu installieren",repository:"Repository",show_beta:"Beta anzeigen",uninstall:"Deinstallieren",update_information:"Aktualisierungsinformationen",upgrade:"Aktualisieren"},ke={add_custom_repository:"CUSTOM REPOSITORY HINZUFÜGEN",category:"Kategorie",compact_mode:"Kompakter Modus",custom_repositories:"CUSTOM REPOSITORIES",delete:"Löschen",display:"Anzeige",grid:"Gitter",hacs_repo:"HACS repo",hidden_repositories:"versteckte Repositories",reload_data:"Daten neu laden",save:"Speichern",table:"Tabelle",table_view:"Tabellenansicht",unhide:"einblenden",upgrade_all:"Alles aktualisieren"},xe={clear_new:"Alle neuen Repositories als gesehen markieren",name:"Name",new_repositories:"Neue Repositories",pending_upgrades:"Ausstehende Upgrades",placeholder_search:"Suchbegriff eingeben…",sort:"Sortieren",stars:"Sterne",status:"Status"},Ae={common:fe,config:_e,confirm:be,options:ye,repository_banner:we,repository:ve,settings:ke,store:xe},Se={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apps",background_task:"Τρέχει μια διεργασία στο παρασκήνιο, η σελίδα θα ανανεωθεί μόλις αυτό ολοκληρωθεί.",installed:"εγκατεστημένο",integration:"Ενσωμάτωση",integrations:"Ενσωματωμένα",plugin:"Πρόσθετο",plugins:"Πρόσθετα",python_script:"Πρόγραμμα Python",python_scripts:"Προγράμματα Python",repositories:"Αποθετήρια",settings:"ρυθμίσεις",theme:"Θέμα",themes:"Θέματα",version:"Έκδοση"},je={abort:{single_instance_allowed:"Μονάχα μία ρύθμιση των παραμέτρων του HACS επιτρέπεται."},error:{auth:"Το διακριτικό πρόσβασης δεν είναι σωστό."},step:{user:{data:{appdaemon:"Ενεργοποίηση εύρεσης & παρακολούθησης για το AppDaemon",python_script:"Ενεργοποίηση εύρεσης & παρακολούθησης για τα python_scripts",sidepanel_icon:"Εικονίδιο πλαϊνού πάνελ",sidepanel_title:"Τίτλος πλαϊνού πάνελ",theme:"Ενεργοποίηση εύρεσης & παρακολούθησης για τα θεμάτων",token:"Διακριτικό πρόσβασης του GitHub"},description:"Εάν χρειαστείτε βοήθεια με τις ρυθμίσεις ανατρέξτε εδώ: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Ee={delete:'Είστε σίγουροι ότι θέλετε να διαγράψετε το "{item}";'},Oe={step:{user:{data:{country:"Κριτήριο με βάση τον κωδικό χώρας.",experimental:"Ενεργοποίση πειραματικών λειτουργιών",release_limit:"Αριθμός εκδόσεων που να παραθέτονται."}}}},Ce={authors:"Συγγραφείς",available:"Διαθέσιμο",back_to:"Πίσω στο",changelog:"Σημειώσεις των αλλαγών",flag_this:"Σημείωσε αυτό",hide:"Απόκρυψη",hide_beta:"Απόκριση του beta",install:"Εγκατάσταση",installed:"Εγκατεστημένο",lovelace_copy_example:"Αντίγραψε το παράδειγμα στο πρόχειρο",lovelace_instruction:"Όταν το προσθέσετε στις ρυθμίσεις του lovelace χρησιμοποιήστε τούτο",lovelace_no_js_type:"Δεν καταφέραμε να προσδιορίσουμε τον τύπο αυτού του προσθέτου, ελέξτε το αποθετήριο.",newest:"νεότερο",note_appdaemon:"εξακολουθεί να χρειάζεται να το προσθέσετε στο αρχείο 'apps.yaml'",note_installed:"Όταν εγκατασταθεί, θα προστεθεί στο",note_integration:"εξακολουθεί να χρειάζεται να το προσθέσετε στο αρχείο 'configuration.yaml'",note_plugin:"εξακολουθεί να χρειάζετε να το προσθέσετε στις ρυθμίσεις του lovelace ('ui-lovelace.yaml' ή μέσω του γραφικού επεξεργαστή των ρυθμίσεων)",open_issue:"Εκκρεμόν ζήτημα",open_plugin:"Ανοιχτό πρόσθετο",reinstall:"Επανεγκατάσταση",repository:"Αποθετήριο",show_beta:"Εμφάνιση του beta",uninstall:"Απεγκατάσταση",update_information:"Ενημέρωση πληροφοριών",upgrade:"Ενημέρωση"},ze={add_custom_repository:"ΠΡΟΣΘΕΣΤΕ ΕΝΑ ΕΙΔΙΚΟ ΑΠΟΘΕΤΗΡΙΟ",category:"Κατηγορία",custom_repositories:"ΕΙΔΙΚΑ ΑΠΟΘΕΤΗΡΙΑ",delete:"Διαγραφή",display:"Εμφάνιση",grid:"Πλέγμα",hacs_repo:"Αποθετήριο του HACS",reload_data:"Επαναφόρτωση δεδομένων",save:"Αποθήκευση",table:"Πίνακας",upgrade_all:"Αναβάθμιση όλων"},Te={placeholder_search:"Παρακαλώ πληκτρολογήστε έναν όρο προς αναζήτηση..."},$e={common:Se,config:je,confirm:Ee,options:Oe,repository:Ce,settings:ze,store:Te},Re={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apps",background_task:"Background task running, this page will reload when it's done.",installed:"installed",integration:"Integration",integrations:"Integrations",plugin:"Plugin",plugins:"Plugins",python_script:"Python Script",python_scripts:"Python Scripts",repositories:"Repositories",settings:"settings",theme:"Theme",themes:"Themes",version:"Version"},Ne={abort:{single_instance_allowed:"Only a single configuration of HACS is allowed."},error:{auth:"Personal Access Token is not correct."},step:{user:{data:{appdaemon:"Enable AppDaemon apps discovery & tracking",python_script:"Enable python_scripts discovery & tracking",sidepanel_icon:"Side panel icon",sidepanel_title:"Side panel title",theme:"Enable Themes discovery & tracking",token:"GitHub Personal Access Token"},description:"If you need help with the configuration have a look here: https://hacs.xyz/docs/configuration/start",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Ie={add_to_lovelace:"Are you sure you want to add this to your Lovelace resources?",bg_task:"Action is disabled while background tasks is running.",cancel:"Cancel",continue:"Are you sure you want to continue?",delete:"Are you sure you want to delete '{item}'?",delete_installed:"'{item}' is installed, you need to uninstall it before you can delete it.",exist:"{item} already exists",generic:"Are you sure?",no:"No",no_upgrades:"No upgrades pending",ok:"OK",overwrite:"Doing this will overwrite it.",uninstall:"Are you sure you want to uninstall '{item}'?",upgrade_all:"This will upgrade all of these repositories, make sure that you have read the release notes for all of them before proceeding.",yes:"Yes"},Pe={step:{user:{data:{country:"Filter with country code.",debug:"Enable debug.",experimental:"Enable experimental features",release_limit:"Number of releases to show."}}}},Me={integration_not_loaded:"This integration is not loaded in Home Assistant.",not_loaded:"Not loaded",plugin_not_loaded:"This plugin is not added to your Lovelace resources.",restart:"You need to restart Home Assistant.",restart_pending:"Restart pending"},Le={add_to_lovelace:"Add to Lovelace",authors:"Authors",available:"Available",back_to:"Back to",changelog:"Change log",flag_this:"Flag this",hide:"Hide",hide_beta:"Hide beta",install:"Install",installed:"Installed",lovelace_copy_example:"Copy the example to your clipboard",lovelace_instruction:"When you add this to your lovelace configuration use this",lovelace_no_js_type:"Could not determine the type of this plugin, check the repository.",newest:"newest",note_appdaemon:"you still need to add it to your 'apps.yaml' file",note_installed:"When installed, this will be located in",note_integration:"you still need to add it to your 'configuration.yaml' file",note_plugin:"you still need to add it to your lovelace configuration ('ui-lovelace.yaml' or the raw UI config editor)",open_issue:"Open issue",open_plugin:"Open plugin",reinstall:"Reinstall",repository:"Repository",show_beta:"Show beta",uninstall:"Uninstall",update_information:"Update information",upgrade:"Update"},De={add_custom_repository:"ADD CUSTOM REPOSITORY",adding_new_repo:"Adding new repository '{repo}'",adding_new_repo_category:"With category '{category}'.",bg_task_custom:"Custom repositories are hidden while background tasks is running.",category:"Category",compact_mode:"Compact mode",custom_repositories:"CUSTOM REPOSITORIES",delete:"Delete",display:"Display",grid:"Grid",hacs_repo:"HACS repo",hidden_repositories:"hidden repositories",missing_category:"You need to select a category",reload_data:"Reload data",save:"Save",table:"Table",table_view:"Table view",unhide:"unhide",upgrade_all:"Upgrade all"},He={clear_new:"Clear all new repositories",name:"Name",new_repositories:"New Repositories",pending_upgrades:"Pending upgrades",placeholder_search:"Please enter a search term...",sort:"sort",stars:"Stars",status:"Status"},Be={common:Re,config:Ne,confirm:Ie,options:Pe,repository_banner:Me,repository:Le,settings:De,store:He},Ue={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apps",background_task:"Ejecutando tareas en segundo plano. Se refrescará automaticamente esta página al finalizar.",installed:"instalado",integration:"Integración",integrations:"Integraciones",plugin:"Plugin",plugins:"Plugins",python_script:"Python Script",python_scripts:"Python Scripts",repositories:"Repositorios",settings:"configuraciones",theme:"Tema",themes:"Temas",version:"Versión"},qe={abort:{single_instance_allowed:"Sólo se permite una única configuración de HACS."},error:{auth:"El token de acceso personal no es correcto."},step:{user:{data:{appdaemon:"Habilitar el descubrimiento y seguimiento de las aplicaciones de AppDaemon",python_script:"Habilitar el descubrimiento y seguimiento en python_scripts",sidepanel_icon:"Ícono del panel lateral",sidepanel_title:"Título del panel lateral",theme:"Habilitar el descubrimiento y seguimiento de temas",token:"Token de acceso personal de GitHub"},description:"Si necesitas ayuda con la configuración dirigete a: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Ve={delete:'¿Seguro que quieres eliminar " {item} "?'},Fe={step:{user:{data:{country:"Filtrar por el código de país.",experimental:"Habilitar funciones experimentales",release_limit:"Número de versiones a mostrar."}}}},Ge={authors:"Autores",available:"Disponible",back_to:"Volver a",changelog:"Changelog",flag_this:"Marcar esto",hide:"Ocultar",hide_beta:"Ocultar beta",install:"Instalar",installed:"Instalado",lovelace_copy_example:"Copiar el ejemplo al clipboard",lovelace_instruction:"Cuando agregue esto a su configuración de lovelace, use esto",lovelace_no_js_type:"No se pudo determinar el tipo de plugin, revise el repositorio.",newest:"más nuevo",note_appdaemon:"deberá agregar esto a su archivo 'apps.yaml'",note_installed:"Al instalarse se encontrará en",note_integration:"deberá agregar esto a su archivo 'configuration.yaml'",note_plugin:"deberá agregar esto a su configuración de lovelace ('ui-lovelace.yaml' o en el editor UI de lovelace)",open_issue:"Abrir issue",open_plugin:"Abrir plugin",reinstall:"Reinstalar",repository:"Repositorio",show_beta:"Mostrar beta",uninstall:"Desinstalar",update_information:"Actualizar información",upgrade:"Actualizar"},We={add_custom_repository:"AGREGAR CUSTOM REPOSITORY",category:"Categoría",custom_repositories:"CUSTOM REPOSITORIES",delete:"Eliminar",display:"Display",grid:"Grilla",hacs_repo:"HACS repo",reload_data:"Releer datos",save:"Grabar",table:"Tabla",upgrade_all:"Actualizar todo"},Ye={placeholder_search:"Por favor escriba una palabra clave de búsqueda..."},Ze={common:Ue,config:qe,confirm:Ve,options:Fe,repository:Ge,settings:We,store:Ye},Ke={appdaemon:"AppDaemon",appdaemon_apps:"Applications AppDaemon",background_task:"Tache de fond en cours, cette page se rechargera une fois terminée",installed:"installés",integration:"Intégration",integrations:"Intégrations",plugin:"Plugin",plugins:"Plugins",python_script:"Script Python",python_scripts:"Scripts Python",repositories:"Dépôts",settings:"paramètres",theme:"Thème",themes:"Thèmes",version:"Version"},Xe={abort:{single_instance_allowed:"Une seule configuration de HACS est autorisée."},error:{auth:"Le jeton personnel d'accès est invalide."},step:{user:{data:{appdaemon:"Activer la découverte et le suivi des applications AppDaemon",python_script:"Activer la découverte et le suivi des scripts python",sidepanel_icon:"Icône de la barre latérale",sidepanel_title:"Titre de la barre latérale",theme:"Activer la découverte et le suivi des thèmes",token:"Jeton d'accès personnel GitHub"},description:"Si vous avez besoin d'aide pour la configuration, jetez un œil ici: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Je={add_to_lovelace:"Êtes-vous sûr de vouloir l'ajouter à vos ressources Lovelace ?",continue:"Es-tu sur de vouloir continuer?",delete:'Êtes-vous sûr de vouloir supprimer "{item}"?',generic:"Êtes-vous sûr?",overwrite:"En faisant cela, cela l'écrasera.",uninstall:'Êtes-vous sûr de vouloir désinstaller "{item}"?'},Qe={step:{user:{data:{country:"Filtrer par code pays.",experimental:"Activer les fonctionnalités expérimentales",release_limit:"Nombre de recensés à afficher."}}}},et={integration_not_loaded:"Cette intégration n'est pas chargée dans Home Assistant.",not_loaded:"Non chargé",plugin_not_loaded:"Ce plugin n'est pas ajouté à vos ressources Lovelace.",restart:"Vous devez redémarrer Home Assistant.",restart_pending:"Redémarrage en attente"},tt={add_to_lovelace:"Ajouter à Lovelace",authors:"Auteurs",available:"Disponible",back_to:"Retour",changelog:"Change log",flag_this:"Marquer",hide:"Masquer",hide_beta:"Masquer les bêta",install:"Installer",installed:"Installés",lovelace_copy_example:"Copier cet exemple dans le presse-papier",lovelace_instruction:"Quand vous l'ajoutez à votre configuration lovelace, utilisez",lovelace_no_js_type:"Impossible de déterminer le type de plugin, veuillez vérifier le dépôt",newest:"nouveau",note_appdaemon:"vous devez toujours l'ajouter à votre fichier 'apps.yaml'",note_installed:"Une fois installé, il se trouvera dans",note_integration:"Vous devez toujours l'ajouter à votre fichier 'configuration.yaml'",note_plugin:"Vous devez toujours l'ajouter à votre configuration lovelace ('ui-lovelace.yaml' ou l'éditeur de configuration de l'interface)",open_issue:"Ouvrir un ticket",open_plugin:"Ouvrir le plugin",reinstall:"Réinstaller",repository:"Dépôt",show_beta:"Afficher les bêta",uninstall:"Désinstaller",update_information:"Mettre à jour les informations",upgrade:"Mettre à jour"},ot={add_custom_repository:"AJOUTER UN DÉPÔT PERSONNALISÉ",category:"Catégorie",compact_mode:"Mode compact",custom_repositories:"DÉPÔTS PERSONNALISÉS",delete:"Supprimer",display:"Affichage",grid:"Grille",hacs_repo:"Dépôt HACS",hidden_repositories:"dépôts cachés",reload_data:"Recharger les données",save:"Enregistrer",table:"Tableau",table_view:"Vue table",unhide:"Afficher",upgrade_all:"Tout mettre à jour"},at={clear_new:"Effacer tous les nouveaux dépôts",name:"Nom",new_repositories:"Nouveaux dépôts",placeholder_search:"Veuillez entrer un terme de recherche...",sort:"Trier",status:"Statut"},nt={common:Ke,config:Xe,confirm:Je,options:Qe,repository_banner:et,repository:tt,settings:ot,store:at},rt={appdaemon:"AppDaemon",appdaemon_apps:"Applicazioni AppDaemon",background_task:"Attività in esecuzione, questa pagina sarà ricaricata al termine.",installed:"Installati",integration:"Integrazione",integrations:"Integrazioni",plugin:"Plugin",plugins:"Plugin",python_script:"Script python",python_scripts:"Script python",repositories:"Repository",settings:"Impostazioni",theme:"Tema",themes:"Temi",version:"Versione"},it={abort:{single_instance_allowed:"È consentita una sola configurazione di HACS."},error:{auth:"Il token di accesso personale non è corretto."},step:{user:{data:{appdaemon:"Abilita il rilevamento e il monitoraggio delle applicazioni AppDaemon",python_script:"Abilita il rilevamento e il monitoraggio dei python_scripts",sidepanel_icon:"Icona nel pannello laterale",sidepanel_title:"Titolo nel pannello laterale",theme:"Abilita individuazione e tracciamento dei temi",token:"Token di accesso personale GitHub"},description:"Se hai bisogno di aiuto con la configurazione dai un'occhiata qui: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},st={step:{user:{data:{country:"Filtra con prefisso internazionale.",experimental:"Abilita funzionalità sperimentali",release_limit:"Numero di versioni da mostrare."}}}},lt={authors:"Autori",available:"Disponibile",back_to:"Torna a",changelog:"Change log",flag_this:"Spunta questo",hide:"Nascondi",hide_beta:"Nascondi beta",install:"Installa",installed:"Installato",lovelace_copy_example:"Copia l'esempio negli appunti",lovelace_instruction:"Quando lo aggiungi nella configurazione di lovelace, usa questo ",lovelace_no_js_type:"Impossibile determinare il tipo di plugin, verificare il repository.",newest:"Più recente",note_appdaemon:"dovrai aggiungerlo nel file 'apps.yaml'",note_installed:"Una volta installato, si troverà in",note_integration:"dovrai aggiungerlo nel file 'configuration.yaml'",note_plugin:"devi aggiungere la configurazione nel file 'ui-lovelace.yaml' oppure via Editor RAW della UI.",open_issue:"Segnala anomalia",open_plugin:"Apri plugin",reinstall:"Reinstalla",repository:"Repository",show_beta:"Visualizza beta",uninstall:"Rimuovi",update_information:"Aggiorna informazioni",upgrade:"Aggiorna"},ct={add_custom_repository:"AGGIUNGI REPOSITORY PERSONALIZZATA",category:"Categoria",custom_repositories:"REPOSITORY PERSONALIZZATE",delete:"Cancella",display:"Visualizza",grid:"Griglia",hacs_repo:"HACS repo",reload_data:"Ricarica i dati",save:"Salva",table:"Tabella",upgrade_all:"Aggiorna tutto"},dt={placeholder_search:"Inserire un termine di ricerca"},pt={common:rt,config:it,options:st,repository:lt,settings:ct,store:dt},ut={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apper",background_task:"Bakgrunnsoppgaven kjører. Denne siden lastes inn på nytt når den er ferdig.",installed:"Installert",integration:"Integrering",integrations:"Integrasjoner",plugin:"Plugin",plugins:"Plugins",python_script:"Python-skript",python_scripts:"Python-skript",repositories:"Repositories",settings:"Innstillinger",theme:"Teama",themes:"Temaer",version:"Versjon"},ht={abort:{single_instance_allowed:"Bare en konfigurasjon av HACS er tillatt."},error:{auth:"Personlig tilgangstoken er ikke korrekt."},step:{user:{data:{appdaemon:"Aktiver oppdagelse og sporing av AppDaemon-apper",python_script:"Aktiver oppdagelse og sporing av python_scripts",sidepanel_icon:"Sidepanel ikon",sidepanel_title:"Sidepanel tittel",theme:"Aktiver oppdagelse og sporing av temaer",token:"GitHub Personal Access Token"},description:"Hvis du trenger hjelp med konfigurasjonen, ta en titt her: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},gt={add_to_lovelace:"Er du sikker på at du vil legge dette til i dine Lovelace resources?",bg_task:"Handlingen er deaktivert mens bakgrunnsoppgaver kjører.",cancel:"Avbryt",continue:"Er du sikker på at du vil fortsette?",delete:'Er du sikker på at du vil fjerne "{item}"?',delete_installed:"'{item}' er installert, du må avinstallere det før du kan slette det.",exist:"{item} eksisterer allerede",generic:"Er du sikker?",no:"Nei",no_upgrades:"Ingen oppgraderinger tilgjengelig",ok:"OK",overwrite:"Å gjøre dette vil overskrive det.",uninstall:'Er du sikker på at du vil avinstallere "{item}"?',upgrade_all:"Dette vil oppgradere alle disse repositorene, sørg for at du har lest utgivelses notatene for dem alle før du fortsetter.",yes:"Ja"},mt={step:{user:{data:{country:"Filtrer med landskode.",debug:"Aktiver debug",experimental:"Aktiver eksperimentelle funksjoner",release_limit:"Antall utgivelser som skal vises."}}}},ft={integration_not_loaded:"Integrasjonen er ikke lastet inn i Home Assistant.",not_loaded:"Ikke lastet inn",plugin_not_loaded:'Denne pluginen er ikke lagt til i lovelace under "resource" delen av konfigurasjonen.',restart:"Du må restart Home Assistant",restart_pending:"Restart er nødvendig"},_t={add_to_lovelace:"Legg til i Lovelace",authors:"Laget av",available:"Tilgjengelig",back_to:"Tilbake til",changelog:"Endringslogg",flag_this:"Flag dette",hide:"Skjul",hide_beta:"Skjul beta",install:"Installer",installed:"Installert",lovelace_copy_example:"Kopier eksemplet til utklippstavlen",lovelace_instruction:"Når du legger til dette i lovelace-konfigurasjonen din, bruk dette",lovelace_no_js_type:"Kunne ikke bestemme typen for denne plugin, sjekk repository.",newest:"Nyeste",note_appdaemon:"du må fortsatt legge den til i 'apps.yaml' filen",note_installed:"Når det er installert, vil dette ligge i",note_integration:"du må fortsatt legge den til 'configuration.yaml' filen",note_plugin:"du må fortsatt legge den til i lovelace-konfigurasjonen ('ui-lovelace.yaml' eller den rå UI-konfigurasjonsredigereren)",open_issue:"Meld et problem",open_plugin:"Åpne plugin",reinstall:"Installer på nytt",repository:"Repository",show_beta:"Vis beta",uninstall:"Avinstaller",update_information:"Oppdater informasjon",upgrade:"Oppdater"},bt={add_custom_repository:"LEGG TIL REPOSITORY",adding_new_repo:"Legger til ny repository '{repo}'",adding_new_repo_category:"Med kategori '{kategori}'.",bg_task_custom:"Custom repositories er skjult mens bakgrunnsoppgaver kjører.",category:"Kategori",compact_mode:"Kompakt modus",custom_repositories:"TILPASSEDE REPOSITORIER",delete:"Slett",display:"Vise",grid:"Nett",hacs_repo:"HACS repo",hidden_repositories:"Gjemte repositories",missing_category:"Du må velge en kategori",reload_data:"Last inn data på nytt",save:"Lagre",table:"Tabell",table_view:"Tabellvisning",unhide:"Vis igjen",upgrade_all:"Oppgradere alle"},yt={clear_new:"Tøm nye repositories",name:"Navn",new_repositories:"Nye repositories",pending_upgrades:"Venter på oppgradering",placeholder_search:"Skriv inn et søkeord ...",sort:"sorter",stars:"Stjerner",status:"Status"},wt={common:ut,config:ht,confirm:gt,options:mt,repository_banner:ft,repository:_t,settings:bt,store:yt},vt={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apps",background_task:"Achtergrond taak is draaiende, de pagina herhaalt zichzelf wanneer dit klaar is.",installed:"geinstalleerd",integration:"Integratie",integrations:"Integraties",plugin:"Plugin",plugins:"Plugins",python_script:"Python Script",python_scripts:"Python Scripts",repositories:"Repositories",settings:"instellingen",theme:"Thema",themes:"Themas",version:"Versie"},kt={abort:{single_instance_allowed:"Je kunt maar een enkele configuratie van HACS tegelijk hebben."},error:{auth:"Persoonlijke Toegang Token is niet correct."},step:{user:{data:{appdaemon:"Zet AppDaemon apps ontdekken & traceren aan",python_script:"Zet python_scripts ontdekken & traceren aan",sidepanel_icon:"Zijpaneel icoon",sidepanel_title:"Zijpaneel titel",theme:"Zet Themes ontdekken & traceren aan",token:"GitHub Persoonlijke Toegang Token"},description:"Als je hulp nodig hebt met de configuratie, kun je hier verder kijken: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},xt={add_to_lovelace:"Weet u zeker dat u dit wilt toevoegen aan uw Lovelace bronnen?",continue:"Weet je zeker dat je door wilt gaan?",delete:'Weet u zeker dat u "{item}" wilt verwijderen?',generic:"Weet je het zeker?",overwrite:"Door dit te doen, wordt het overschreven.",uninstall:'Weet u zeker dat u "{item}" wilt verwijderen?'},At={step:{user:{data:{country:"Filter met land code.",experimental:"Zet experimentele functies aan",release_limit:"Aantal releases om te laten zien."}}}},St={integration_not_loaded:"Deze integratie wordt niet geladen in Home Assistant.",not_loaded:"Niet geladen",plugin_not_loaded:"Deze plugin wordt niet toegevoegd aan je Lovelace resources.",restart:"U moet Home Assistant opnieuw starten.",restart_pending:"Wachten op herstart"},jt={add_to_lovelace:"Toevoegen aan Lovelace",authors:"Auteurs",available:"Beschikbaar",back_to:"Terug naar",changelog:"Changelog",flag_this:"Vlag dit",hide:"Verberg",hide_beta:"Verberg beta",install:"Installeer",installed:"Geinstalleerd",lovelace_copy_example:"Kopier het voorbeeld naar je klembord",lovelace_instruction:"Wanneer je dit gaat toevoegen aan je lovelace configuratie gebruik dit",lovelace_no_js_type:"Kon niet achterhalen welk type plugin dit is, check de repository van de plugin.",newest:"nieuwste",note_appdaemon:"je moet het nog steeds toevoegen aan je 'apps.yaml' bestand",note_installed:"Wanneer geïnstalleerd, staat het in",note_integration:"je moet het nog steeds toevoegen aan je 'configuration.yaml' bestand",note_plugin:"je moet het nog steeds toevoegen aan je lovelace configuratie ('ui-lovelace.yaml') of raw UI config editor.",open_issue:"Meld probleem",open_plugin:"Open plugin",reinstall:"Herinstalleer",repository:"Repository",show_beta:"Laat beta zien",uninstall:"Verwijder",update_information:"Update informatie",upgrade:"Update"},Et={add_custom_repository:"VOEG EIGEN REPOSITORY TOE",category:"Categorie",compact_mode:"Compacte modus",custom_repositories:"EIGEN REPOSITORIES",delete:"Verwijder",display:"Weergave",grid:"Rooster",hacs_repo:"HACS repo",hidden_repositories:"verborgen repositories",reload_data:"Herlaad data",save:"Opslaan",table:"Tabel",table_view:"Tabelweergave",unhide:"zichtbaar maken",upgrade_all:"Upgrade alles"},Ot={clear_new:"Wissen van alle nieuwe repositories",name:"Naam",new_repositories:"Nieuwe Repositories",placeholder_search:"Typ iets om te zoeken...",sort:"sorteer",status:"Status"},Ct={common:vt,config:kt,confirm:xt,options:At,repository_banner:St,repository:jt,settings:Et,store:Ot},zt={appdaemon:"AppDaemon",appdaemon_apps:"AppDeamon-appar",background_task:"Bakgrunnsoppgåve køyrer. Denne sida kjem til å laste seg omatt når ho er ferdig.",installed:"Installert",integration:"Integrasjon",integrations:"Integrasjonar",plugin:"Tillegg",plugins:"Tillegg",python_script:"Pythonskript",python_scripts:"Pythonskript",repositories:"Repositories",settings:"innstillingar",theme:"Tema",themes:"Tema",version:"Versjon"},Tt={abort:{single_instance_allowed:"Berre éin enkelt konfigurasjon av HACS er tillete."},error:{auth:"Personleg tilgangsnøkkel er ikkje korrekt."},step:{user:{data:{appdaemon:"Aktiver AppDeamon-appar-oppdaging og sporing",python_script:"Aktiver pythonscript-oppdaging og sporing",sidepanel_icon:"Sidepanelikon",sidepanel_title:"Sidepaneltittel",theme:"Aktiver tema-oppdaging og sporing",token:"Personleg GitHub tilgangsnøkkel"},description:"Dersom du treng hjelp med konfigurasjonen, ta ein kik her: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},$t={add_to_lovelace:"Er du sikker på at du vil legge til dette i Lovelace-ressursane dine?",continue:"Er du sikker på at du vil halde fram?",delete:'Er du sikker på at du vil slette "{item}"?',generic:"Er du sikker?",overwrite:"Ved å gjere dette kjem du til å overskrive. ",uninstall:'Er du sikker på at du vil avinstallere "{item}"?'},Rt={step:{user:{data:{country:"Filterer med landskode",experimental:"Aktiver ekspreimentelle funksjonar",release_limit:"Talet på utgivingar"}}}},Nt={integration_not_loaded:"Integrasjonen er ikkje lasta inn i Home Assistant.",not_loaded:"Ikkje lasta",plugin_not_loaded:"Tillegget er ikkje lagt til i Lovelace-ressursane dine.",restart:"Du må starte Home Assistant på nytt",restart_pending:"Omstart venter"},It={add_to_lovelace:"Legg til i Lovelace",authors:"Forfatter(e)",available:"Tilgjengeleg",back_to:"Tilbake til",changelog:"Endre logg",flag_this:"Marker dette",hide:"Gøym",hide_beta:"Gøym beta",install:"Installer",installed:"Installert",lovelace_copy_example:"Kopier eksempelet til utklippsbreittet ditt",lovelace_instruction:"Når du legg til dette i Lovelace-konfigurasjonen din, bruk dette",lovelace_no_js_type:"Kunne ikkje slå fast typen til dette tilegget. Sjå i repositoryet.",newest:"nyaste",note_appdaemon:'du må framleis legge dette til i "apps.yaml"-fila di',note_installed:"Når dette er installert, kjem den til å vere plassert i",note_integration:'du må framleis legge dette til i "configuration.yaml"-fila di',note_plugin:'du må framleis dette til i Lovelace-konfigurasjonen ("ui-lovelace.yaml" eller i rå-brukargrensesnittredigeraren',open_issue:"Opne problem",open_plugin:"Opne tillegg",reinstall:"Installer på nytt",repository:"Repository",show_beta:"Vis beta",uninstall:"Avinstaller",update_information:"Oppdater informasjonen",upgrade:"Oppdater"},Pt={add_custom_repository:"LEGG TIL EIN ANNAN REPOSITORY",category:"Kategori",compact_mode:"Kompaktmodus",custom_repositories:"VANLEG REPOSITORY",delete:"Slett",display:"Vis",grid:"rutenett",hacs_repo:"HACS repo",hidden_repositories:"gøymde repositories",reload_data:"Last om dataa",save:"Lagre",table:"Tavle",table_view:"Tabellvisning",unhide:"vis",upgrade_all:"Oppdater alle"},Mt={clear_new:"Fjern alle nye repositories",name:"Namn",new_repositories:"Ny repository",placeholder_search:"Ver vennleg og skriv inn ei søkefrase",sort:"Sorter",status:"Status"},Lt={common:zt,config:Tt,confirm:$t,options:Rt,repository_banner:Nt,repository:It,settings:Pt,store:Mt},Dt={appdaemon:"AppDaemon",appdaemon_apps:"Aplikacje AppDaemon",background_task:"Wykonywanie zadania w tle, ta strona zostanie odświeżona, gdy zadanie zostanie ukończone.",installed:"zainstalowane",integration:"Integracja",integrations:"Integracje",plugin:"Wtyczka",plugins:"Wtyczki",python_script:"Skrypt Python",python_scripts:"Skrypty Python",repositories:"Repozytoria",settings:"ustawienia",theme:"Motyw",themes:"Motywy",version:"Wersja"},Ht={abort:{single_instance_allowed:"Dozwolona jest tylko jedna konfiguracja HACS."},error:{auth:"Osobisty token dostępu jest nieprawidłowy."},step:{user:{data:{appdaemon:"Włącz wykrywanie i śledzenie aplikacji AppDaemon",python_script:"Włącz wykrywanie i śledzenie skryptów Python",sidepanel_icon:"Ikona w panelu bocznym",sidepanel_title:"Tytuł w panelu bocznym",theme:"Włącz wykrywanie i śledzenie motywów",token:"Osobisty token dostępu GitHub"},description:"Jeśli potrzebujesz pomocy w konfiguracji, przejdź na stronę: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Bt={add_to_lovelace:"Na pewno chcesz dodać to do swoich zasobów Lovelace?",continue:"Na pewno chcesz kontynuować?",delete:'Na pewno chcesz usunąć "{item}"?',generic:"Jesteś pewny?",overwrite:"Spowoduje to zastąpienie istniejącej kopii.",uninstall:'Na pewno chcesz odinstalować "{item}"?'},Ut={step:{user:{data:{country:"Filtruj według kodu kraju",experimental:"Włącz funkcje eksperymentalne",release_limit:"Liczba wydań do wyświetlenia"}}}},qt={integration_not_loaded:"Ta integracja nie jest załadowana do Home Assistant'a.",not_loaded:"Nie załadowano",plugin_not_loaded:"Ta wtyczka nie jest dodana do zasobów Lovelace.",restart:"Musisz ponownie uruchomić Home Assistant'a.",restart_pending:"Oczekiwanie na ponowne uruchomienie"},Vt={add_to_lovelace:"Dodaj do Lovelace",authors:"Autorzy",available:"Dostępna",back_to:"Wróć do",changelog:"Lista zmian",flag_this:"Oflaguj",hide:"Ukryj",hide_beta:"Ukryj wydania beta",install:"Zainstaluj",installed:"Zainstalowano",lovelace_copy_example:"Skopiuj przykład do schowka",lovelace_instruction:"Interfejs użytkownika użyje tej wtyczki po dodaniu konfiguracji",lovelace_no_js_type:"Nie można określić typu tej wtyczki, sprawdź repozytorium.",newest:"najnowsza",note_appdaemon:"musisz jeszcze dodać aplikację do pliku 'apps.yaml'",note_installed:"Po zainstalowaniu dodatek będzie znajdować się w",note_integration:"musisz jeszcze dodać integrację do pliku 'configuration.yaml'",note_plugin:"musisz jeszcze dodać wtyczkę do konfiguracji interfejsu użytkownika (plik 'ui-lovelace.yaml' lub edytor interfejsu użytkownika)",open_issue:"Powiadom o problemie",open_plugin:"Otwórz dodatek",reinstall:"Przeinstaluj",repository:"Repozytorium",show_beta:"Wyświetl wydania beta",uninstall:"Odinstaluj",update_information:"Informacje o aktualizacji",upgrade:"Uaktualnij"},Ft={add_custom_repository:"DODAJ REPOZYTORIUM NIESTANDARDOWE",category:"Kategoria",compact_mode:"Tryb kompaktowy",custom_repositories:"REPOZYTORIA NIESTANDARDOWE",delete:"Usuń",display:"Sposób wyświetlania",grid:"kratka",hacs_repo:"Repozytorium HACS",hidden_repositories:"ukryte repozytoria",reload_data:"Wczytaj ponownie dane",save:"Zapisz",table:"tabela",table_view:"Widok tabeli",unhide:"pokaż",upgrade_all:"Uaktualnij wszystkie"},Gt={clear_new:"Wyczyść wszystkie nowe repozytoria",name:"Nazwa",new_repositories:"Nowe repozytoria",placeholder_search:"Wprowadź wyszukiwane hasło...",sort:"sortowanie",status:"Status"},Wt={common:Dt,config:Ht,confirm:Bt,options:Ut,repository_banner:qt,repository:Vt,settings:Ft,store:Gt},Yt={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Apps",background_task:"Tarefa em segundo plano em execução, esta página será recarregada quando terminar.",installed:"instalado",integration:"Integração",integrations:"Integrações",plugin:"Plugin",plugins:"Plugins",python_script:"Python Script",python_scripts:"Python Scripts",repositories:"Repositórios",settings:"configurações",theme:"Tema",themes:"Temas",version:"Versão"},Zt={abort:{single_instance_allowed:"Apenas uma configuração do HACS é permitida."},error:{auth:"Token de acesso pessoal incorreto."},step:{user:{data:{appdaemon:"Habilitar AppDaemon apps descoberta & rastreamento",python_script:"Habilitar python_scripts descoberta & rastreamento",sidepanel_icon:"Icone do painel lateral",sidepanel_title:"Titulo do painel lateral",theme:"Habilitar temas descoberta & rastreamento",token:"GitHub Token de acesso pessoal"},description:"Se você preciar de ajuda com a configuração olhe aqui: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Kt={step:{user:{data:{country:"Filtro pelo código do país.",experimental:"Ativar recursos experimentais",release_limit:"Número de lançamentos a serem exibidos."}}}},Xt={authors:"Autores",available:"Disponível",back_to:"Voltar para",changelog:"Changelog",flag_this:"Sinalizar isso",hide:"Esconder",hide_beta:"Esconder beta",install:"Instalar",installed:"Instalado",lovelace_copy_example:"Copie este exemplo para seu clipboard",lovelace_instruction:"Quando você adicionar isso à sua configuração do lovelace, use este",lovelace_no_js_type:"Não foi possível determinar o tipo deste plug-in, verifique o repositório.",newest:"O mais novo",note_appdaemon:"Você ainda precisa adicioná-lo ao seu arquivo 'apps.yaml'",note_installed:"Quando instalado, ele estará localizado em",note_integration:"Você ainda precisa adicioná-lo ao seu arquivo 'configuration.yaml'",note_plugin:"você ainda precisará adicioná-lo à sua configuração do lovelace ('ui-lovelace.yaml' ou o editor de configuração da interface do usuário)",open_issue:"Open issue",open_plugin:"Plugin aberto",reinstall:"Reinstalar",repository:"Repositório",show_beta:"Mostrar beta",uninstall:"Desinstalar",update_information:"Atualizar informação",upgrade:"Melhorar"},Jt={add_custom_repository:"ADICIONAR REPOSITÓRIO PERSONALIZADO",category:"Categoria",custom_repositories:"REPOSITÓRIOS PERSONALIZADOS",delete:"Deletar",display:"Display",grid:"Grade",hacs_repo:"HACS repo",reload_data:"Recarregar dados",save:"Salvar",table:"Tabela",upgrade_all:"Atualizar tudo"},Qt={placeholder_search:"Por favor insira um termo de pesquisa..."},eo={common:Yt,config:Zt,options:Kt,repository:Xt,settings:Jt,store:Qt},to={appdaemon:"AppDaemon",appdaemon_apps:"Aplicații AppDaemon",background_task:"Activitatea de fundal se execută, această pagină se va reîncărca atunci când este gata.",installed:"instalat",integration:"Integrare",integrations:"Integrări",plugin:"Plugin",plugins:"Plugin-uri",python_script:"Script Python",python_scripts:"Scripturi Python",repositories:"Depozite",settings:"setări",theme:"Temă",themes:"Teme",version:"Versiune"},oo={abort:{single_instance_allowed:"Doar o singură configurație pentru HACS este permisă."},error:{auth:"Token-ul de acces personal nu este corect."},step:{user:{data:{appdaemon:"Activați descoperirea și urmărirea aplicațiilor AppDaemon",python_script:"Activați descoperirea și urmărirea python_scripts",sidepanel_icon:"Pictogramă Panou lateral",sidepanel_title:"Titlu panou lateral",theme:"Activați descoperirea și urmărirea temelor",token:"Token de acces personal GitHub"},description:"Dacă aveți nevoie de ajutor pentru configurare, uitați-vă aici: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},ao={delete:"Sigur doriți să ștergeți „{item}”?"},no={step:{user:{data:{country:"Filtrează cu codul țării.",experimental:"Activați funcțiile experimentale",release_limit:"Număr de versiuni afișate."}}}},ro={authors:"Autori",available:"Disponibil",back_to:"Înapoi la",changelog:"Jurnal modificari",flag_this:"Semnalizează",hide:"Ascunde",hide_beta:"Ascundere beta",install:"Instalează",installed:"Instalat",lovelace_copy_example:"Copiați exemplul în clipboard",lovelace_instruction:"Când adăugați acest lucru la configurația lovelace, folosiți acest",lovelace_no_js_type:'Nu s-a putut determina tipul acestui plugin, verificați "repository"',newest:"cele mai noi",note_appdaemon:"mai trebuie să o adăugați in fișierul „apps.yaml”",note_installed:"Când este instalat, acesta va fi localizat în",note_integration:"mai trebuie să o adăugați in fișierul „configuration.yaml”",note_plugin:"mai trebuie să o adăugați la configurația lovelace ('ui-lovelace.yaml' sau in editorul UI)",open_issue:"Deschidere problemă",open_plugin:"Deschide plugin",reinstall:"Reinstalare",repository:"Depozit",show_beta:"Afișare beta",uninstall:"Dezinstalare",update_information:"Actualizare informație",upgrade:"Actualizare"},io={add_custom_repository:"ADĂUGARE DEPOZIT PERSONALIZAT",category:"Categorie",custom_repositories:"DEPOZITE PERSONALIZATE",delete:"Șterge",display:"Afişeaza",grid:"Grilă",hacs_repo:"HACS repo",reload_data:"Reîncărcați datele",save:"Salveaza",table:"Tabel",upgrade_all:"Actualizați toate"},so={placeholder_search:"Vă rugăm să introduceți un termen de căutare ..."},lo={common:to,config:oo,confirm:ao,options:no,repository:ro,settings:io,store:so},co={appdaemon:"AppDaemon",appdaemon_apps:"Приложения AppDaemon",background_task:"Выполняется фоновая задача, страница перезагрузится по готовности.",installed:"установлено",integration:"Интеграция",integrations:"Интеграции",plugin:"Плагин",plugins:"Плагины",python_script:"Скрипт Python",python_scripts:"Скрипты Python",repositories:"Репозитории",settings:"настройки",theme:"Тема",themes:"Темы",version:"Версия"},po={abort:{single_instance_allowed:"Разрешена только одна настройка HACS."},error:{auth:"Неверный токен персонального доступа."},step:{user:{data:{appdaemon:"Включить поиск и отслеживание приложений AppDaemon",python_script:"Включить поиск и отслеживание скриптов Python",sidepanel_icon:"Иконка в боковом меню",sidepanel_title:"Название в боковом меню",theme:"Включить поиск и отслеживание тем",token:"GitHub-токен персонального доступа"},description:"Если вам нужна помощь с настройкой, посмотрите: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},uo={add_to_lovelace:"Вы уверены, что хотите добавить это в ресурсы Lovelace?",continue:"Вы уверены, что хотите продолжить?",delete:'Вы уверены, что хотите удалить "{item}"?',generic:"Вы уверены?",overwrite:"После подтверждения файлы будут перезаписаны.",uninstall:'Вы уверены, что хотите удалить "{item}"?'},ho={step:{user:{data:{country:"Фильтр с кодом страны.",experimental:"Включить экспериментальные функции",release_limit:"Число доступных версий."}}}},go={integration_not_loaded:"Эта интеграция не загружена в Home Assistant.",not_loaded:"Не загружено",plugin_not_loaded:"Этот плагин не добавлен к ресурсам Lovelace.",restart:"Вам нужно перезапустить Home Assistant.",restart_pending:"Ожидается перезапуск"},mo={add_to_lovelace:"Добавить в Lovelace",authors:"Авторы",available:"Доступно",back_to:"Назад к",changelog:"Изменения",flag_this:"Пожаловаться",hide:"Скрыть",hide_beta:"Скрыть бета",install:"Установить",installed:"Установлено",lovelace_copy_example:"Скопируйте пример в буфер обмена",lovelace_instruction:"Для добавления в конфигурацию Lovelace, используйте",lovelace_no_js_type:"Не удалось определить тип этого плагина, проверьте репозиторий.",newest:"новейшая",note_appdaemon:"вам всё ещё нужно добавить код для настройки приложения в файл 'apps.yaml'",note_installed:"После установки, файлы будут расположены в",note_integration:"вам всё ещё нужно добавить код для настройки интеграции в файл 'configuration.yaml'",note_plugin:"вам всё ещё нужно добавить код для настройки плагина в конфигурацию Lovelace ('ui-lovelace.yaml')",open_issue:"Сообщить о проблеме",open_plugin:"Открыть плагин",reinstall:"Переустановить",repository:"Репозиторий",show_beta:"Показать бета",uninstall:"Удалить",update_information:"Обновить информацию",upgrade:"Обновить"},fo={add_custom_repository:"ДОБАВИТЬ СВОЙ РЕПОЗИТОРИЙ",category:"Категория",compact_mode:"Компактный режим",custom_repositories:"СВОИ РЕПОЗИТОРИИ",delete:"Удалить",display:"Вид",grid:"Сетка",hacs_repo:"Репозиторий HACS",hidden_repositories:"Скрытые репозитории",reload_data:"Перезагрузить",save:"Сохранить",table:"Таблица",table_view:"Таблица",unhide:"Показать",upgrade_all:"Обновить всё"},_o={clear_new:"Очистить все новые репозитории",name:"Название",new_repositories:"Новые репозитории",placeholder_search:"Пожалуйста, введите условие для поиска...",sort:"Сортировка",status:"Статус"},bo={common:co,config:po,confirm:uo,options:ho,repository_banner:go,repository:mo,settings:fo,store:_o},yo={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon Aplikacije",background_task:"v ozadju se izvaja naloga, ko se konča, se bo stran osvežila.",installed:"Nameščeno",integration:"Integracija",integrations:"Integracije",plugin:"vtičnik",plugins:"Vtičniki",python_script:"Python skripta",python_scripts:"Python skripte",repositories:"Repozitoriji",settings:"nastavitve",theme:"Tema",themes:"Teme",version:"Različica"},wo={abort:{single_instance_allowed:"Dovoljena je samo ena konfiguracija HACS."},error:{auth:"Osebni dostopni žeton ni pravilen."},step:{user:{data:{appdaemon:"Omogoči odkrivanje in sledenje aplikacij AppDaemon",python_script:"Omogoči odkrivanje in sledenje python_scripts",sidepanel_icon:"Ikona stranske plošče",sidepanel_title:"Naslov stranske plošče",theme:"Omogoči odkrivanje in sledenje tem",token:"GitHub žeton za osebni dostop"},description:"Če potrebujete pomoč pri konfiguraciji, poglejte tukaj: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},vo={add_to_lovelace:"Ali si prepričan, da želiš to dodati med svoje vire Lovelace?",continue:"Ali ste prepričani, da želite nadaljevati?",delete:'Ali ste prepričani, da želite izbrisati "{item}"?',generic:"Ali si prepričan?",overwrite:"Če to storite, bo to prepisano.",uninstall:'Ali ste prepričani, da želite odstraniti "{item}"?'},ko={step:{user:{data:{country:"Filtrirajte s kodo države.",experimental:"Omogočite poskusne funkcije",release_limit:"Število izdaj, ki jih želite prikazati."}}}},xo={integration_not_loaded:"Ta integracija ni naložena v programu Home Assistant.",not_loaded:"Ni naloženo",plugin_not_loaded:"Ta vtičnik ni dodan vašim virom Lovelace.",restart:"Znova morate zagnati Home Assistant.",restart_pending:"Vnovični zagon v čakanju"},Ao={add_to_lovelace:"Dodaj v Lovelace",authors:"Avtorji",available:"Na voljo",back_to:"Nazaj na",changelog:"Dnevnik sprememb",flag_this:"Označite to",hide:"Skrij",hide_beta:"Skrij različico beta",install:"Namestite",installed:"Nameščeno",lovelace_copy_example:"Kopirajte primer v odložišče",lovelace_instruction:"Ko ga boste dodajali v svojo lovelace konfiguracijo uporabite to:",lovelace_no_js_type:"Ni bilo mogoče določiti vrsto tega vtičnika, preverite repozitorij.",newest:"najnovejše",note_appdaemon:"Še vedno ga morate dodati v svojo 'apps.yaml' datoteko",note_installed:"Ko bo nameščen, se bo nahajal v",note_integration:"Še vedno ga morate dodati v svojo 'configuration.yaml' datoteko",note_plugin:'vendar ga še vedno morate dodati v svojo lovelace konfiguracijo (\'ui-lovelace.yaml " ali "raw" UI config urejevalnik)',open_issue:"Odprite težavo",open_plugin:"Odprite vtičnik",reinstall:"Znova namestite",repository:"Repozitorij",show_beta:"Pokaži različico beta",uninstall:"Odstranite",update_information:"Posodobite podatke",upgrade:"Nadgradnja"},So={add_custom_repository:"DODAJTE SVOJ REPOZITORIJ",category:"Kategorija",compact_mode:"Kompaktni način",custom_repositories:"VAŠI REPOZITORIJI",delete:"Izbriši",display:"Prikaz",grid:"Mreža",hacs_repo:"HACS repo",hidden_repositories:"skriti repozitoriji",reload_data:"Ponovno naloži podatke",save:"Shranite",table:"Tabela",table_view:"Pogled tabele",unhide:"Razkrij",upgrade_all:"Nadgradite vse"},jo={clear_new:"Počisti vse nove repozitorije",name:"Ime",new_repositories:"Novi repozitoriji",placeholder_search:"Prosim vnesite iskalni izraz ...",sort:"razvrsti",status:"Stanje"},Eo={common:yo,config:wo,confirm:vo,options:ko,repository_banner:xo,repository:Ao,settings:So,store:jo},Oo={appdaemon:"AppDaemon",appdaemon_apps:"Appdaemon Applikationer",background_task:"Bakgrundsjobb körs, denna sida kommer att laddas igen när det är klart.",installed:"installerad",integration:"Integration",integrations:"Integrationer",plugin:"Plugin",plugins:"Plugins",python_script:"Python skript",python_scripts:"Python skript",repositories:"Repositories",settings:"inställningar",theme:"Tema",themes:"Teman",version:"Version"},Co={abort:{single_instance_allowed:"Endast en konfiguration kan användas i HACS."},error:{auth:"Personal Access Token är inte korrekt."},step:{user:{data:{appdaemon:"Upptäck och följ Appdaemon applikationer",python_script:"Upptäck och följ python_scripts",sidepanel_icon:"Ikon för sidpanel",sidepanel_title:"Rubrik för sidpanel",theme:"Upptäck och följ teman",token:"GitHub Personal Access Token"},description:"Om du behöver hjälp med konfigurationen, se här: https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},zo={add_to_lovelace:"Är du säker på att du vill lägga till detta till dina Lovelace-resurser?",continue:"Är du säker på att du vill fortsätta?",delete:'Är du säker på att du vill ta bort "{item}"?',generic:"Är du säker?",overwrite:"Detta kommer att skriva över den.",uninstall:'Är du säker på att du vill avinstallera " {item} "?'},To={step:{user:{data:{country:"Filtrera på landskod.",experimental:"Använd experimentella funktioner",release_limit:"Antalet releaser som visas."}}}},$o={integration_not_loaded:"Denna integration inte laddats i Hem Assistent.",not_loaded:"Ej laddad",plugin_not_loaded:"Detta plugin är inte tillagt till din Lovelaceresurs.",restart:"Du måste starta om Home Assistant.",restart_pending:"Omstart väntar"},Ro={add_to_lovelace:"Lägg till i Lovelace",authors:"Författare",available:"Tillgänglig",back_to:"Tillbaka till",changelog:"Ändringslogg",flag_this:"Flagga denna",hide:"Göm",hide_beta:"Göm betaversioner",install:"Installera",installed:"Installerad",lovelace_copy_example:"Kopiera exemplet till urklipp",lovelace_instruction:"När du lägger till denna till din lovelace konfiguration, använd",lovelace_no_js_type:"Kan inte avgöra villken typ av plugin, kontrollera i GIT \nrepository",newest:"nyaste",note_appdaemon:"du behöver fortfarande lägga till den till filen 'apps.yaml'",note_installed:"När den är installerad kommer den finnas i",note_integration:"du behöver fortfarande lägga den till filen 'configuration.yaml'",note_plugin:"du behöver fortfarande lägga till den till din lovelace konfiguration ('ui-lovelace.yaml' eller raw UI config redigerare)",open_issue:"Rapportera problem",open_plugin:"Öppna plugin",reinstall:"Ominstallera",repository:"Repository",show_beta:"Visa betaversioner",uninstall:"Avinstallera",update_information:"Uppdatera information",upgrade:"Uppdatera"},No={add_custom_repository:"LÄGG TILL ETT REPOSITORY",category:"Kategori",compact_mode:"Kompakt läge",custom_repositories:"REPOSITORIES",delete:"Ta bort",display:"Visa",grid:"Rutnät",hacs_repo:"HACS repo",hidden_repositories:"dolda förråd",reload_data:"Ladda om data",save:"Spara",table:"Tabell",table_view:"Tabellvy",unhide:"ta fram",upgrade_all:"Uppgradera alla"},Io={clear_new:"Rensa alla nya förvar",name:"Namn",new_repositories:"Nya förvar",placeholder_search:"Skriv ett sökord...",sort:"sortera",status:"Status"},Po={common:Oo,config:Co,confirm:zo,options:To,repository_banner:$o,repository:Ro,settings:No,store:Io},Mo={appdaemon:"AppDaemon",appdaemon_apps:"AppDaemon应用",background_task:"后台任务正在运行，完成后将重新加载此页面。",installed:"已安装",integration:"自定义组件",integrations:"自定义组件",plugin:"Lovelace插件",plugins:"Lovelace插件",python_script:"Python脚本",python_scripts:"Python脚本",repositories:"仓库数量",settings:"设置",theme:"主题",themes:"主题",version:"版本"},Lo={abort:{single_instance_allowed:"仅允许单个HACS配置。"},error:{auth:"个人访问令牌不正确。"},step:{user:{data:{appdaemon:"启用AppDaemon应用发现和跟踪",python_script:"启用python_scripts发现和跟踪",sidepanel_icon:"侧面板图标",sidepanel_title:"侧面板标题",theme:"启用主题发现和跟踪",token:"GitHub个人访问令牌"},description:"如果您需要有关配置的帮助，请在此处查看：https://hacs.xyz/docs/configuration/start/",title:"HACS (Home Assistant Community Store)"}},title:"HACS (Home Assistant Community Store)"},Do={add_to_lovelace:"您确定要将此添加到Lovelace资源中吗？",bg_task:"后台任务正在运行时，操作被禁用。",cancel:"取消",continue:"你确定你要继续吗？",delete:'是否确实要删除"{item}"？',generic:"你确定吗？",no:"不",no_upgrades:"暂无升级",ok:"确定",overwrite:"这样做会覆盖它。",uninstall:"您确定要卸载“ {item} ”吗？",upgrade_all:"这将升级所有这些仓库，请确保在继续之前已阅读所有仓库的发行说明。",yes:"是"},Ho={step:{user:{data:{country:"用国家代码过滤。",debug:"启用调试。",experimental:"启用实验功能",release_limit:"要显示的发行数量。"}}}},Bo={integration_not_loaded:"此集成未加载到Home Assistant中。",not_loaded:"未加载",plugin_not_loaded:"该插件未添加到您的Lovelace资源中。",restart:"您需要重新启动Home Assistant。",restart_pending:"重新启动待处理"},Uo={add_to_lovelace:"添加到Lovelace",authors:"作者",available:"版本号",back_to:"返回",changelog:"更新日志",flag_this:"标记",hide:"隐藏",hide_beta:"隐藏测试版",install:"安装",installed:"已安装版本",lovelace_copy_example:"复制样例代码到你的剪贴板",lovelace_instruction:"您仍然需要将下列代码添加到lovelace配置中（“ ui-lovelace.yaml”或原始配置编辑器）:",lovelace_no_js_type:"无法确定此插件的类型，请检查仓库。",newest:"最新",note_appdaemon:"您仍然需要将其添加到“ apps.yaml”文件中",note_installed:"安装后，它将位于",note_integration:"您仍然需要将其添加到“ configuration.yaml”文件中",note_plugin:"您仍然需要将其添加到lovelace配置中（“ ui-lovelace.yaml”或原始配置编辑器）ui-lovelace.yaml",open_issue:"提交问题",open_plugin:"打开插件",reinstall:"重新安装",repository:"仓库",show_beta:"显示测试版",uninstall:"卸载",update_information:"更新信息",upgrade:"升级"},qo={add_custom_repository:"添加自定义仓库",category:"类别",compact_mode:"紧凑模式",custom_repositories:"自定义仓库",delete:"删除",display:"视图方式",grid:"网格",hacs_repo:"HACS仓库",hidden_repositories:"隐藏的仓库",reload_data:"重载数据",save:"保存",table:"列表",table_view:"表视图",unhide:"取消隐藏",upgrade_all:"升级全部"},Vo={clear_new:"清除所有新仓库标记",name:"名称",new_repositories:"新仓库",pending_upgrades:"待升级",placeholder_search:"搜索项目...",sort:"排序",status:"状态"},Fo={common:Mo,config:Lo,confirm:Do,options:Ho,repository_banner:Bo,repository:Uo,settings:qo,store:Vo},Go={de:Object.freeze({__proto__:null,common:fe,config:_e,confirm:be,options:ye,repository_banner:we,repository:ve,settings:ke,store:xe,default:Ae}),el:Object.freeze({__proto__:null,common:Se,config:je,confirm:Ee,options:Oe,repository:Ce,settings:ze,store:Te,default:$e}),en:Object.freeze({__proto__:null,common:Re,config:Ne,confirm:Ie,options:Pe,repository_banner:Me,repository:Le,settings:De,store:He,default:Be}),es:Object.freeze({__proto__:null,common:Ue,config:qe,confirm:Ve,options:Fe,repository:Ge,settings:We,store:Ye,default:Ze}),fr:Object.freeze({__proto__:null,common:Ke,config:Xe,confirm:Je,options:Qe,repository_banner:et,repository:tt,settings:ot,store:at,default:nt}),it:Object.freeze({__proto__:null,common:rt,config:it,options:st,repository:lt,settings:ct,store:dt,default:pt}),nb:Object.freeze({__proto__:null,common:ut,config:ht,confirm:gt,options:mt,repository_banner:ft,repository:_t,settings:bt,store:yt,default:wt}),nl:Object.freeze({__proto__:null,common:vt,config:kt,confirm:xt,options:At,repository_banner:St,repository:jt,settings:Et,store:Ot,default:Ct}),nn:Object.freeze({__proto__:null,common:zt,config:Tt,confirm:$t,options:Rt,repository_banner:Nt,repository:It,settings:Pt,store:Mt,default:Lt}),pl:Object.freeze({__proto__:null,common:Dt,config:Ht,confirm:Bt,options:Ut,repository_banner:qt,repository:Vt,settings:Ft,store:Gt,default:Wt}),pt_BR:Object.freeze({__proto__:null,common:Yt,config:Zt,options:Kt,repository:Xt,settings:Jt,store:Qt,default:eo}),ro:Object.freeze({__proto__:null,common:to,config:oo,confirm:ao,options:no,repository:ro,settings:io,store:so,default:lo}),ru:Object.freeze({__proto__:null,common:co,config:po,confirm:uo,options:ho,repository_banner:go,repository:mo,settings:fo,store:_o,default:bo}),sl:Object.freeze({__proto__:null,common:yo,config:wo,confirm:vo,options:ko,repository_banner:xo,repository:Ao,settings:So,store:jo,default:Eo}),sv:Object.freeze({__proto__:null,common:Oo,config:Co,confirm:zo,options:To,repository_banner:$o,repository:Ro,settings:No,store:Io,default:Po}),zh_Hans:Object.freeze({__proto__:null,common:Mo,config:Lo,confirm:Do,options:Ho,repository_banner:Bo,repository:Uo,settings:qo,store:Vo,default:Fo})};function Wo(e,t,o){const a=e.split(".")[0],n=e.split(".")[1],r=(localStorage.getItem("selectedLanguage")||"en").replace(/['"]+/g,"").replace("-","_");var i;try{i=Go[r][a][n]}catch(e){i=Go.en[a][n]}return void 0===i&&(i=Go.en[a][n]),void 0!==t&&void 0!==o&&(i=i.replace(t,o)),i}var Yo="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function Zo(e,t){return e(t={exports:{}},t.exports),t.exports}var Ko=9007199254740991,Xo="[object Arguments]",Jo="[object Function]",Qo="[object GeneratorFunction]",ea="[object Map]",ta="[object Set]",oa="[object String]",aa=/^\[object .+?Constructor\]$/,na=/^(?:0|[1-9]\d*)$/,ra="[\\ud800-\\udfff]",ia="[\\u0300-\\u036f\\ufe20-\\ufe23\\u20d0-\\u20f0]",sa="\\ud83c[\\udffb-\\udfff]",la="[^\\ud800-\\udfff]",ca="(?:\\ud83c[\\udde6-\\uddff]){2}",da="[\\ud800-\\udbff][\\udc00-\\udfff]",pa="(?:"+ia+"|"+sa+")"+"?",ua="[\\ufe0e\\ufe0f]?"+pa+("(?:\\u200d(?:"+[la,ca,da].join("|")+")[\\ufe0e\\ufe0f]?"+pa+")*"),ha="(?:"+[la+ia+"?",ia,ca,da,ra].join("|")+")",ga=RegExp(sa+"(?="+sa+")|"+ha+ua,"g"),ma=RegExp("[\\u200d\\ud800-\\udfff\\u0300-\\u036f\\ufe20-\\ufe23\\u20d0-\\u20f0\\ufe0e\\ufe0f]"),fa="object"==typeof Yo&&Yo&&Yo.Object===Object&&Yo,_a="object"==typeof self&&self&&self.Object===Object&&self,ba=fa||_a||Function("return this")();function ya(e,t){return function(e,t){for(var o=-1,a=e?e.length:0,n=Array(a);++o<a;)n[o]=t(e[o],o,e);return n}(t,(function(t){return e[t]}))}function wa(e){var t=-1,o=Array(e.size);return e.forEach((function(e,a){o[++t]=[a,e]})),o}function va(e){var t=-1,o=Array(e.size);return e.forEach((function(e){o[++t]=e})),o}function ka(e){return function(e){return ma.test(e)}(e)?function(e){return e.match(ga)||[]}(e):function(e){return e.split("")}(e)}var xa,Aa,Sa,ja=Function.prototype,Ea=Object.prototype,Oa=ba["__core-js_shared__"],Ca=(xa=/[^.]+$/.exec(Oa&&Oa.keys&&Oa.keys.IE_PROTO||""))?"Symbol(src)_1."+xa:"",za=ja.toString,Ta=Ea.hasOwnProperty,$a=Ea.toString,Ra=RegExp("^"+za.call(Ta).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),Na=ba.Symbol,Ia=Na?Na.iterator:void 0,Pa=Ea.propertyIsEnumerable,Ma=(Aa=Object.keys,Sa=Object,function(e){return Aa(Sa(e))}),La=Xa(ba,"DataView"),Da=Xa(ba,"Map"),Ha=Xa(ba,"Promise"),Ba=Xa(ba,"Set"),Ua=Xa(ba,"WeakMap"),qa=en(La),Va=en(Da),Fa=en(Ha),Ga=en(Ba),Wa=en(Ua);function Ya(e,t){var o=tn(e)||function(e){return function(e){return rn(e)&&on(e)}(e)&&Ta.call(e,"callee")&&(!Pa.call(e,"callee")||$a.call(e)==Xo)}(e)?function(e,t){for(var o=-1,a=Array(e);++o<e;)a[o]=t(o);return a}(e.length,String):[],a=o.length,n=!!a;for(var r in e)!t&&!Ta.call(e,r)||n&&("length"==r||Qa(r,a))||o.push(r);return o}function Za(e){return!(!nn(e)||function(e){return!!Ca&&Ca in e}(e))&&(an(e)||function(e){var t=!1;if(null!=e&&"function"!=typeof e.toString)try{t=!!(e+"")}catch(e){}return t}(e)?Ra:aa).test(en(e))}function Ka(e){if(o=(t=e)&&t.constructor,a="function"==typeof o&&o.prototype||Ea,t!==a)return Ma(e);var t,o,a,n=[];for(var r in Object(e))Ta.call(e,r)&&"constructor"!=r&&n.push(r);return n}function Xa(e,t){var o=function(e,t){return null==e?void 0:e[t]}(e,t);return Za(o)?o:void 0}var Ja=function(e){return $a.call(e)};function Qa(e,t){return!!(t=null==t?Ko:t)&&("number"==typeof e||na.test(e))&&e>-1&&e%1==0&&e<t}function en(e){if(null!=e){try{return za.call(e)}catch(e){}try{return e+""}catch(e){}}return""}(La&&"[object DataView]"!=Ja(new La(new ArrayBuffer(1)))||Da&&Ja(new Da)!=ea||Ha&&"[object Promise]"!=Ja(Ha.resolve())||Ba&&Ja(new Ba)!=ta||Ua&&"[object WeakMap]"!=Ja(new Ua))&&(Ja=function(e){var t=$a.call(e),o="[object Object]"==t?e.constructor:void 0,a=o?en(o):void 0;if(a)switch(a){case qa:return"[object DataView]";case Va:return ea;case Fa:return"[object Promise]";case Ga:return ta;case Wa:return"[object WeakMap]"}return t});var tn=Array.isArray;function on(e){return null!=e&&function(e){return"number"==typeof e&&e>-1&&e%1==0&&e<=Ko}(e.length)&&!an(e)}function an(e){var t=nn(e)?$a.call(e):"";return t==Jo||t==Qo}function nn(e){var t=typeof e;return!!e&&("object"==t||"function"==t)}function rn(e){return!!e&&"object"==typeof e}function sn(e){return e?ya(e,function(e){return on(e)?Ya(e):Ka(e)}(e)):[]}var ln,cn=function(e){if(!e)return[];if(on(e))return function(e){return"string"==typeof e||!tn(e)&&rn(e)&&$a.call(e)==oa}(e)?ka(e):function(e,t){var o=-1,a=e.length;for(t||(t=Array(a));++o<a;)t[o]=e[o];return t}(e);if(Ia&&e[Ia])return function(e){for(var t,o=[];!(t=e.next()).done;)o.push(t.value);return o}(e[Ia]());var t=Ja(e);return(t==ea?wa:t==ta?va:sn)(e)},dn={100:"💯",1234:"🔢",umbrella_with_rain_drops:"☔",coffee:"☕",aries:"♈",taurus:"♉",sagittarius:"♐",capricorn:"♑",aquarius:"♒",pisces:"♓",anchor:"⚓",white_check_mark:"✅",sparkles:"✨",question:"❓",grey_question:"❔",grey_exclamation:"❕",exclamation:"❗",heavy_exclamation_mark:"❗",heavy_plus_sign:"➕",heavy_minus_sign:"➖",heavy_division_sign:"➗",hash:"#️⃣",keycap_star:"*️⃣",zero:"0️⃣",one:"1️⃣",two:"2️⃣",three:"3️⃣",four:"4️⃣",five:"5️⃣",six:"6️⃣",seven:"7️⃣",eight:"8️⃣",nine:"9️⃣",copyright:"©️",registered:"®️",mahjong:"🀄",black_joker:"🃏",a:"🅰️",b:"🅱️",o2:"🅾️",parking:"🅿️",ab:"🆎",cl:"🆑",cool:"🆒",free:"🆓",id:"🆔",new:"🆕",ng:"🆖",ok:"🆗",sos:"🆘",up:"🆙",vs:"🆚","flag-ac":"🇦🇨","flag-ad":"🇦🇩","flag-ae":"🇦🇪","flag-af":"🇦🇫","flag-ag":"🇦🇬","flag-ai":"🇦🇮","flag-al":"🇦🇱","flag-am":"🇦🇲","flag-ao":"🇦🇴","flag-aq":"🇦🇶","flag-ar":"🇦🇷","flag-as":"🇦🇸","flag-at":"🇦🇹","flag-au":"🇦🇺","flag-aw":"🇦🇼","flag-ax":"🇦🇽","flag-az":"🇦🇿","flag-ba":"🇧🇦","flag-bb":"🇧🇧","flag-bd":"🇧🇩","flag-be":"🇧🇪","flag-bf":"🇧🇫","flag-bg":"🇧🇬","flag-bh":"🇧🇭","flag-bi":"🇧🇮","flag-bj":"🇧🇯","flag-bl":"🇧🇱","flag-bm":"🇧🇲","flag-bn":"🇧🇳","flag-bo":"🇧🇴","flag-bq":"🇧🇶","flag-br":"🇧🇷","flag-bs":"🇧🇸","flag-bt":"🇧🇹","flag-bv":"🇧🇻","flag-bw":"🇧🇼","flag-by":"🇧🇾","flag-bz":"🇧🇿","flag-ca":"🇨🇦","flag-cc":"🇨🇨","flag-cd":"🇨🇩","flag-cf":"🇨🇫","flag-cg":"🇨🇬","flag-ch":"🇨🇭","flag-ci":"🇨🇮","flag-ck":"🇨🇰","flag-cl":"🇨🇱","flag-cm":"🇨🇲",cn:"🇨🇳","flag-cn":"🇨🇳","flag-co":"🇨🇴","flag-cp":"🇨🇵","flag-cr":"🇨🇷","flag-cu":"🇨🇺","flag-cv":"🇨🇻","flag-cw":"🇨🇼","flag-cx":"🇨🇽","flag-cy":"🇨🇾","flag-cz":"🇨🇿",de:"🇩🇪","flag-de":"🇩🇪","flag-dg":"🇩🇬","flag-dj":"🇩🇯","flag-dk":"🇩🇰","flag-dm":"🇩🇲","flag-do":"🇩🇴","flag-dz":"🇩🇿","flag-ea":"🇪🇦","flag-ec":"🇪🇨","flag-ee":"🇪🇪","flag-eg":"🇪🇬","flag-eh":"🇪🇭","flag-er":"🇪🇷",es:"🇪🇸","flag-es":"🇪🇸","flag-et":"🇪🇹","flag-eu":"🇪🇺","flag-fi":"🇫🇮","flag-fj":"🇫🇯","flag-fk":"🇫🇰","flag-fm":"🇫🇲","flag-fo":"🇫🇴",fr:"🇫🇷","flag-fr":"🇫🇷","flag-ga":"🇬🇦",gb:"🇬🇧",uk:"🇬🇧","flag-gb":"🇬🇧","flag-gd":"🇬🇩","flag-ge":"🇬🇪","flag-gf":"🇬🇫","flag-gg":"🇬🇬","flag-gh":"🇬🇭","flag-gi":"🇬🇮","flag-gl":"🇬🇱","flag-gm":"🇬🇲","flag-gn":"🇬🇳","flag-gp":"🇬🇵","flag-gq":"🇬🇶","flag-gr":"🇬🇷","flag-gs":"🇬🇸","flag-gt":"🇬🇹","flag-gu":"🇬🇺","flag-gw":"🇬🇼","flag-gy":"🇬🇾","flag-hk":"🇭🇰","flag-hm":"🇭🇲","flag-hn":"🇭🇳","flag-hr":"🇭🇷","flag-ht":"🇭🇹","flag-hu":"🇭🇺","flag-ic":"🇮🇨","flag-id":"🇮🇩","flag-ie":"🇮🇪","flag-il":"🇮🇱","flag-im":"🇮🇲","flag-in":"🇮🇳","flag-io":"🇮🇴","flag-iq":"🇮🇶","flag-ir":"🇮🇷","flag-is":"🇮🇸",it:"🇮🇹","flag-it":"🇮🇹","flag-je":"🇯🇪","flag-jm":"🇯🇲","flag-jo":"🇯🇴",jp:"🇯🇵","flag-jp":"🇯🇵","flag-ke":"🇰🇪","flag-kg":"🇰🇬","flag-kh":"🇰🇭","flag-ki":"🇰🇮","flag-km":"🇰🇲","flag-kn":"🇰🇳","flag-kp":"🇰🇵",kr:"🇰🇷","flag-kr":"🇰🇷","flag-kw":"🇰🇼","flag-ky":"🇰🇾","flag-kz":"🇰🇿","flag-la":"🇱🇦","flag-lb":"🇱🇧","flag-lc":"🇱🇨","flag-li":"🇱🇮","flag-lk":"🇱🇰","flag-lr":"🇱🇷","flag-ls":"🇱🇸","flag-lt":"🇱🇹","flag-lu":"🇱🇺","flag-lv":"🇱🇻","flag-ly":"🇱🇾","flag-ma":"🇲🇦","flag-mc":"🇲🇨","flag-md":"🇲🇩","flag-me":"🇲🇪","flag-mf":"🇲🇫","flag-mg":"🇲🇬","flag-mh":"🇲🇭","flag-mk":"🇲🇰","flag-ml":"🇲🇱","flag-mm":"🇲🇲","flag-mn":"🇲🇳","flag-mo":"🇲🇴","flag-mp":"🇲🇵","flag-mq":"🇲🇶","flag-mr":"🇲🇷","flag-ms":"🇲🇸","flag-mt":"🇲🇹","flag-mu":"🇲🇺","flag-mv":"🇲🇻","flag-mw":"🇲🇼","flag-mx":"🇲🇽","flag-my":"🇲🇾","flag-mz":"🇲🇿","flag-na":"🇳🇦","flag-nc":"🇳🇨","flag-ne":"🇳🇪","flag-nf":"🇳🇫","flag-ng":"🇳🇬","flag-ni":"🇳🇮","flag-nl":"🇳🇱","flag-no":"🇳🇴","flag-np":"🇳🇵","flag-nr":"🇳🇷","flag-nu":"🇳🇺","flag-nz":"🇳🇿","flag-om":"🇴🇲","flag-pa":"🇵🇦","flag-pe":"🇵🇪","flag-pf":"🇵🇫","flag-pg":"🇵🇬","flag-ph":"🇵🇭","flag-pk":"🇵🇰","flag-pl":"🇵🇱","flag-pm":"🇵🇲","flag-pn":"🇵🇳","flag-pr":"🇵🇷","flag-ps":"🇵🇸","flag-pt":"🇵🇹","flag-pw":"🇵🇼","flag-py":"🇵🇾","flag-qa":"🇶🇦","flag-re":"🇷🇪","flag-ro":"🇷🇴","flag-rs":"🇷🇸",ru:"🇷🇺","flag-ru":"🇷🇺","flag-rw":"🇷🇼","flag-sa":"🇸🇦","flag-sb":"🇸🇧","flag-sc":"🇸🇨","flag-sd":"🇸🇩","flag-se":"🇸🇪","flag-sg":"🇸🇬","flag-sh":"🇸🇭","flag-si":"🇸🇮","flag-sj":"🇸🇯","flag-sk":"🇸🇰","flag-sl":"🇸🇱","flag-sm":"🇸🇲","flag-sn":"🇸🇳","flag-so":"🇸🇴","flag-sr":"🇸🇷","flag-ss":"🇸🇸","flag-st":"🇸🇹","flag-sv":"🇸🇻","flag-sx":"🇸🇽","flag-sy":"🇸🇾","flag-sz":"🇸🇿","flag-ta":"🇹🇦","flag-tc":"🇹🇨","flag-td":"🇹🇩","flag-tf":"🇹🇫","flag-tg":"🇹🇬","flag-th":"🇹🇭","flag-tj":"🇹🇯","flag-tk":"🇹🇰","flag-tl":"🇹🇱","flag-tm":"🇹🇲","flag-tn":"🇹🇳","flag-to":"🇹🇴","flag-tr":"🇹🇷","flag-tt":"🇹🇹","flag-tv":"🇹🇻","flag-tw":"🇹🇼","flag-tz":"🇹🇿","flag-ua":"🇺🇦","flag-ug":"🇺🇬","flag-um":"🇺🇲","flag-un":"🇺🇳",us:"🇺🇸","flag-us":"🇺🇸","flag-uy":"🇺🇾","flag-uz":"🇺🇿","flag-va":"🇻🇦","flag-vc":"🇻🇨","flag-ve":"🇻🇪","flag-vg":"🇻🇬","flag-vi":"🇻🇮","flag-vn":"🇻🇳","flag-vu":"🇻🇺","flag-wf":"🇼🇫","flag-ws":"🇼🇸","flag-xk":"🇽🇰","flag-ye":"🇾🇪","flag-yt":"🇾🇹","flag-za":"🇿🇦","flag-zm":"🇿🇲","flag-zw":"🇿🇼",koko:"🈁",sa:"🈂️",u7121:"🈚",u6307:"🈯",u7981:"🈲",u7a7a:"🈳",u5408:"🈴",u6e80:"🈵",u6709:"🈶",u6708:"🈷️",u7533:"🈸",u5272:"🈹",u55b6:"🈺",ideograph_advantage:"🉐",accept:"🉑",cyclone:"🌀",foggy:"🌁",closed_umbrella:"🌂",night_with_stars:"🌃",sunrise_over_mountains:"🌄",sunrise:"🌅",city_sunset:"🌆",city_sunrise:"🌇",rainbow:"🌈",bridge_at_night:"🌉",ocean:"🌊",volcano:"🌋",milky_way:"🌌",earth_africa:"🌍",earth_americas:"🌎",earth_asia:"🌏",globe_with_meridians:"🌐",new_moon:"🌑",waxing_crescent_moon:"🌒",first_quarter_moon:"🌓",moon:"🌔",waxing_gibbous_moon:"🌔",full_moon:"🌕",waning_gibbous_moon:"🌖",last_quarter_moon:"🌗",waning_crescent_moon:"🌘",crescent_moon:"🌙",new_moon_with_face:"🌚",first_quarter_moon_with_face:"🌛",last_quarter_moon_with_face:"🌜",full_moon_with_face:"🌝",sun_with_face:"🌞",star2:"🌟",stars:"🌠",thermometer:"🌡️",mostly_sunny:"🌤️",sun_small_cloud:"🌤️",barely_sunny:"🌥️",sun_behind_cloud:"🌥️",partly_sunny_rain:"🌦️",sun_behind_rain_cloud:"🌦️",rain_cloud:"🌧️",snow_cloud:"🌨️",lightning:"🌩️",lightning_cloud:"🌩️",tornado:"🌪️",tornado_cloud:"🌪️",fog:"🌫️",wind_blowing_face:"🌬️",hotdog:"🌭",taco:"🌮",burrito:"🌯",chestnut:"🌰",seedling:"🌱",evergreen_tree:"🌲",deciduous_tree:"🌳",palm_tree:"🌴",cactus:"🌵",hot_pepper:"🌶️",tulip:"🌷",cherry_blossom:"🌸",rose:"🌹",hibiscus:"🌺",sunflower:"🌻",blossom:"🌼",corn:"🌽",ear_of_rice:"🌾",herb:"🌿",four_leaf_clover:"🍀",maple_leaf:"🍁",fallen_leaf:"🍂",leaves:"🍃",mushroom:"🍄",tomato:"🍅",eggplant:"🍆",grapes:"🍇",melon:"🍈",watermelon:"🍉",tangerine:"🍊",lemon:"🍋",banana:"🍌",pineapple:"🍍",apple:"🍎",green_apple:"🍏",pear:"🍐",peach:"🍑",cherries:"🍒",strawberry:"🍓",hamburger:"🍔",pizza:"🍕",meat_on_bone:"🍖",poultry_leg:"🍗",rice_cracker:"🍘",rice_ball:"🍙",rice:"🍚",curry:"🍛",ramen:"🍜",spaghetti:"🍝",bread:"🍞",fries:"🍟",sweet_potato:"🍠",dango:"🍡",oden:"🍢",sushi:"🍣",fried_shrimp:"🍤",fish_cake:"🍥",icecream:"🍦",shaved_ice:"🍧",ice_cream:"🍨",doughnut:"🍩",cookie:"🍪",chocolate_bar:"🍫",candy:"🍬",lollipop:"🍭",custard:"🍮",honey_pot:"🍯",cake:"🍰",bento:"🍱",stew:"🍲",fried_egg:"🍳",cooking:"🍳",fork_and_knife:"🍴",tea:"🍵",sake:"🍶",wine_glass:"🍷",cocktail:"🍸",tropical_drink:"🍹",beer:"🍺",beers:"🍻",baby_bottle:"🍼",knife_fork_plate:"🍽️",champagne:"🍾",popcorn:"🍿",ribbon:"🎀",gift:"🎁",birthday:"🎂",jack_o_lantern:"🎃",christmas_tree:"🎄",santa:"🎅",fireworks:"🎆",sparkler:"🎇",balloon:"🎈",tada:"🎉",confetti_ball:"🎊",tanabata_tree:"🎋",crossed_flags:"🎌",bamboo:"🎍",dolls:"🎎",flags:"🎏",wind_chime:"🎐",rice_scene:"🎑",school_satchel:"🎒",mortar_board:"🎓",medal:"🎖️",reminder_ribbon:"🎗️",studio_microphone:"🎙️",level_slider:"🎚️",control_knobs:"🎛️",film_frames:"🎞️",admission_tickets:"🎟️",carousel_horse:"🎠",ferris_wheel:"🎡",roller_coaster:"🎢",fishing_pole_and_fish:"🎣",microphone:"🎤",movie_camera:"🎥",cinema:"🎦",headphones:"🎧",art:"🎨",tophat:"🎩",circus_tent:"🎪",ticket:"🎫",clapper:"🎬",performing_arts:"🎭",video_game:"🎮",dart:"🎯",slot_machine:"🎰","8ball":"🎱",game_die:"🎲",bowling:"🎳",flower_playing_cards:"🎴",musical_note:"🎵",notes:"🎶",saxophone:"🎷",guitar:"🎸",musical_keyboard:"🎹",trumpet:"🎺",violin:"🎻",musical_score:"🎼",running_shirt_with_sash:"🎽",tennis:"🎾",ski:"🎿",basketball:"🏀",checkered_flag:"🏁",snowboarder:"🏂","woman-running":"🏃‍♀️","man-running":"🏃‍♂️",runner:"🏃‍♂️",running:"🏃‍♂️","woman-surfing":"🏄‍♀️","man-surfing":"🏄‍♂️",surfer:"🏄‍♂️",sports_medal:"🏅",trophy:"🏆",horse_racing:"🏇",football:"🏈",rugby_football:"🏉","woman-swimming":"🏊‍♀️","man-swimming":"🏊‍♂️",swimmer:"🏊‍♂️","woman-lifting-weights":"🏋️‍♀️","man-lifting-weights":"🏋️‍♂️",weight_lifter:"🏋️‍♂️","woman-golfing":"🏌️‍♀️","man-golfing":"🏌️‍♂️",golfer:"🏌️‍♂️",racing_motorcycle:"🏍️",racing_car:"🏎️",cricket_bat_and_ball:"🏏",volleyball:"🏐",field_hockey_stick_and_ball:"🏑",ice_hockey_stick_and_puck:"🏒",table_tennis_paddle_and_ball:"🏓",snow_capped_mountain:"🏔️",camping:"🏕️",beach_with_umbrella:"🏖️",building_construction:"🏗️",house_buildings:"🏘️",cityscape:"🏙️",derelict_house_building:"🏚️",classical_building:"🏛️",desert:"🏜️",desert_island:"🏝️",national_park:"🏞️",stadium:"🏟️",house:"🏠",house_with_garden:"🏡",office:"🏢",post_office:"🏣",european_post_office:"🏤",hospital:"🏥",bank:"🏦",atm:"🏧",hotel:"🏨",love_hotel:"🏩",convenience_store:"🏪",school:"🏫",department_store:"🏬",factory:"🏭",izakaya_lantern:"🏮",lantern:"🏮",japanese_castle:"🏯",european_castle:"🏰","rainbow-flag":"🏳️‍🌈",waving_white_flag:"🏳️","flag-england":"🏴󠁧󠁢󠁥󠁮󠁧󠁿","flag-scotland":"🏴󠁧󠁢󠁳󠁣󠁴󠁿","flag-wales":"🏴󠁧󠁢󠁷󠁬󠁳󠁿",waving_black_flag:"🏴",rosette:"🏵️",label:"🏷️",badminton_racquet_and_shuttlecock:"🏸",bow_and_arrow:"🏹",amphora:"🏺","skin-tone-2":"🏻","skin-tone-3":"🏼","skin-tone-4":"🏽","skin-tone-5":"🏾","skin-tone-6":"🏿",rat:"🐀",mouse2:"🐁",ox:"🐂",water_buffalo:"🐃",cow2:"🐄",tiger2:"🐅",leopard:"🐆",rabbit2:"🐇",cat2:"🐈",dragon:"🐉",crocodile:"🐊",whale2:"🐋",snail:"🐌",snake:"🐍",racehorse:"🐎",ram:"🐏",goat:"🐐",sheep:"🐑",monkey:"🐒",rooster:"🐓",chicken:"🐔",dog2:"🐕",pig2:"🐖",boar:"🐗",elephant:"🐘",octopus:"🐙",shell:"🐚",bug:"🐛",ant:"🐜",bee:"🐝",honeybee:"🐝",beetle:"🐞",fish:"🐟",tropical_fish:"🐠",blowfish:"🐡",turtle:"🐢",hatching_chick:"🐣",baby_chick:"🐤",hatched_chick:"🐥",bird:"🐦",penguin:"🐧",koala:"🐨",poodle:"🐩",dromedary_camel:"🐪",camel:"🐫",dolphin:"🐬",flipper:"🐬",mouse:"🐭",cow:"🐮",tiger:"🐯",rabbit:"🐰",cat:"🐱",dragon_face:"🐲",whale:"🐳",horse:"🐴",monkey_face:"🐵",dog:"🐶",pig:"🐷",frog:"🐸",hamster:"🐹",wolf:"🐺",bear:"🐻",panda_face:"🐼",pig_nose:"🐽",feet:"🐾",paw_prints:"🐾",chipmunk:"🐿️",eyes:"👀","eye-in-speech-bubble":"👁️‍🗨️",eye:"👁️",ear:"👂",nose:"👃",lips:"👄",tongue:"👅",point_up_2:"👆",point_down:"👇",point_left:"👈",point_right:"👉",facepunch:"👊",punch:"👊",wave:"👋",ok_hand:"👌","+1":"👍",thumbsup:"👍","-1":"👎",thumbsdown:"👎",clap:"👏",open_hands:"👐",crown:"👑",womans_hat:"👒",eyeglasses:"👓",necktie:"👔",shirt:"👕",tshirt:"👕",jeans:"👖",dress:"👗",kimono:"👘",bikini:"👙",womans_clothes:"👚",purse:"👛",handbag:"👜",pouch:"👝",mans_shoe:"👞",shoe:"👞",athletic_shoe:"👟",high_heel:"👠",sandal:"👡",boot:"👢",footprints:"👣",bust_in_silhouette:"👤",busts_in_silhouette:"👥",boy:"👦",girl:"👧","male-farmer":"👨‍🌾","male-cook":"👨‍🍳","male-student":"👨‍🎓","male-singer":"👨‍🎤","male-artist":"👨‍🎨","male-teacher":"👨‍🏫","male-factory-worker":"👨‍🏭","man-boy-boy":"👨‍👦‍👦","man-boy":"👨‍👦","man-girl-boy":"👨‍👧‍👦","man-girl-girl":"👨‍👧‍👧","man-girl":"👨‍👧","man-man-boy":"👨‍👨‍👦","man-man-boy-boy":"👨‍👨‍👦‍👦","man-man-girl":"👨‍👨‍👧","man-man-girl-boy":"👨‍👨‍👧‍👦","man-man-girl-girl":"👨‍👨‍👧‍👧","man-woman-boy":"👨‍👩‍👦",family:"👨‍👩‍👦","man-woman-boy-boy":"👨‍👩‍👦‍👦","man-woman-girl":"👨‍👩‍👧","man-woman-girl-boy":"👨‍👩‍👧‍👦","man-woman-girl-girl":"👨‍👩‍👧‍👧","male-technologist":"👨‍💻","male-office-worker":"👨‍💼","male-mechanic":"👨‍🔧","male-scientist":"👨‍🔬","male-astronaut":"👨‍🚀","male-firefighter":"👨‍🚒","male-doctor":"👨‍⚕️","male-judge":"👨‍⚖️","male-pilot":"👨‍✈️","man-heart-man":"👨‍❤️‍👨","man-kiss-man":"👨‍❤️‍💋‍👨",man:"👨","female-farmer":"👩‍🌾","female-cook":"👩‍🍳","female-student":"👩‍🎓","female-singer":"👩‍🎤","female-artist":"👩‍🎨","female-teacher":"👩‍🏫","female-factory-worker":"👩‍🏭","woman-boy-boy":"👩‍👦‍👦","woman-boy":"👩‍👦","woman-girl-boy":"👩‍👧‍👦","woman-girl-girl":"👩‍👧‍👧","woman-girl":"👩‍👧","woman-woman-boy":"👩‍👩‍👦","woman-woman-boy-boy":"👩‍👩‍👦‍👦","woman-woman-girl":"👩‍👩‍👧","woman-woman-girl-boy":"👩‍👩‍👧‍👦","woman-woman-girl-girl":"👩‍👩‍👧‍👧","female-technologist":"👩‍💻","female-office-worker":"👩‍💼","female-mechanic":"👩‍🔧","female-scientist":"👩‍🔬","female-astronaut":"👩‍🚀","female-firefighter":"👩‍🚒","female-doctor":"👩‍⚕️","female-judge":"👩‍⚖️","female-pilot":"👩‍✈️","woman-heart-man":"👩‍❤️‍👨",couple_with_heart:"👩‍❤️‍👨","woman-heart-woman":"👩‍❤️‍👩","woman-kiss-man":"👩‍❤️‍💋‍👨",couplekiss:"👩‍❤️‍💋‍👨","woman-kiss-woman":"👩‍❤️‍💋‍👩",woman:"👩",couple:"👫",man_and_woman_holding_hands:"👫",two_men_holding_hands:"👬",two_women_holding_hands:"👭","female-police-officer":"👮‍♀️","male-police-officer":"👮‍♂️",cop:"👮‍♂️","woman-with-bunny-ears-partying":"👯‍♀️",dancers:"👯‍♀️","man-with-bunny-ears-partying":"👯‍♂️",bride_with_veil:"👰","blond-haired-woman":"👱‍♀️","blond-haired-man":"👱‍♂️",person_with_blond_hair:"👱‍♂️",man_with_gua_pi_mao:"👲","woman-wearing-turban":"👳‍♀️","man-wearing-turban":"👳‍♂️",man_with_turban:"👳‍♂️",older_man:"👴",older_woman:"👵",baby:"👶","female-construction-worker":"👷‍♀️","male-construction-worker":"👷‍♂️",construction_worker:"👷‍♂️",princess:"👸",japanese_ogre:"👹",japanese_goblin:"👺",ghost:"👻",angel:"👼",alien:"👽",space_invader:"👾",imp:"👿",skull:"💀","woman-tipping-hand":"💁‍♀️",information_desk_person:"💁‍♀️","man-tipping-hand":"💁‍♂️","female-guard":"💂‍♀️","male-guard":"💂‍♂️",guardsman:"💂‍♂️",dancer:"💃",lipstick:"💄",nail_care:"💅","woman-getting-massage":"💆‍♀️",massage:"💆‍♀️","man-getting-massage":"💆‍♂️","woman-getting-haircut":"💇‍♀️",haircut:"💇‍♀️","man-getting-haircut":"💇‍♂️",barber:"💈",syringe:"💉",pill:"💊",kiss:"💋",love_letter:"💌",ring:"💍",gem:"💎",bouquet:"💐",wedding:"💒",heartbeat:"💓",broken_heart:"💔",two_hearts:"💕",sparkling_heart:"💖",heartpulse:"💗",cupid:"💘",blue_heart:"💙",green_heart:"💚",yellow_heart:"💛",purple_heart:"💜",gift_heart:"💝",revolving_hearts:"💞",heart_decoration:"💟",diamond_shape_with_a_dot_inside:"💠",bulb:"💡",anger:"💢",bomb:"💣",zzz:"💤",boom:"💥",collision:"💥",sweat_drops:"💦",droplet:"💧",dash:"💨",hankey:"💩",poop:"💩",shit:"💩",muscle:"💪",dizzy:"💫",speech_balloon:"💬",thought_balloon:"💭",white_flower:"💮",moneybag:"💰",currency_exchange:"💱",heavy_dollar_sign:"💲",credit_card:"💳",yen:"💴",dollar:"💵",euro:"💶",pound:"💷",money_with_wings:"💸",chart:"💹",seat:"💺",computer:"💻",briefcase:"💼",minidisc:"💽",floppy_disk:"💾",cd:"💿",dvd:"📀",file_folder:"📁",open_file_folder:"📂",page_with_curl:"📃",page_facing_up:"📄",date:"📅",calendar:"📆",card_index:"📇",chart_with_upwards_trend:"📈",chart_with_downwards_trend:"📉",bar_chart:"📊",clipboard:"📋",pushpin:"📌",round_pushpin:"📍",paperclip:"📎",straight_ruler:"📏",triangular_ruler:"📐",bookmark_tabs:"📑",ledger:"📒",notebook:"📓",notebook_with_decorative_cover:"📔",closed_book:"📕",book:"📖",open_book:"📖",green_book:"📗",blue_book:"📘",orange_book:"📙",books:"📚",name_badge:"📛",scroll:"📜",memo:"📝",pencil:"📝",telephone_receiver:"📞",pager:"📟",fax:"📠",satellite_antenna:"📡",loudspeaker:"📢",mega:"📣",outbox_tray:"📤",inbox_tray:"📥",package:"📦","e-mail":"📧",incoming_envelope:"📨",envelope_with_arrow:"📩",mailbox_closed:"📪",mailbox:"📫",mailbox_with_mail:"📬",mailbox_with_no_mail:"📭",postbox:"📮",postal_horn:"📯",newspaper:"📰",iphone:"📱",calling:"📲",vibration_mode:"📳",mobile_phone_off:"📴",no_mobile_phones:"📵",signal_strength:"📶",camera:"📷",camera_with_flash:"📸",video_camera:"📹",tv:"📺",radio:"📻",vhs:"📼",film_projector:"📽️",prayer_beads:"📿",twisted_rightwards_arrows:"🔀",repeat:"🔁",repeat_one:"🔂",arrows_clockwise:"🔃",arrows_counterclockwise:"🔄",low_brightness:"🔅",high_brightness:"🔆",mute:"🔇",speaker:"🔈",sound:"🔉",loud_sound:"🔊",battery:"🔋",electric_plug:"🔌",mag:"🔍",mag_right:"🔎",lock_with_ink_pen:"🔏",closed_lock_with_key:"🔐",key:"🔑",lock:"🔒",unlock:"🔓",bell:"🔔",no_bell:"🔕",bookmark:"🔖",link:"🔗",radio_button:"🔘",back:"🔙",end:"🔚",on:"🔛",soon:"🔜",top:"🔝",underage:"🔞",keycap_ten:"🔟",capital_abcd:"🔠",abcd:"🔡",symbols:"🔣",abc:"🔤",fire:"🔥",flashlight:"🔦",wrench:"🔧",hammer:"🔨",nut_and_bolt:"🔩",hocho:"🔪",knife:"🔪",gun:"🔫",microscope:"🔬",telescope:"🔭",crystal_ball:"🔮",six_pointed_star:"🔯",beginner:"🔰",trident:"🔱",black_square_button:"🔲",white_square_button:"🔳",red_circle:"🔴",large_blue_circle:"🔵",large_orange_diamond:"🔶",large_blue_diamond:"🔷",small_orange_diamond:"🔸",small_blue_diamond:"🔹",small_red_triangle:"🔺",small_red_triangle_down:"🔻",arrow_up_small:"🔼",arrow_down_small:"🔽",om_symbol:"🕉️",dove_of_peace:"🕊️",kaaba:"🕋",mosque:"🕌",synagogue:"🕍",menorah_with_nine_branches:"🕎",clock1:"🕐",clock2:"🕑",clock3:"🕒",clock4:"🕓",clock5:"🕔",clock6:"🕕",clock7:"🕖",clock8:"🕗",clock9:"🕘",clock10:"🕙",clock11:"🕚",clock12:"🕛",clock130:"🕜",clock230:"🕝",clock330:"🕞",clock430:"🕟",clock530:"🕠",clock630:"🕡",clock730:"🕢",clock830:"🕣",clock930:"🕤",clock1030:"🕥",clock1130:"🕦",clock1230:"🕧",candle:"🕯️",mantelpiece_clock:"🕰️",hole:"🕳️",man_in_business_suit_levitating:"🕴️","female-detective":"🕵️‍♀️","male-detective":"🕵️‍♂️",sleuth_or_spy:"🕵️‍♂️",dark_sunglasses:"🕶️",spider:"🕷️",spider_web:"🕸️",joystick:"🕹️",man_dancing:"🕺",linked_paperclips:"🖇️",lower_left_ballpoint_pen:"🖊️",lower_left_fountain_pen:"🖋️",lower_left_paintbrush:"🖌️",lower_left_crayon:"🖍️",raised_hand_with_fingers_splayed:"🖐️",middle_finger:"🖕",reversed_hand_with_middle_finger_extended:"🖕","spock-hand":"🖖",black_heart:"🖤",desktop_computer:"🖥️",printer:"🖨️",three_button_mouse:"🖱️",trackball:"🖲️",frame_with_picture:"🖼️",card_index_dividers:"🗂️",card_file_box:"🗃️",file_cabinet:"🗄️",wastebasket:"🗑️",spiral_note_pad:"🗒️",spiral_calendar_pad:"🗓️",compression:"🗜️",old_key:"🗝️",rolled_up_newspaper:"🗞️",dagger_knife:"🗡️",speaking_head_in_silhouette:"🗣️",left_speech_bubble:"🗨️",right_anger_bubble:"🗯️",ballot_box_with_ballot:"🗳️",world_map:"🗺️",mount_fuji:"🗻",tokyo_tower:"🗼",statue_of_liberty:"🗽",japan:"🗾",moyai:"🗿",grinning:"😀",grin:"😁",joy:"😂",smiley:"😃",smile:"😄",sweat_smile:"😅",laughing:"😆",satisfied:"😆",innocent:"😇",smiling_imp:"😈",wink:"😉",blush:"😊",yum:"😋",relieved:"😌",heart_eyes:"😍",sunglasses:"😎",smirk:"😏",neutral_face:"😐",expressionless:"😑",unamused:"😒",sweat:"😓",pensive:"😔",confused:"😕",confounded:"😖",kissing:"😗",kissing_heart:"😘",kissing_smiling_eyes:"😙",kissing_closed_eyes:"😚",stuck_out_tongue:"😛",stuck_out_tongue_winking_eye:"😜",stuck_out_tongue_closed_eyes:"😝",disappointed:"😞",worried:"😟",angry:"😠",rage:"😡",cry:"😢",persevere:"😣",triumph:"😤",disappointed_relieved:"😥",frowning:"😦",anguished:"😧",fearful:"😨",weary:"😩",sleepy:"😪",tired_face:"😫",grimacing:"😬",sob:"😭",open_mouth:"😮",hushed:"😯",cold_sweat:"😰",scream:"😱",astonished:"😲",flushed:"😳",sleeping:"😴",dizzy_face:"😵",no_mouth:"😶",mask:"😷",smile_cat:"😸",joy_cat:"😹",smiley_cat:"😺",heart_eyes_cat:"😻",smirk_cat:"😼",kissing_cat:"😽",pouting_cat:"😾",crying_cat_face:"😿",scream_cat:"🙀",slightly_frowning_face:"🙁",slightly_smiling_face:"🙂",upside_down_face:"🙃",face_with_rolling_eyes:"🙄","woman-gesturing-no":"🙅‍♀️",no_good:"🙅‍♀️","man-gesturing-no":"🙅‍♂️","woman-gesturing-ok":"🙆‍♀️",ok_woman:"🙆‍♀️","man-gesturing-ok":"🙆‍♂️","woman-bowing":"🙇‍♀️","man-bowing":"🙇‍♂️",bow:"🙇‍♂️",see_no_evil:"🙈",hear_no_evil:"🙉",speak_no_evil:"🙊","woman-raising-hand":"🙋‍♀️",raising_hand:"🙋‍♀️","man-raising-hand":"🙋‍♂️",raised_hands:"🙌","woman-frowning":"🙍‍♀️",person_frowning:"🙍‍♀️","man-frowning":"🙍‍♂️","woman-pouting":"🙎‍♀️",person_with_pouting_face:"🙎‍♀️","man-pouting":"🙎‍♂️",pray:"🙏",rocket:"🚀",helicopter:"🚁",steam_locomotive:"🚂",railway_car:"🚃",bullettrain_side:"🚄",bullettrain_front:"🚅",train2:"🚆",metro:"🚇",light_rail:"🚈",station:"🚉",tram:"🚊",train:"🚋",bus:"🚌",oncoming_bus:"🚍",trolleybus:"🚎",busstop:"🚏",minibus:"🚐",ambulance:"🚑",fire_engine:"🚒",police_car:"🚓",oncoming_police_car:"🚔",taxi:"🚕",oncoming_taxi:"🚖",car:"🚗",red_car:"🚗",oncoming_automobile:"🚘",blue_car:"🚙",truck:"🚚",articulated_lorry:"🚛",tractor:"🚜",monorail:"🚝",mountain_railway:"🚞",suspension_railway:"🚟",mountain_cableway:"🚠",aerial_tramway:"🚡",ship:"🚢","woman-rowing-boat":"🚣‍♀️","man-rowing-boat":"🚣‍♂️",rowboat:"🚣‍♂️",speedboat:"🚤",traffic_light:"🚥",vertical_traffic_light:"🚦",construction:"🚧",rotating_light:"🚨",triangular_flag_on_post:"🚩",door:"🚪",no_entry_sign:"🚫",smoking:"🚬",no_smoking:"🚭",put_litter_in_its_place:"🚮",do_not_litter:"🚯",potable_water:"🚰","non-potable_water":"🚱",bike:"🚲",no_bicycles:"🚳","woman-biking":"🚴‍♀️","man-biking":"🚴‍♂️",bicyclist:"🚴‍♂️","woman-mountain-biking":"🚵‍♀️","man-mountain-biking":"🚵‍♂️",mountain_bicyclist:"🚵‍♂️","woman-walking":"🚶‍♀️","man-walking":"🚶‍♂️",walking:"🚶‍♂️",no_pedestrians:"🚷",children_crossing:"🚸",mens:"🚹",womens:"🚺",restroom:"🚻",baby_symbol:"🚼",toilet:"🚽",wc:"🚾",shower:"🚿",bath:"🛀",bathtub:"🛁",passport_control:"🛂",customs:"🛃",baggage_claim:"🛄",left_luggage:"🛅",couch_and_lamp:"🛋️",sleeping_accommodation:"🛌",shopping_bags:"🛍️",bellhop_bell:"🛎️",bed:"🛏️",place_of_worship:"🛐",octagonal_sign:"🛑",shopping_trolley:"🛒",hammer_and_wrench:"🛠️",shield:"🛡️",oil_drum:"🛢️",motorway:"🛣️",railway_track:"🛤️",motor_boat:"🛥️",small_airplane:"🛩️",airplane_departure:"🛫",airplane_arriving:"🛬",satellite:"🛰️",passenger_ship:"🛳️",scooter:"🛴",motor_scooter:"🛵",canoe:"🛶",sled:"🛷",flying_saucer:"🛸",zipper_mouth_face:"🤐",money_mouth_face:"🤑",face_with_thermometer:"🤒",nerd_face:"🤓",thinking_face:"🤔",face_with_head_bandage:"🤕",robot_face:"🤖",hugging_face:"🤗",the_horns:"🤘",sign_of_the_horns:"🤘",call_me_hand:"🤙",raised_back_of_hand:"🤚","left-facing_fist":"🤛","right-facing_fist":"🤜",handshake:"🤝",crossed_fingers:"🤞",hand_with_index_and_middle_fingers_crossed:"🤞",i_love_you_hand_sign:"🤟",face_with_cowboy_hat:"🤠",clown_face:"🤡",nauseated_face:"🤢",rolling_on_the_floor_laughing:"🤣",drooling_face:"🤤",lying_face:"🤥","woman-facepalming":"🤦‍♀️","man-facepalming":"🤦‍♂️",face_palm:"🤦",sneezing_face:"🤧",face_with_raised_eyebrow:"🤨",face_with_one_eyebrow_raised:"🤨","star-struck":"🤩",grinning_face_with_star_eyes:"🤩",zany_face:"🤪",grinning_face_with_one_large_and_one_small_eye:"🤪",shushing_face:"🤫",face_with_finger_covering_closed_lips:"🤫",face_with_symbols_on_mouth:"🤬",serious_face_with_symbols_covering_mouth:"🤬",face_with_hand_over_mouth:"🤭",smiling_face_with_smiling_eyes_and_hand_covering_mouth:"🤭",face_vomiting:"🤮",face_with_open_mouth_vomiting:"🤮",exploding_head:"🤯",shocked_face_with_exploding_head:"🤯",pregnant_woman:"🤰","breast-feeding":"🤱",palms_up_together:"🤲",selfie:"🤳",prince:"🤴",man_in_tuxedo:"🤵",mrs_claus:"🤶",mother_christmas:"🤶","woman-shrugging":"🤷‍♀️","man-shrugging":"🤷‍♂️",shrug:"🤷","woman-cartwheeling":"🤸‍♀️","man-cartwheeling":"🤸‍♂️",person_doing_cartwheel:"🤸","woman-juggling":"🤹‍♀️","man-juggling":"🤹‍♂️",juggling:"🤹",fencer:"🤺","woman-wrestling":"🤼‍♀️","man-wrestling":"🤼‍♂️",wrestlers:"🤼","woman-playing-water-polo":"🤽‍♀️","man-playing-water-polo":"🤽‍♂️",water_polo:"🤽","woman-playing-handball":"🤾‍♀️","man-playing-handball":"🤾‍♂️",handball:"🤾",wilted_flower:"🥀",drum_with_drumsticks:"🥁",clinking_glasses:"🥂",tumbler_glass:"🥃",spoon:"🥄",goal_net:"🥅",first_place_medal:"🥇",second_place_medal:"🥈",third_place_medal:"🥉",boxing_glove:"🥊",martial_arts_uniform:"🥋",curling_stone:"🥌",croissant:"🥐",avocado:"🥑",cucumber:"🥒",bacon:"🥓",potato:"🥔",carrot:"🥕",baguette_bread:"🥖",green_salad:"🥗",shallow_pan_of_food:"🥘",stuffed_flatbread:"🥙",egg:"🥚",glass_of_milk:"🥛",peanuts:"🥜",kiwifruit:"🥝",pancakes:"🥞",dumpling:"🥟",fortune_cookie:"🥠",takeout_box:"🥡",chopsticks:"🥢",bowl_with_spoon:"🥣",cup_with_straw:"🥤",coconut:"🥥",broccoli:"🥦",pie:"🥧",pretzel:"🥨",cut_of_meat:"🥩",sandwich:"🥪",canned_food:"🥫",crab:"🦀",lion_face:"🦁",scorpion:"🦂",turkey:"🦃",unicorn_face:"🦄",eagle:"🦅",duck:"🦆",bat:"🦇",shark:"🦈",owl:"🦉",fox_face:"🦊",butterfly:"🦋",deer:"🦌",gorilla:"🦍",lizard:"🦎",rhinoceros:"🦏",shrimp:"🦐",squid:"🦑",giraffe_face:"🦒",zebra_face:"🦓",hedgehog:"🦔",sauropod:"🦕","t-rex":"🦖",cricket:"🦗",cheese_wedge:"🧀",face_with_monocle:"🧐",adult:"🧑",child:"🧒",older_adult:"🧓",bearded_person:"🧔",person_with_headscarf:"🧕",woman_in_steamy_room:"🧖‍♀️",man_in_steamy_room:"🧖‍♂️",person_in_steamy_room:"🧖‍♂️",woman_climbing:"🧗‍♀️",person_climbing:"🧗‍♀️",man_climbing:"🧗‍♂️",woman_in_lotus_position:"🧘‍♀️",person_in_lotus_position:"🧘‍♀️",man_in_lotus_position:"🧘‍♂️",female_mage:"🧙‍♀️",mage:"🧙‍♀️",male_mage:"🧙‍♂️",female_fairy:"🧚‍♀️",fairy:"🧚‍♀️",male_fairy:"🧚‍♂️",female_vampire:"🧛‍♀️",vampire:"🧛‍♀️",male_vampire:"🧛‍♂️",mermaid:"🧜‍♀️",merman:"🧜‍♂️",merperson:"🧜‍♂️",female_elf:"🧝‍♀️",male_elf:"🧝‍♂️",elf:"🧝‍♂️",female_genie:"🧞‍♀️",male_genie:"🧞‍♂️",genie:"🧞‍♂️",female_zombie:"🧟‍♀️",male_zombie:"🧟‍♂️",zombie:"🧟‍♂️",brain:"🧠",orange_heart:"🧡",billed_cap:"🧢",scarf:"🧣",gloves:"🧤",coat:"🧥",socks:"🧦",bangbang:"‼️",interrobang:"⁉️",tm:"™️",information_source:"ℹ️",left_right_arrow:"↔️",arrow_up_down:"↕️",arrow_upper_left:"↖️",arrow_upper_right:"↗️",arrow_lower_right:"↘️",arrow_lower_left:"↙️",leftwards_arrow_with_hook:"↩️",arrow_right_hook:"↪️",watch:"⌚",hourglass:"⌛",keyboard:"⌨️",eject:"⏏️",fast_forward:"⏩",rewind:"⏪",arrow_double_up:"⏫",arrow_double_down:"⏬",black_right_pointing_double_triangle_with_vertical_bar:"⏭️",black_left_pointing_double_triangle_with_vertical_bar:"⏮️",black_right_pointing_triangle_with_double_vertical_bar:"⏯️",alarm_clock:"⏰",stopwatch:"⏱️",timer_clock:"⏲️",hourglass_flowing_sand:"⏳",double_vertical_bar:"⏸️",black_square_for_stop:"⏹️",black_circle_for_record:"⏺️",m:"Ⓜ️",black_small_square:"▪️",white_small_square:"▫️",arrow_forward:"▶️",arrow_backward:"◀️",white_medium_square:"◻️",black_medium_square:"◼️",white_medium_small_square:"◽",black_medium_small_square:"◾",sunny:"☀️",cloud:"☁️",umbrella:"☂️",snowman:"☃️",comet:"☄️",phone:"☎️",telephone:"☎️",ballot_box_with_check:"☑️",shamrock:"☘️",point_up:"☝️",skull_and_crossbones:"☠️",radioactive_sign:"☢️",biohazard_sign:"☣️",orthodox_cross:"☦️",star_and_crescent:"☪️",peace_symbol:"☮️",yin_yang:"☯️",wheel_of_dharma:"☸️",white_frowning_face:"☹️",relaxed:"☺️",female_sign:"♀️",male_sign:"♂️",gemini:"♊",cancer:"♋",leo:"♌",virgo:"♍",libra:"♎",scorpius:"♏",spades:"♠️",clubs:"♣️",hearts:"♥️",diamonds:"♦️",hotsprings:"♨️",recycle:"♻️",wheelchair:"♿",hammer_and_pick:"⚒️",crossed_swords:"⚔️",medical_symbol:"⚕️",staff_of_aesculapius:"⚕️",scales:"⚖️",alembic:"⚗️",gear:"⚙️",atom_symbol:"⚛️",fleur_de_lis:"⚜️",warning:"⚠️",zap:"⚡",white_circle:"⚪",black_circle:"⚫",coffin:"⚰️",funeral_urn:"⚱️",soccer:"⚽",baseball:"⚾",snowman_without_snow:"⛄",partly_sunny:"⛅",thunder_cloud_and_rain:"⛈️",ophiuchus:"⛎",pick:"⛏️",helmet_with_white_cross:"⛑️",chains:"⛓️",no_entry:"⛔",shinto_shrine:"⛩️",church:"⛪",mountain:"⛰️",umbrella_on_ground:"⛱️",fountain:"⛲",golf:"⛳",ferry:"⛴️",boat:"⛵",sailboat:"⛵",skier:"⛷️",ice_skate:"⛸️","woman-bouncing-ball":"⛹️‍♀️","man-bouncing-ball":"⛹️‍♂️",person_with_ball:"⛹️‍♂️",tent:"⛺",fuelpump:"⛽",scissors:"✂️",airplane:"✈️",email:"✉️",envelope:"✉️",fist:"✊",hand:"✋",raised_hand:"✋",v:"✌️",writing_hand:"✍️",pencil2:"✏️",black_nib:"✒️",heavy_check_mark:"✔️",heavy_multiplication_x:"✖️",latin_cross:"✝️",star_of_david:"✡️",eight_spoked_asterisk:"✳️",eight_pointed_black_star:"✴️",snowflake:"❄️",sparkle:"❇️",x:"❌",negative_squared_cross_mark:"❎",heavy_heart_exclamation_mark_ornament:"❣️",heart:"❤️",arrow_right:"➡️",curly_loop:"➰",loop:"➿",arrow_heading_up:"⤴️",arrow_heading_down:"⤵️",arrow_left:"⬅️",arrow_up:"⬆️",arrow_down:"⬇️",black_large_square:"⬛",white_large_square:"⬜",star:"⭐",o:"⭕",wavy_dash:"〰️",part_alternation_mark:"〽️",congratulations:"㊗️",secret:"㊙️"},pn=(ln=Object.freeze({__proto__:null,umbrella_with_rain_drops:"☔",coffee:"☕",aries:"♈",taurus:"♉",sagittarius:"♐",capricorn:"♑",aquarius:"♒",pisces:"♓",anchor:"⚓",white_check_mark:"✅",sparkles:"✨",question:"❓",grey_question:"❔",grey_exclamation:"❕",exclamation:"❗",heavy_exclamation_mark:"❗",heavy_plus_sign:"➕",heavy_minus_sign:"➖",heavy_division_sign:"➗",hash:"#️⃣",keycap_star:"*️⃣",zero:"0️⃣",one:"1️⃣",two:"2️⃣",three:"3️⃣",four:"4️⃣",five:"5️⃣",six:"6️⃣",seven:"7️⃣",eight:"8️⃣",nine:"9️⃣",copyright:"©️",registered:"®️",mahjong:"🀄",black_joker:"🃏",a:"🅰️",b:"🅱️",o2:"🅾️",parking:"🅿️",ab:"🆎",cl:"🆑",cool:"🆒",free:"🆓",id:"🆔",ng:"🆖",ok:"🆗",sos:"🆘",up:"🆙",vs:"🆚",cn:"🇨🇳",de:"🇩🇪",es:"🇪🇸",fr:"🇫🇷",gb:"🇬🇧",uk:"🇬🇧",it:"🇮🇹",jp:"🇯🇵",kr:"🇰🇷",ru:"🇷🇺",us:"🇺🇸",koko:"🈁",sa:"🈂️",u7121:"🈚",u6307:"🈯",u7981:"🈲",u7a7a:"🈳",u5408:"🈴",u6e80:"🈵",u6709:"🈶",u6708:"🈷️",u7533:"🈸",u5272:"🈹",u55b6:"🈺",ideograph_advantage:"🉐",accept:"🉑",cyclone:"🌀",foggy:"🌁",closed_umbrella:"🌂",night_with_stars:"🌃",sunrise_over_mountains:"🌄",sunrise:"🌅",city_sunset:"🌆",city_sunrise:"🌇",rainbow:"🌈",bridge_at_night:"🌉",ocean:"🌊",volcano:"🌋",milky_way:"🌌",earth_africa:"🌍",earth_americas:"🌎",earth_asia:"🌏",globe_with_meridians:"🌐",new_moon:"🌑",waxing_crescent_moon:"🌒",first_quarter_moon:"🌓",moon:"🌔",waxing_gibbous_moon:"🌔",full_moon:"🌕",waning_gibbous_moon:"🌖",last_quarter_moon:"🌗",waning_crescent_moon:"🌘",crescent_moon:"🌙",new_moon_with_face:"🌚",first_quarter_moon_with_face:"🌛",last_quarter_moon_with_face:"🌜",full_moon_with_face:"🌝",sun_with_face:"🌞",star2:"🌟",stars:"🌠",thermometer:"🌡️",mostly_sunny:"🌤️",sun_small_cloud:"🌤️",barely_sunny:"🌥️",sun_behind_cloud:"🌥️",partly_sunny_rain:"🌦️",sun_behind_rain_cloud:"🌦️",rain_cloud:"🌧️",snow_cloud:"🌨️",lightning:"🌩️",lightning_cloud:"🌩️",tornado:"🌪️",tornado_cloud:"🌪️",fog:"🌫️",wind_blowing_face:"🌬️",hotdog:"🌭",taco:"🌮",burrito:"🌯",chestnut:"🌰",seedling:"🌱",evergreen_tree:"🌲",deciduous_tree:"🌳",palm_tree:"🌴",cactus:"🌵",hot_pepper:"🌶️",tulip:"🌷",cherry_blossom:"🌸",rose:"🌹",hibiscus:"🌺",sunflower:"🌻",blossom:"🌼",corn:"🌽",ear_of_rice:"🌾",herb:"🌿",four_leaf_clover:"🍀",maple_leaf:"🍁",fallen_leaf:"🍂",leaves:"🍃",mushroom:"🍄",tomato:"🍅",eggplant:"🍆",grapes:"🍇",melon:"🍈",watermelon:"🍉",tangerine:"🍊",lemon:"🍋",banana:"🍌",pineapple:"🍍",apple:"🍎",green_apple:"🍏",pear:"🍐",peach:"🍑",cherries:"🍒",strawberry:"🍓",hamburger:"🍔",pizza:"🍕",meat_on_bone:"🍖",poultry_leg:"🍗",rice_cracker:"🍘",rice_ball:"🍙",rice:"🍚",curry:"🍛",ramen:"🍜",spaghetti:"🍝",bread:"🍞",fries:"🍟",sweet_potato:"🍠",dango:"🍡",oden:"🍢",sushi:"🍣",fried_shrimp:"🍤",fish_cake:"🍥",icecream:"🍦",shaved_ice:"🍧",ice_cream:"🍨",doughnut:"🍩",cookie:"🍪",chocolate_bar:"🍫",candy:"🍬",lollipop:"🍭",custard:"🍮",honey_pot:"🍯",cake:"🍰",bento:"🍱",stew:"🍲",fried_egg:"🍳",cooking:"🍳",fork_and_knife:"🍴",tea:"🍵",sake:"🍶",wine_glass:"🍷",cocktail:"🍸",tropical_drink:"🍹",beer:"🍺",beers:"🍻",baby_bottle:"🍼",knife_fork_plate:"🍽️",champagne:"🍾",popcorn:"🍿",ribbon:"🎀",gift:"🎁",birthday:"🎂",jack_o_lantern:"🎃",christmas_tree:"🎄",santa:"🎅",fireworks:"🎆",sparkler:"🎇",balloon:"🎈",tada:"🎉",confetti_ball:"🎊",tanabata_tree:"🎋",crossed_flags:"🎌",bamboo:"🎍",dolls:"🎎",flags:"🎏",wind_chime:"🎐",rice_scene:"🎑",school_satchel:"🎒",mortar_board:"🎓",medal:"🎖️",reminder_ribbon:"🎗️",studio_microphone:"🎙️",level_slider:"🎚️",control_knobs:"🎛️",film_frames:"🎞️",admission_tickets:"🎟️",carousel_horse:"🎠",ferris_wheel:"🎡",roller_coaster:"🎢",fishing_pole_and_fish:"🎣",microphone:"🎤",movie_camera:"🎥",cinema:"🎦",headphones:"🎧",art:"🎨",tophat:"🎩",circus_tent:"🎪",ticket:"🎫",clapper:"🎬",performing_arts:"🎭",video_game:"🎮",dart:"🎯",slot_machine:"🎰",game_die:"🎲",bowling:"🎳",flower_playing_cards:"🎴",musical_note:"🎵",notes:"🎶",saxophone:"🎷",guitar:"🎸",musical_keyboard:"🎹",trumpet:"🎺",violin:"🎻",musical_score:"🎼",running_shirt_with_sash:"🎽",tennis:"🎾",ski:"🎿",basketball:"🏀",checkered_flag:"🏁",snowboarder:"🏂",runner:"🏃‍♂️",running:"🏃‍♂️",surfer:"🏄‍♂️",sports_medal:"🏅",trophy:"🏆",horse_racing:"🏇",football:"🏈",rugby_football:"🏉",swimmer:"🏊‍♂️",weight_lifter:"🏋️‍♂️",golfer:"🏌️‍♂️",racing_motorcycle:"🏍️",racing_car:"🏎️",cricket_bat_and_ball:"🏏",volleyball:"🏐",field_hockey_stick_and_ball:"🏑",ice_hockey_stick_and_puck:"🏒",table_tennis_paddle_and_ball:"🏓",snow_capped_mountain:"🏔️",camping:"🏕️",beach_with_umbrella:"🏖️",building_construction:"🏗️",house_buildings:"🏘️",cityscape:"🏙️",derelict_house_building:"🏚️",classical_building:"🏛️",desert:"🏜️",desert_island:"🏝️",national_park:"🏞️",stadium:"🏟️",house:"🏠",house_with_garden:"🏡",office:"🏢",post_office:"🏣",european_post_office:"🏤",hospital:"🏥",bank:"🏦",atm:"🏧",hotel:"🏨",love_hotel:"🏩",convenience_store:"🏪",school:"🏫",department_store:"🏬",factory:"🏭",izakaya_lantern:"🏮",lantern:"🏮",japanese_castle:"🏯",european_castle:"🏰",waving_white_flag:"🏳️",waving_black_flag:"🏴",rosette:"🏵️",label:"🏷️",badminton_racquet_and_shuttlecock:"🏸",bow_and_arrow:"🏹",amphora:"🏺",rat:"🐀",mouse2:"🐁",ox:"🐂",water_buffalo:"🐃",cow2:"🐄",tiger2:"🐅",leopard:"🐆",rabbit2:"🐇",cat2:"🐈",dragon:"🐉",crocodile:"🐊",whale2:"🐋",snail:"🐌",snake:"🐍",racehorse:"🐎",ram:"🐏",goat:"🐐",sheep:"🐑",monkey:"🐒",rooster:"🐓",chicken:"🐔",dog2:"🐕",pig2:"🐖",boar:"🐗",elephant:"🐘",octopus:"🐙",shell:"🐚",bug:"🐛",ant:"🐜",bee:"🐝",honeybee:"🐝",beetle:"🐞",fish:"🐟",tropical_fish:"🐠",blowfish:"🐡",turtle:"🐢",hatching_chick:"🐣",baby_chick:"🐤",hatched_chick:"🐥",bird:"🐦",penguin:"🐧",koala:"🐨",poodle:"🐩",dromedary_camel:"🐪",camel:"🐫",dolphin:"🐬",flipper:"🐬",mouse:"🐭",cow:"🐮",tiger:"🐯",rabbit:"🐰",cat:"🐱",dragon_face:"🐲",whale:"🐳",horse:"🐴",monkey_face:"🐵",dog:"🐶",pig:"🐷",frog:"🐸",hamster:"🐹",wolf:"🐺",bear:"🐻",panda_face:"🐼",pig_nose:"🐽",feet:"🐾",paw_prints:"🐾",chipmunk:"🐿️",eyes:"👀",eye:"👁️",ear:"👂",nose:"👃",lips:"👄",tongue:"👅",point_up_2:"👆",point_down:"👇",point_left:"👈",point_right:"👉",facepunch:"👊",punch:"👊",wave:"👋",ok_hand:"👌",thumbsup:"👍",thumbsdown:"👎",clap:"👏",open_hands:"👐",crown:"👑",womans_hat:"👒",eyeglasses:"👓",necktie:"👔",shirt:"👕",tshirt:"👕",jeans:"👖",dress:"👗",kimono:"👘",bikini:"👙",womans_clothes:"👚",purse:"👛",handbag:"👜",pouch:"👝",mans_shoe:"👞",shoe:"👞",athletic_shoe:"👟",high_heel:"👠",sandal:"👡",boot:"👢",footprints:"👣",bust_in_silhouette:"👤",busts_in_silhouette:"👥",boy:"👦",girl:"👧",family:"👨‍👩‍👦",man:"👨",couple_with_heart:"👩‍❤️‍👨",couplekiss:"👩‍❤️‍💋‍👨",woman:"👩",couple:"👫",man_and_woman_holding_hands:"👫",two_men_holding_hands:"👬",two_women_holding_hands:"👭",cop:"👮‍♂️",dancers:"👯‍♀️",bride_with_veil:"👰",person_with_blond_hair:"👱‍♂️",man_with_gua_pi_mao:"👲",man_with_turban:"👳‍♂️",older_man:"👴",older_woman:"👵",baby:"👶",construction_worker:"👷‍♂️",princess:"👸",japanese_ogre:"👹",japanese_goblin:"👺",ghost:"👻",angel:"👼",alien:"👽",space_invader:"👾",imp:"👿",skull:"💀",information_desk_person:"💁‍♀️",guardsman:"💂‍♂️",dancer:"💃",lipstick:"💄",nail_care:"💅",massage:"💆‍♀️",haircut:"💇‍♀️",barber:"💈",syringe:"💉",pill:"💊",kiss:"💋",love_letter:"💌",ring:"💍",gem:"💎",bouquet:"💐",wedding:"💒",heartbeat:"💓",broken_heart:"💔",two_hearts:"💕",sparkling_heart:"💖",heartpulse:"💗",cupid:"💘",blue_heart:"💙",green_heart:"💚",yellow_heart:"💛",purple_heart:"💜",gift_heart:"💝",revolving_hearts:"💞",heart_decoration:"💟",diamond_shape_with_a_dot_inside:"💠",bulb:"💡",anger:"💢",bomb:"💣",zzz:"💤",boom:"💥",collision:"💥",sweat_drops:"💦",droplet:"💧",dash:"💨",hankey:"💩",poop:"💩",shit:"💩",muscle:"💪",dizzy:"💫",speech_balloon:"💬",thought_balloon:"💭",white_flower:"💮",moneybag:"💰",currency_exchange:"💱",heavy_dollar_sign:"💲",credit_card:"💳",yen:"💴",dollar:"💵",euro:"💶",pound:"💷",money_with_wings:"💸",chart:"💹",seat:"💺",computer:"💻",briefcase:"💼",minidisc:"💽",floppy_disk:"💾",cd:"💿",dvd:"📀",file_folder:"📁",open_file_folder:"📂",page_with_curl:"📃",page_facing_up:"📄",date:"📅",calendar:"📆",card_index:"📇",chart_with_upwards_trend:"📈",chart_with_downwards_trend:"📉",bar_chart:"📊",clipboard:"📋",pushpin:"📌",round_pushpin:"📍",paperclip:"📎",straight_ruler:"📏",triangular_ruler:"📐",bookmark_tabs:"📑",ledger:"📒",notebook:"📓",notebook_with_decorative_cover:"📔",closed_book:"📕",book:"📖",open_book:"📖",green_book:"📗",blue_book:"📘",orange_book:"📙",books:"📚",name_badge:"📛",scroll:"📜",memo:"📝",pencil:"📝",telephone_receiver:"📞",pager:"📟",fax:"📠",satellite_antenna:"📡",loudspeaker:"📢",mega:"📣",outbox_tray:"📤",inbox_tray:"📥",incoming_envelope:"📨",envelope_with_arrow:"📩",mailbox_closed:"📪",mailbox:"📫",mailbox_with_mail:"📬",mailbox_with_no_mail:"📭",postbox:"📮",postal_horn:"📯",newspaper:"📰",iphone:"📱",calling:"📲",vibration_mode:"📳",mobile_phone_off:"📴",no_mobile_phones:"📵",signal_strength:"📶",camera:"📷",camera_with_flash:"📸",video_camera:"📹",tv:"📺",radio:"📻",vhs:"📼",film_projector:"📽️",prayer_beads:"📿",twisted_rightwards_arrows:"🔀",repeat:"🔁",repeat_one:"🔂",arrows_clockwise:"🔃",arrows_counterclockwise:"🔄",low_brightness:"🔅",high_brightness:"🔆",mute:"🔇",speaker:"🔈",sound:"🔉",loud_sound:"🔊",battery:"🔋",electric_plug:"🔌",mag:"🔍",mag_right:"🔎",lock_with_ink_pen:"🔏",closed_lock_with_key:"🔐",key:"🔑",lock:"🔒",unlock:"🔓",bell:"🔔",no_bell:"🔕",bookmark:"🔖",link:"🔗",radio_button:"🔘",back:"🔙",end:"🔚",on:"🔛",soon:"🔜",top:"🔝",underage:"🔞",keycap_ten:"🔟",capital_abcd:"🔠",abcd:"🔡",symbols:"🔣",abc:"🔤",fire:"🔥",flashlight:"🔦",wrench:"🔧",hammer:"🔨",nut_and_bolt:"🔩",hocho:"🔪",knife:"🔪",gun:"🔫",microscope:"🔬",telescope:"🔭",crystal_ball:"🔮",six_pointed_star:"🔯",beginner:"🔰",trident:"🔱",black_square_button:"🔲",white_square_button:"🔳",red_circle:"🔴",large_blue_circle:"🔵",large_orange_diamond:"🔶",large_blue_diamond:"🔷",small_orange_diamond:"🔸",small_blue_diamond:"🔹",small_red_triangle:"🔺",small_red_triangle_down:"🔻",arrow_up_small:"🔼",arrow_down_small:"🔽",om_symbol:"🕉️",dove_of_peace:"🕊️",kaaba:"🕋",mosque:"🕌",synagogue:"🕍",menorah_with_nine_branches:"🕎",clock1:"🕐",clock2:"🕑",clock3:"🕒",clock4:"🕓",clock5:"🕔",clock6:"🕕",clock7:"🕖",clock8:"🕗",clock9:"🕘",clock10:"🕙",clock11:"🕚",clock12:"🕛",clock130:"🕜",clock230:"🕝",clock330:"🕞",clock430:"🕟",clock530:"🕠",clock630:"🕡",clock730:"🕢",clock830:"🕣",clock930:"🕤",clock1030:"🕥",clock1130:"🕦",clock1230:"🕧",candle:"🕯️",mantelpiece_clock:"🕰️",hole:"🕳️",man_in_business_suit_levitating:"🕴️",sleuth_or_spy:"🕵️‍♂️",dark_sunglasses:"🕶️",spider:"🕷️",spider_web:"🕸️",joystick:"🕹️",man_dancing:"🕺",linked_paperclips:"🖇️",lower_left_ballpoint_pen:"🖊️",lower_left_fountain_pen:"🖋️",lower_left_paintbrush:"🖌️",lower_left_crayon:"🖍️",raised_hand_with_fingers_splayed:"🖐️",middle_finger:"🖕",reversed_hand_with_middle_finger_extended:"🖕",black_heart:"🖤",desktop_computer:"🖥️",printer:"🖨️",three_button_mouse:"🖱️",trackball:"🖲️",frame_with_picture:"🖼️",card_index_dividers:"🗂️",card_file_box:"🗃️",file_cabinet:"🗄️",wastebasket:"🗑️",spiral_note_pad:"🗒️",spiral_calendar_pad:"🗓️",compression:"🗜️",old_key:"🗝️",rolled_up_newspaper:"🗞️",dagger_knife:"🗡️",speaking_head_in_silhouette:"🗣️",left_speech_bubble:"🗨️",right_anger_bubble:"🗯️",ballot_box_with_ballot:"🗳️",world_map:"🗺️",mount_fuji:"🗻",tokyo_tower:"🗼",statue_of_liberty:"🗽",japan:"🗾",moyai:"🗿",grinning:"😀",grin:"😁",joy:"😂",smiley:"😃",smile:"😄",sweat_smile:"😅",laughing:"😆",satisfied:"😆",innocent:"😇",smiling_imp:"😈",wink:"😉",blush:"😊",yum:"😋",relieved:"😌",heart_eyes:"😍",sunglasses:"😎",smirk:"😏",neutral_face:"😐",expressionless:"😑",unamused:"😒",sweat:"😓",pensive:"😔",confused:"😕",confounded:"😖",kissing:"😗",kissing_heart:"😘",kissing_smiling_eyes:"😙",kissing_closed_eyes:"😚",stuck_out_tongue:"😛",stuck_out_tongue_winking_eye:"😜",stuck_out_tongue_closed_eyes:"😝",disappointed:"😞",worried:"😟",angry:"😠",rage:"😡",cry:"😢",persevere:"😣",triumph:"😤",disappointed_relieved:"😥",frowning:"😦",anguished:"😧",fearful:"😨",weary:"😩",sleepy:"😪",tired_face:"😫",grimacing:"😬",sob:"😭",open_mouth:"😮",hushed:"😯",cold_sweat:"😰",scream:"😱",astonished:"😲",flushed:"😳",sleeping:"😴",dizzy_face:"😵",no_mouth:"😶",mask:"😷",smile_cat:"😸",joy_cat:"😹",smiley_cat:"😺",heart_eyes_cat:"😻",smirk_cat:"😼",kissing_cat:"😽",pouting_cat:"😾",crying_cat_face:"😿",scream_cat:"🙀",slightly_frowning_face:"🙁",slightly_smiling_face:"🙂",upside_down_face:"🙃",face_with_rolling_eyes:"🙄",no_good:"🙅‍♀️",ok_woman:"🙆‍♀️",bow:"🙇‍♂️",see_no_evil:"🙈",hear_no_evil:"🙉",speak_no_evil:"🙊",raising_hand:"🙋‍♀️",raised_hands:"🙌",person_frowning:"🙍‍♀️",person_with_pouting_face:"🙎‍♀️",pray:"🙏",rocket:"🚀",helicopter:"🚁",steam_locomotive:"🚂",railway_car:"🚃",bullettrain_side:"🚄",bullettrain_front:"🚅",train2:"🚆",metro:"🚇",light_rail:"🚈",station:"🚉",tram:"🚊",train:"🚋",bus:"🚌",oncoming_bus:"🚍",trolleybus:"🚎",busstop:"🚏",minibus:"🚐",ambulance:"🚑",fire_engine:"🚒",police_car:"🚓",oncoming_police_car:"🚔",taxi:"🚕",oncoming_taxi:"🚖",car:"🚗",red_car:"🚗",oncoming_automobile:"🚘",blue_car:"🚙",truck:"🚚",articulated_lorry:"🚛",tractor:"🚜",monorail:"🚝",mountain_railway:"🚞",suspension_railway:"🚟",mountain_cableway:"🚠",aerial_tramway:"🚡",ship:"🚢",rowboat:"🚣‍♂️",speedboat:"🚤",traffic_light:"🚥",vertical_traffic_light:"🚦",construction:"🚧",rotating_light:"🚨",triangular_flag_on_post:"🚩",door:"🚪",no_entry_sign:"🚫",smoking:"🚬",no_smoking:"🚭",put_litter_in_its_place:"🚮",do_not_litter:"🚯",potable_water:"🚰",bike:"🚲",no_bicycles:"🚳",bicyclist:"🚴‍♂️",mountain_bicyclist:"🚵‍♂️",walking:"🚶‍♂️",no_pedestrians:"🚷",children_crossing:"🚸",mens:"🚹",womens:"🚺",restroom:"🚻",baby_symbol:"🚼",toilet:"🚽",wc:"🚾",shower:"🚿",bath:"🛀",bathtub:"🛁",passport_control:"🛂",customs:"🛃",baggage_claim:"🛄",left_luggage:"🛅",couch_and_lamp:"🛋️",sleeping_accommodation:"🛌",shopping_bags:"🛍️",bellhop_bell:"🛎️",bed:"🛏️",place_of_worship:"🛐",octagonal_sign:"🛑",shopping_trolley:"🛒",hammer_and_wrench:"🛠️",shield:"🛡️",oil_drum:"🛢️",motorway:"🛣️",railway_track:"🛤️",motor_boat:"🛥️",small_airplane:"🛩️",airplane_departure:"🛫",airplane_arriving:"🛬",satellite:"🛰️",passenger_ship:"🛳️",scooter:"🛴",motor_scooter:"🛵",canoe:"🛶",sled:"🛷",flying_saucer:"🛸",zipper_mouth_face:"🤐",money_mouth_face:"🤑",face_with_thermometer:"🤒",nerd_face:"🤓",thinking_face:"🤔",face_with_head_bandage:"🤕",robot_face:"🤖",hugging_face:"🤗",the_horns:"🤘",sign_of_the_horns:"🤘",call_me_hand:"🤙",raised_back_of_hand:"🤚",handshake:"🤝",crossed_fingers:"🤞",hand_with_index_and_middle_fingers_crossed:"🤞",i_love_you_hand_sign:"🤟",face_with_cowboy_hat:"🤠",clown_face:"🤡",nauseated_face:"🤢",rolling_on_the_floor_laughing:"🤣",drooling_face:"🤤",lying_face:"🤥",face_palm:"🤦",sneezing_face:"🤧",face_with_raised_eyebrow:"🤨",face_with_one_eyebrow_raised:"🤨",grinning_face_with_star_eyes:"🤩",zany_face:"🤪",grinning_face_with_one_large_and_one_small_eye:"🤪",shushing_face:"🤫",face_with_finger_covering_closed_lips:"🤫",face_with_symbols_on_mouth:"🤬",serious_face_with_symbols_covering_mouth:"🤬",face_with_hand_over_mouth:"🤭",smiling_face_with_smiling_eyes_and_hand_covering_mouth:"🤭",face_vomiting:"🤮",face_with_open_mouth_vomiting:"🤮",exploding_head:"🤯",shocked_face_with_exploding_head:"🤯",pregnant_woman:"🤰",palms_up_together:"🤲",selfie:"🤳",prince:"🤴",man_in_tuxedo:"🤵",mrs_claus:"🤶",mother_christmas:"🤶",shrug:"🤷",person_doing_cartwheel:"🤸",juggling:"🤹",fencer:"🤺",wrestlers:"🤼",water_polo:"🤽",handball:"🤾",wilted_flower:"🥀",drum_with_drumsticks:"🥁",clinking_glasses:"🥂",tumbler_glass:"🥃",spoon:"🥄",goal_net:"🥅",first_place_medal:"🥇",second_place_medal:"🥈",third_place_medal:"🥉",boxing_glove:"🥊",martial_arts_uniform:"🥋",curling_stone:"🥌",croissant:"🥐",avocado:"🥑",cucumber:"🥒",bacon:"🥓",potato:"🥔",carrot:"🥕",baguette_bread:"🥖",green_salad:"🥗",shallow_pan_of_food:"🥘",stuffed_flatbread:"🥙",egg:"🥚",glass_of_milk:"🥛",peanuts:"🥜",kiwifruit:"🥝",pancakes:"🥞",dumpling:"🥟",fortune_cookie:"🥠",takeout_box:"🥡",chopsticks:"🥢",bowl_with_spoon:"🥣",cup_with_straw:"🥤",coconut:"🥥",broccoli:"🥦",pie:"🥧",pretzel:"🥨",cut_of_meat:"🥩",sandwich:"🥪",canned_food:"🥫",crab:"🦀",lion_face:"🦁",scorpion:"🦂",turkey:"🦃",unicorn_face:"🦄",eagle:"🦅",duck:"🦆",bat:"🦇",shark:"🦈",owl:"🦉",fox_face:"🦊",butterfly:"🦋",deer:"🦌",gorilla:"🦍",lizard:"🦎",rhinoceros:"🦏",shrimp:"🦐",squid:"🦑",giraffe_face:"🦒",zebra_face:"🦓",hedgehog:"🦔",sauropod:"🦕",cricket:"🦗",cheese_wedge:"🧀",face_with_monocle:"🧐",adult:"🧑",child:"🧒",older_adult:"🧓",bearded_person:"🧔",person_with_headscarf:"🧕",woman_in_steamy_room:"🧖‍♀️",man_in_steamy_room:"🧖‍♂️",person_in_steamy_room:"🧖‍♂️",woman_climbing:"🧗‍♀️",person_climbing:"🧗‍♀️",man_climbing:"🧗‍♂️",woman_in_lotus_position:"🧘‍♀️",person_in_lotus_position:"🧘‍♀️",man_in_lotus_position:"🧘‍♂️",female_mage:"🧙‍♀️",mage:"🧙‍♀️",male_mage:"🧙‍♂️",female_fairy:"🧚‍♀️",fairy:"🧚‍♀️",male_fairy:"🧚‍♂️",female_vampire:"🧛‍♀️",vampire:"🧛‍♀️",male_vampire:"🧛‍♂️",mermaid:"🧜‍♀️",merman:"🧜‍♂️",merperson:"🧜‍♂️",female_elf:"🧝‍♀️",male_elf:"🧝‍♂️",elf:"🧝‍♂️",female_genie:"🧞‍♀️",male_genie:"🧞‍♂️",genie:"🧞‍♂️",female_zombie:"🧟‍♀️",male_zombie:"🧟‍♂️",zombie:"🧟‍♂️",brain:"🧠",orange_heart:"🧡",billed_cap:"🧢",scarf:"🧣",gloves:"🧤",coat:"🧥",socks:"🧦",bangbang:"‼️",interrobang:"⁉️",tm:"™️",information_source:"ℹ️",left_right_arrow:"↔️",arrow_up_down:"↕️",arrow_upper_left:"↖️",arrow_upper_right:"↗️",arrow_lower_right:"↘️",arrow_lower_left:"↙️",leftwards_arrow_with_hook:"↩️",arrow_right_hook:"↪️",watch:"⌚",hourglass:"⌛",keyboard:"⌨️",eject:"⏏️",fast_forward:"⏩",rewind:"⏪",arrow_double_up:"⏫",arrow_double_down:"⏬",black_right_pointing_double_triangle_with_vertical_bar:"⏭️",black_left_pointing_double_triangle_with_vertical_bar:"⏮️",black_right_pointing_triangle_with_double_vertical_bar:"⏯️",alarm_clock:"⏰",stopwatch:"⏱️",timer_clock:"⏲️",hourglass_flowing_sand:"⏳",double_vertical_bar:"⏸️",black_square_for_stop:"⏹️",black_circle_for_record:"⏺️",m:"Ⓜ️",black_small_square:"▪️",white_small_square:"▫️",arrow_forward:"▶️",arrow_backward:"◀️",white_medium_square:"◻️",black_medium_square:"◼️",white_medium_small_square:"◽",black_medium_small_square:"◾",sunny:"☀️",cloud:"☁️",umbrella:"☂️",snowman:"☃️",comet:"☄️",phone:"☎️",telephone:"☎️",ballot_box_with_check:"☑️",shamrock:"☘️",point_up:"☝️",skull_and_crossbones:"☠️",radioactive_sign:"☢️",biohazard_sign:"☣️",orthodox_cross:"☦️",star_and_crescent:"☪️",peace_symbol:"☮️",yin_yang:"☯️",wheel_of_dharma:"☸️",white_frowning_face:"☹️",relaxed:"☺️",female_sign:"♀️",male_sign:"♂️",gemini:"♊",cancer:"♋",leo:"♌",virgo:"♍",libra:"♎",scorpius:"♏",spades:"♠️",clubs:"♣️",hearts:"♥️",diamonds:"♦️",hotsprings:"♨️",recycle:"♻️",wheelchair:"♿",hammer_and_pick:"⚒️",crossed_swords:"⚔️",medical_symbol:"⚕️",staff_of_aesculapius:"⚕️",scales:"⚖️",alembic:"⚗️",gear:"⚙️",atom_symbol:"⚛️",fleur_de_lis:"⚜️",warning:"⚠️",zap:"⚡",white_circle:"⚪",black_circle:"⚫",coffin:"⚰️",funeral_urn:"⚱️",soccer:"⚽",baseball:"⚾",snowman_without_snow:"⛄",partly_sunny:"⛅",thunder_cloud_and_rain:"⛈️",ophiuchus:"⛎",pick:"⛏️",helmet_with_white_cross:"⛑️",chains:"⛓️",no_entry:"⛔",shinto_shrine:"⛩️",church:"⛪",mountain:"⛰️",umbrella_on_ground:"⛱️",fountain:"⛲",golf:"⛳",ferry:"⛴️",boat:"⛵",sailboat:"⛵",skier:"⛷️",ice_skate:"⛸️",person_with_ball:"⛹️‍♂️",tent:"⛺",fuelpump:"⛽",scissors:"✂️",airplane:"✈️",email:"✉️",envelope:"✉️",fist:"✊",hand:"✋",raised_hand:"✋",v:"✌️",writing_hand:"✍️",pencil2:"✏️",black_nib:"✒️",heavy_check_mark:"✔️",heavy_multiplication_x:"✖️",latin_cross:"✝️",star_of_david:"✡️",eight_spoked_asterisk:"✳️",eight_pointed_black_star:"✴️",snowflake:"❄️",sparkle:"❇️",x:"❌",negative_squared_cross_mark:"❎",heavy_heart_exclamation_mark_ornament:"❣️",heart:"❤️",arrow_right:"➡️",curly_loop:"➰",loop:"➿",arrow_heading_up:"⤴️",arrow_heading_down:"⤵️",arrow_left:"⬅️",arrow_up:"⬆️",arrow_down:"⬇️",black_large_square:"⬛",white_large_square:"⬜",star:"⭐",o:"⭕",wavy_dash:"〰️",part_alternation_mark:"〽️",congratulations:"㊗️",secret:"㊙️",default:dn}))&&ln.default||ln,un=/:([a-zA-Z0-9_\-\+]+):/g,hn=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;function gn(e){var t=e.indexOf(":");return t>-1?t===e.length-1?gn(e=e.substring(0,t)):gn(e=e.substr(t+1)):e}function mn(e){return"string"==typeof e&&e.length>0?":"+e+":":e}var fn=Object.keys(pn).reduce((function(e,t){return e[pn[t]]=t,e}),{}),_n={emoji:pn};_n._get=function(e){return pn.hasOwnProperty(e)?pn[e]:"string"==typeof(t=e)&&":"!==t[0]?mn(t):t;var t},_n.get=function(e){return e=gn(e),_n._get(e)},_n.find=function(e){return _n.findByName(e)||_n.findByCode(e)},_n.findByName=function(e){var t=gn(e),o=pn[t];return o?{emoji:o,key:t}:void 0},_n.findByCode=function(e){var t=fn[e];return t?{emoji:pn[t],key:t}:void 0},_n.hasEmoji=function(e){return _n.hasEmojiByName(e)||_n.hasEmojiByCode(e)},_n.hasEmojiByName=function(e){var t=_n.findByName(e);return!!t&&t.key===gn(e)},_n.hasEmojiByCode=function(e){var t=_n.findByCode(e);return!!t&&t.emoji===e},_n.which=function(e,t){var o=fn[e];return t?mn(o):o},_n.emojify=function(e,t,o){return e?e.split(un).map((function(e,a){if(a%2==0)return e;var n=_n._get(e),r=n.indexOf(":")>-1;return r&&"function"==typeof t?t(e):r||"function"!=typeof o?n:o(n,e)})).join(""):""},_n.random=function(){var e=Object.keys(pn),t=e[Math.floor(Math.random()*e.length)];return{key:t,emoji:_n._get(t)}},_n.search=function(e){var t=Object.keys(pn),o=gn(e);return t.filter((function(e){return 0===e.toString().indexOf(o)})).map((function(e){return{key:e,emoji:_n._get(e)}}))},_n.unemojify=function(e){return e?cn(e).map((function(e){return _n.which(e,!0)||e})).join(""):""},_n.replace=function(e,t,o){if(!e)return"";var a="function"==typeof t?t:function(){return t},n=cn(e),r=n.map((function(e,t){var r=_n.findByCode(e);return r&&o&&" "===n[t+1]&&(n[t+1]=""),r?a(r):e})).join("");return o?r.replace(hn,""):r},_n.strip=function(e){return _n.replace(e,"",!0)};var bn=_n,yn=Zo((function(e){function t(){return{baseUrl:null,breaks:!1,gfm:!0,headerIds:!0,headerPrefix:"",highlight:null,langPrefix:"language-",mangle:!0,pedantic:!1,renderer:null,sanitize:!1,sanitizer:null,silent:!1,smartLists:!1,smartypants:!1,xhtml:!1}}e.exports={defaults:{baseUrl:null,breaks:!1,gfm:!0,headerIds:!0,headerPrefix:"",highlight:null,langPrefix:"language-",mangle:!0,pedantic:!1,renderer:null,sanitize:!1,sanitizer:null,silent:!1,smartLists:!1,smartypants:!1,xhtml:!1},getDefaults:t,changeDefaults:function(t){e.exports.defaults=t}}}));yn.defaults,yn.getDefaults,yn.changeDefaults;const wn=/[&<>"']/,vn=/[&<>"']/g,kn=/[<>"']|&(?!#?\w+;)/,xn=/[<>"']|&(?!#?\w+;)/g,An={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},Sn=e=>An[e];const jn=/&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/gi;function En(e){return e.replace(jn,(e,t)=>"colon"===(t=t.toLowerCase())?":":"#"===t.charAt(0)?"x"===t.charAt(1)?String.fromCharCode(parseInt(t.substring(2),16)):String.fromCharCode(+t.substring(1)):"")}const On=/(^|[^\[])\^/g;const Cn=/[^\w:]/g,zn=/^$|^[a-z][a-z0-9+.-]*:|^[?#]/i;const Tn={},$n=/^[^:]+:\/*[^/]*$/,Rn=/^([^:]+:)[\s\S]*$/,Nn=/^([^:]+:\/*[^/]*)[\s\S]*$/;function In(e,t){Tn[" "+e]||($n.test(e)?Tn[" "+e]=e+"/":Tn[" "+e]=Pn(e,"/",!0));const o=-1===(e=Tn[" "+e]).indexOf(":");return"//"===t.substring(0,2)?o?t:e.replace(Rn,"$1")+t:"/"===t.charAt(0)?o?t:e.replace(Nn,"$1")+t:e+t}function Pn(e,t,o){const a=e.length;if(0===a)return"";let n=0;for(;n<a;){const r=e.charAt(a-n-1);if(r!==t||o){if(r===t||!o)break;n++}else n++}return e.substr(0,a-n)}var Mn={escape:function(e,t){if(t){if(wn.test(e))return e.replace(vn,Sn)}else if(kn.test(e))return e.replace(xn,Sn);return e},unescape:En,edit:function(e,t){e=e.source||e,t=t||"";const o={replace:(t,a)=>(a=(a=a.source||a).replace(On,"$1"),e=e.replace(t,a),o),getRegex:()=>new RegExp(e,t)};return o},cleanUrl:function(e,t,o){if(e){let e;try{e=decodeURIComponent(En(o)).replace(Cn,"").toLowerCase()}catch(e){return null}if(0===e.indexOf("javascript:")||0===e.indexOf("vbscript:")||0===e.indexOf("data:"))return null}t&&!zn.test(o)&&(o=In(t,o));try{o=encodeURI(o).replace(/%25/g,"%")}catch(e){return null}return o},resolveUrl:In,noopTest:{exec:function(){}},merge:function(e){let t,o,a=1;for(;a<arguments.length;a++)for(o in t=arguments[a],t)Object.prototype.hasOwnProperty.call(t,o)&&(e[o]=t[o]);return e},splitCells:function(e,t){const o=e.replace(/\|/g,(e,t,o)=>{let a=!1,n=t;for(;--n>=0&&"\\"===o[n];)a=!a;return a?"|":" |"}).split(/ \|/);let a=0;if(o.length>t)o.splice(t);else for(;o.length<t;)o.push("");for(;a<o.length;a++)o[a]=o[a].trim().replace(/\\\|/g,"|");return o},rtrim:Pn,findClosingBracket:function(e,t){if(-1===e.indexOf(t[1]))return-1;const o=e.length;let a=0,n=0;for(;n<o;n++)if("\\"===e[n])n++;else if(e[n]===t[0])a++;else if(e[n]===t[1]&&(a--,a<0))return n;return-1},checkSanitizeDeprecation:function(e){e&&e.sanitize&&!e.silent&&console.warn("marked(): sanitize and sanitizer parameters are deprecated since version 0.7.0, should not be used and will be removed in the future. Read more here: https://marked.js.org/#/USING_ADVANCED.md#options")}};const{noopTest:Ln,edit:Dn,merge:Hn}=Mn,Bn={newline:/^\n+/,code:/^( {4}[^\n]+\n*)+/,fences:/^ {0,3}(`{3,}|~{3,})([^`~\n]*)\n(?:|([\s\S]*?)\n)(?: {0,3}\1[~`]* *(?:\n+|$)|$)/,hr:/^ {0,3}((?:- *){3,}|(?:_ *){3,}|(?:\* *){3,})(?:\n+|$)/,heading:/^ {0,3}(#{1,6}) +([^\n]*?)(?: +#+)? *(?:\n+|$)/,blockquote:/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/,list:/^( {0,3})(bull) [\s\S]+?(?:hr|def|\n{2,}(?! )(?!\1bull )\n*|\s*$)/,html:"^ {0,3}(?:<(script|pre|style)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?\\?>\\n*|<![A-Z][\\s\\S]*?>\\n*|<!\\[CDATA\\[[\\s\\S]*?\\]\\]>\\n*|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:\\n{2,}|$)|<(?!script|pre|style)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:\\n{2,}|$)|</(?!script|pre|style)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:\\n{2,}|$))",def:/^ {0,3}\[(label)\]: *\n? *<?([^\s>]+)>?(?:(?: +\n? *| *\n *)(title))? *(?:\n+|$)/,nptable:Ln,table:Ln,lheading:/^([^\n]+)\n {0,3}(=+|-+) *(?:\n+|$)/,_paragraph:/^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html)[^\n]+)*)/,text:/^[^\n]+/,_label:/(?!\s*\])(?:\\[\[\]]|[^\[\]])+/,_title:/(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/};Bn.def=Dn(Bn.def).replace("label",Bn._label).replace("title",Bn._title).getRegex(),Bn.bullet=/(?:[*+-]|\d{1,9}\.)/,Bn.item=/^( *)(bull) ?[^\n]*(?:\n(?!\1bull ?)[^\n]*)*/,Bn.item=Dn(Bn.item,"gm").replace(/bull/g,Bn.bullet).getRegex(),Bn.list=Dn(Bn.list).replace(/bull/g,Bn.bullet).replace("hr","\\n+(?=\\1?(?:(?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$))").replace("def","\\n+(?="+Bn.def.source+")").getRegex(),Bn._tag="address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|section|source|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul",Bn._comment=/<!--(?!-?>)[\s\S]*?-->/,Bn.html=Dn(Bn.html,"i").replace("comment",Bn._comment).replace("tag",Bn._tag).replace("attribute",/ +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(),Bn.paragraph=Dn(Bn._paragraph).replace("hr",Bn.hr).replace("heading"," {0,3}#{1,6} +").replace("|lheading","").replace("blockquote"," {0,3}>").replace("fences"," {0,3}(?:`{3,}|~{3,})[^`\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|!--)").replace("tag",Bn._tag).getRegex(),Bn.blockquote=Dn(Bn.blockquote).replace("paragraph",Bn.paragraph).getRegex(),Bn.normal=Hn({},Bn),Bn.gfm=Hn({},Bn.normal,{nptable:/^ *([^|\n ].*\|.*)\n *([-:]+ *\|[-| :]*)(?:\n((?:.*[^>\n ].*(?:\n|$))*)\n*|$)/,table:/^ *\|(.+)\n *\|?( *[-:]+[-| :]*)(?:\n((?: *[^>\n ].*(?:\n|$))*)\n*|$)/}),Bn.pedantic=Hn({},Bn.normal,{html:Dn("^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:\"[^\"]*\"|'[^']*'|\\s[^'\"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))").replace("comment",Bn._comment).replace(/tag/g,"(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),def:/^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,heading:/^ *(#{1,6}) *([^\n]+?) *(?:#+ *)?(?:\n+|$)/,fences:Ln,paragraph:Dn(Bn.normal._paragraph).replace("hr",Bn.hr).replace("heading"," *#{1,6} *[^\n]").replace("lheading",Bn.lheading).replace("blockquote"," {0,3}>").replace("|fences","").replace("|list","").replace("|html","").getRegex()});const Un={escape:/^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/,autolink:/^<(scheme:[^\s\x00-\x1f<>]*|email)>/,url:Ln,tag:"^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>",link:/^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/,reflink:/^!?\[(label)\]\[(?!\s*\])((?:\\[\[\]]?|[^\[\]\\])+)\]/,nolink:/^!?\[(?!\s*\])((?:\[[^\[\]]*\]|\\[\[\]]|[^\[\]])*)\](?:\[\])?/,strong:/^__([^\s_])__(?!_)|^\*\*([^\s*])\*\*(?!\*)|^__([^\s][\s\S]*?[^\s])__(?!_)|^\*\*([^\s][\s\S]*?[^\s])\*\*(?!\*)/,em:/^_([^\s_])_(?!_)|^\*([^\s*<\[])\*(?!\*)|^_([^\s<][\s\S]*?[^\s_])_(?!_|[^\spunctuation])|^_([^\s_<][\s\S]*?[^\s])_(?!_|[^\spunctuation])|^\*([^\s<"][\s\S]*?[^\s\*])\*(?!\*|[^\spunctuation])|^\*([^\s*"<\[][\s\S]*?[^\s])\*(?!\*)/,code:/^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/,br:/^( {2,}|\\)\n(?!\s*$)/,del:Ln,text:/^(`+|[^`])(?:[\s\S]*?(?:(?=[\\<!\[`*]|\b_|$)|[^ ](?= {2,}\n))|(?= {2,}\n))/,_punctuation:"!\"#$%&'()*+,\\-./:;<=>?@\\[^_{|}~"};Un.em=Dn(Un.em).replace(/punctuation/g,Un._punctuation).getRegex(),Un._escapes=/\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/g,Un._scheme=/[a-zA-Z][a-zA-Z0-9+.-]{1,31}/,Un._email=/[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/,Un.autolink=Dn(Un.autolink).replace("scheme",Un._scheme).replace("email",Un._email).getRegex(),Un._attribute=/\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/,Un.tag=Dn(Un.tag).replace("comment",Bn._comment).replace("attribute",Un._attribute).getRegex(),Un._label=/(?:\[[^\[\]]*\]|\\.|`[^`]*`|[^\[\]\\`])*?/,Un._href=/<(?:\\[<>]?|[^\s<>\\])*>|[^\s\x00-\x1f]*/,Un._title=/"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/,Un.link=Dn(Un.link).replace("label",Un._label).replace("href",Un._href).replace("title",Un._title).getRegex(),Un.reflink=Dn(Un.reflink).replace("label",Un._label).getRegex(),Un.normal=Hn({},Un),Un.pedantic=Hn({},Un.normal,{strong:/^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/,em:/^_(?=\S)([\s\S]*?\S)_(?!_)|^\*(?=\S)([\s\S]*?\S)\*(?!\*)/,link:Dn(/^!?\[(label)\]\((.*?)\)/).replace("label",Un._label).getRegex(),reflink:Dn(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label",Un._label).getRegex()}),Un.gfm=Hn({},Un.normal,{escape:Dn(Un.escape).replace("])","~|])").getRegex(),_extended_email:/[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/,url:/^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/,_backpedal:/(?:[^?!.,:;*_~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_~)]+(?!$))+/,del:/^~+(?=\S)([\s\S]*?\S)~+/,text:/^(`+|[^`])(?:[\s\S]*?(?:(?=[\\<!\[`*~]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@))|(?= {2,}\n|[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@))/}),Un.gfm.url=Dn(Un.gfm.url,"i").replace("email",Un.gfm._extended_email).getRegex(),Un.breaks=Hn({},Un.gfm,{br:Dn(Un.br).replace("{2,}","*").getRegex(),text:Dn(Un.gfm.text).replace("\\b_","\\b_| {2,}\\n").replace(/\{2,\}/g,"*").getRegex()});var qn={block:Bn,inline:Un};const{defaults:Vn}=yn,{block:Fn}=qn,{rtrim:Gn,splitCells:Wn,escape:Yn}=Mn;var Zn=class e{constructor(e){this.tokens=[],this.tokens.links=Object.create(null),this.options=e||Vn,this.rules=Fn.normal,this.options.pedantic?this.rules=Fn.pedantic:this.options.gfm&&(this.rules=Fn.gfm)}static get rules(){return Fn}static lex(t,o){return new e(o).lex(t)}lex(e){return e=e.replace(/\r\n|\r/g,"\n").replace(/\t/g,"    "),this.token(e,!0)}token(e,t){let o,a,n,r,i,s,l,c,d,p,u,h,g,m,f,_;for(e=e.replace(/^ +$/gm,"");e;)if((n=this.rules.newline.exec(e))&&(e=e.substring(n[0].length),n[0].length>1&&this.tokens.push({type:"space"})),n=this.rules.code.exec(e)){const t=this.tokens[this.tokens.length-1];e=e.substring(n[0].length),t&&"paragraph"===t.type?t.text+="\n"+n[0].trimRight():(n=n[0].replace(/^ {4}/gm,""),this.tokens.push({type:"code",codeBlockStyle:"indented",text:this.options.pedantic?n:Gn(n,"\n")}))}else if(n=this.rules.fences.exec(e))e=e.substring(n[0].length),this.tokens.push({type:"code",lang:n[2]?n[2].trim():n[2],text:n[3]||""});else if(n=this.rules.heading.exec(e))e=e.substring(n[0].length),this.tokens.push({type:"heading",depth:n[1].length,text:n[2]});else if((n=this.rules.nptable.exec(e))&&(s={type:"table",header:Wn(n[1].replace(/^ *| *\| *$/g,"")),align:n[2].replace(/^ *|\| *$/g,"").split(/ *\| */),cells:n[3]?n[3].replace(/\n$/,"").split("\n"):[]},s.header.length===s.align.length)){for(e=e.substring(n[0].length),u=0;u<s.align.length;u++)/^ *-+: *$/.test(s.align[u])?s.align[u]="right":/^ *:-+: *$/.test(s.align[u])?s.align[u]="center":/^ *:-+ *$/.test(s.align[u])?s.align[u]="left":s.align[u]=null;for(u=0;u<s.cells.length;u++)s.cells[u]=Wn(s.cells[u],s.header.length);this.tokens.push(s)}else if(n=this.rules.hr.exec(e))e=e.substring(n[0].length),this.tokens.push({type:"hr"});else if(n=this.rules.blockquote.exec(e))e=e.substring(n[0].length),this.tokens.push({type:"blockquote_start"}),n=n[0].replace(/^ *> ?/gm,""),this.token(n,t),this.tokens.push({type:"blockquote_end"});else if(n=this.rules.list.exec(e)){for(e=e.substring(n[0].length),r=n[2],m=r.length>1,l={type:"list_start",ordered:m,start:m?+r:"",loose:!1},this.tokens.push(l),n=n[0].match(this.rules.item),c=[],o=!1,g=n.length,u=0;u<g;u++)s=n[u],p=s.length,s=s.replace(/^ *([*+-]|\d+\.) */,""),~s.indexOf("\n ")&&(p-=s.length,s=this.options.pedantic?s.replace(/^ {1,4}/gm,""):s.replace(new RegExp("^ {1,"+p+"}","gm"),"")),u!==g-1&&(i=Fn.bullet.exec(n[u+1])[0],(r.length>1?1===i.length:i.length>1||this.options.smartLists&&i!==r)&&(e=n.slice(u+1).join("\n")+e,u=g-1)),a=o||/\n\n(?!\s*$)/.test(s),u!==g-1&&(o="\n"===s.charAt(s.length-1),a||(a=o)),a&&(l.loose=!0),f=/^\[[ xX]\] /.test(s),_=void 0,f&&(_=" "!==s[1],s=s.replace(/^\[[ xX]\] +/,"")),d={type:"list_item_start",task:f,checked:_,loose:a},c.push(d),this.tokens.push(d),this.token(s,!1),this.tokens.push({type:"list_item_end"});if(l.loose)for(g=c.length,u=0;u<g;u++)c[u].loose=!0;this.tokens.push({type:"list_end"})}else if(n=this.rules.html.exec(e))e=e.substring(n[0].length),this.tokens.push({type:this.options.sanitize?"paragraph":"html",pre:!this.options.sanitizer&&("pre"===n[1]||"script"===n[1]||"style"===n[1]),text:this.options.sanitize?this.options.sanitizer?this.options.sanitizer(n[0]):Yn(n[0]):n[0]});else if(t&&(n=this.rules.def.exec(e)))e=e.substring(n[0].length),n[3]&&(n[3]=n[3].substring(1,n[3].length-1)),h=n[1].toLowerCase().replace(/\s+/g," "),this.tokens.links[h]||(this.tokens.links[h]={href:n[2],title:n[3]});else if((n=this.rules.table.exec(e))&&(s={type:"table",header:Wn(n[1].replace(/^ *| *\| *$/g,"")),align:n[2].replace(/^ *|\| *$/g,"").split(/ *\| */),cells:n[3]?n[3].replace(/\n$/,"").split("\n"):[]},s.header.length===s.align.length)){for(e=e.substring(n[0].length),u=0;u<s.align.length;u++)/^ *-+: *$/.test(s.align[u])?s.align[u]="right":/^ *:-+: *$/.test(s.align[u])?s.align[u]="center":/^ *:-+ *$/.test(s.align[u])?s.align[u]="left":s.align[u]=null;for(u=0;u<s.cells.length;u++)s.cells[u]=Wn(s.cells[u].replace(/^ *\| *| *\| *$/g,""),s.header.length);this.tokens.push(s)}else if(n=this.rules.lheading.exec(e))e=e.substring(n[0].length),this.tokens.push({type:"heading",depth:"="===n[2].charAt(0)?1:2,text:n[1]});else if(t&&(n=this.rules.paragraph.exec(e)))e=e.substring(n[0].length),this.tokens.push({type:"paragraph",text:"\n"===n[1].charAt(n[1].length-1)?n[1].slice(0,-1):n[1]});else if(n=this.rules.text.exec(e))e=e.substring(n[0].length),this.tokens.push({type:"text",text:n[0]});else if(e)throw new Error("Infinite loop on byte: "+e.charCodeAt(0));return this.tokens}};const{defaults:Kn}=yn,{cleanUrl:Xn,escape:Jn}=Mn;var Qn=class{constructor(e){this.options=e||Kn}code(e,t,o){const a=(t||"").match(/\S*/)[0];if(this.options.highlight){const t=this.options.highlight(e,a);null!=t&&t!==e&&(o=!0,e=t)}return a?'<pre><code class="'+this.options.langPrefix+Jn(a,!0)+'">'+(o?e:Jn(e,!0))+"</code></pre>\n":"<pre><code>"+(o?e:Jn(e,!0))+"</code></pre>"}blockquote(e){return"<blockquote>\n"+e+"</blockquote>\n"}html(e){return e}heading(e,t,o,a){return this.options.headerIds?"<h"+t+' id="'+this.options.headerPrefix+a.slug(o)+'">'+e+"</h"+t+">\n":"<h"+t+">"+e+"</h"+t+">\n"}hr(){return this.options.xhtml?"<hr/>\n":"<hr>\n"}list(e,t,o){const a=t?"ol":"ul";return"<"+a+(t&&1!==o?' start="'+o+'"':"")+">\n"+e+"</"+a+">\n"}listitem(e){return"<li>"+e+"</li>\n"}checkbox(e){return"<input "+(e?'checked="" ':"")+'disabled="" type="checkbox"'+(this.options.xhtml?" /":"")+"> "}paragraph(e){return"<p>"+e+"</p>\n"}table(e,t){return t&&(t="<tbody>"+t+"</tbody>"),"<table>\n<thead>\n"+e+"</thead>\n"+t+"</table>\n"}tablerow(e){return"<tr>\n"+e+"</tr>\n"}tablecell(e,t){const o=t.header?"th":"td";return(t.align?"<"+o+' align="'+t.align+'">':"<"+o+">")+e+"</"+o+">\n"}strong(e){return"<strong>"+e+"</strong>"}em(e){return"<em>"+e+"</em>"}codespan(e){return"<code>"+e+"</code>"}br(){return this.options.xhtml?"<br/>":"<br>"}del(e){return"<del>"+e+"</del>"}link(e,t,o){if(null===(e=Xn(this.options.sanitize,this.options.baseUrl,e)))return o;let a='<a href="'+Jn(e)+'"';return t&&(a+=' title="'+t+'"'),a+=">"+o+"</a>",a}image(e,t,o){if(null===(e=Xn(this.options.sanitize,this.options.baseUrl,e)))return o;let a='<img src="'+e+'" alt="'+o+'"';return t&&(a+=' title="'+t+'"'),a+=this.options.xhtml?"/>":">",a}text(e){return e}},er=class{constructor(){this.seen={}}slug(e){let t=e.toLowerCase().trim().replace(/[\u2000-\u206F\u2E00-\u2E7F\\'!"#$%&()*+,./:;<=>?@[\]^`{|}~]/g,"").replace(/\s/g,"-");if(this.seen.hasOwnProperty(t)){const e=t;do{this.seen[e]++,t=e+"-"+this.seen[e]}while(this.seen.hasOwnProperty(t))}return this.seen[t]=0,t}};const{defaults:tr}=yn,{inline:or}=qn,{findClosingBracket:ar,escape:nr}=Mn;var rr=class e{constructor(e,t){if(this.options=t||tr,this.links=e,this.rules=or.normal,this.options.renderer=this.options.renderer||new Qn,this.renderer=this.options.renderer,this.renderer.options=this.options,!this.links)throw new Error("Tokens array requires a `links` property.");this.options.pedantic?this.rules=or.pedantic:this.options.gfm&&(this.options.breaks?this.rules=or.breaks:this.rules=or.gfm)}static get rules(){return or}static output(t,o,a){return new e(o,a).output(t)}output(t){let o,a,n,r,i,s,l="";for(;t;)if(i=this.rules.escape.exec(t))t=t.substring(i[0].length),l+=nr(i[1]);else if(i=this.rules.tag.exec(t))!this.inLink&&/^<a /i.test(i[0])?this.inLink=!0:this.inLink&&/^<\/a>/i.test(i[0])&&(this.inLink=!1),!this.inRawBlock&&/^<(pre|code|kbd|script)(\s|>)/i.test(i[0])?this.inRawBlock=!0:this.inRawBlock&&/^<\/(pre|code|kbd|script)(\s|>)/i.test(i[0])&&(this.inRawBlock=!1),t=t.substring(i[0].length),l+=this.options.sanitize?this.options.sanitizer?this.options.sanitizer(i[0]):nr(i[0]):i[0];else if(i=this.rules.link.exec(t)){const a=ar(i[2],"()");if(a>-1){const e=(0===i[0].indexOf("!")?5:4)+i[1].length+a;i[2]=i[2].substring(0,a),i[0]=i[0].substring(0,e).trim(),i[3]=""}t=t.substring(i[0].length),this.inLink=!0,n=i[2],this.options.pedantic?(o=/^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(n),o?(n=o[1],r=o[3]):r=""):r=i[3]?i[3].slice(1,-1):"",n=n.trim().replace(/^<([\s\S]*)>$/,"$1"),l+=this.outputLink(i,{href:e.escapes(n),title:e.escapes(r)}),this.inLink=!1}else if((i=this.rules.reflink.exec(t))||(i=this.rules.nolink.exec(t))){if(t=t.substring(i[0].length),o=(i[2]||i[1]).replace(/\s+/g," "),o=this.links[o.toLowerCase()],!o||!o.href){l+=i[0].charAt(0),t=i[0].substring(1)+t;continue}this.inLink=!0,l+=this.outputLink(i,o),this.inLink=!1}else if(i=this.rules.strong.exec(t))t=t.substring(i[0].length),l+=this.renderer.strong(this.output(i[4]||i[3]||i[2]||i[1]));else if(i=this.rules.em.exec(t))t=t.substring(i[0].length),l+=this.renderer.em(this.output(i[6]||i[5]||i[4]||i[3]||i[2]||i[1]));else if(i=this.rules.code.exec(t))t=t.substring(i[0].length),l+=this.renderer.codespan(nr(i[2].trim(),!0));else if(i=this.rules.br.exec(t))t=t.substring(i[0].length),l+=this.renderer.br();else if(i=this.rules.del.exec(t))t=t.substring(i[0].length),l+=this.renderer.del(this.output(i[1]));else if(i=this.rules.autolink.exec(t))t=t.substring(i[0].length),"@"===i[2]?(a=nr(this.mangle(i[1])),n="mailto:"+a):(a=nr(i[1]),n=a),l+=this.renderer.link(n,null,a);else if(this.inLink||!(i=this.rules.url.exec(t))){if(i=this.rules.text.exec(t))t=t.substring(i[0].length),this.inRawBlock?l+=this.renderer.text(this.options.sanitize?this.options.sanitizer?this.options.sanitizer(i[0]):nr(i[0]):i[0]):l+=this.renderer.text(nr(this.smartypants(i[0])));else if(t)throw new Error("Infinite loop on byte: "+t.charCodeAt(0))}else{if("@"===i[2])a=nr(i[0]),n="mailto:"+a;else{do{s=i[0],i[0]=this.rules._backpedal.exec(i[0])[0]}while(s!==i[0]);a=nr(i[0]),n="www."===i[1]?"http://"+a:a}t=t.substring(i[0].length),l+=this.renderer.link(n,null,a)}return l}static escapes(t){return t?t.replace(e.rules._escapes,"$1"):t}outputLink(e,t){const o=t.href,a=t.title?nr(t.title):null;return"!"!==e[0].charAt(0)?this.renderer.link(o,a,this.output(e[1])):this.renderer.image(o,a,nr(e[1]))}smartypants(e){return this.options.smartypants?e.replace(/---/g,"—").replace(/--/g,"–").replace(/(^|[-\u2014/(\[{"\s])'/g,"$1‘").replace(/'/g,"’").replace(/(^|[-\u2014/(\[{\u2018\s])"/g,"$1“").replace(/"/g,"”").replace(/\.{3}/g,"…"):e}mangle(e){if(!this.options.mangle)return e;const t=e.length;let o,a="",n=0;for(;n<t;n++)o=e.charCodeAt(n),Math.random()>.5&&(o="x"+o.toString(16)),a+="&#"+o+";";return a}},ir=class{strong(e){return e}em(e){return e}codespan(e){return e}del(e){return e}text(e){return e}link(e,t,o){return""+o}image(e,t,o){return""+o}br(){return""}};const{defaults:sr}=yn,{merge:lr,unescape:cr}=Mn;var dr=class e{constructor(e){this.tokens=[],this.token=null,this.options=e||sr,this.options.renderer=this.options.renderer||new Qn,this.renderer=this.options.renderer,this.renderer.options=this.options,this.slugger=new er}static parse(t,o){return new e(o).parse(t)}parse(e){this.inline=new rr(e.links,this.options),this.inlineText=new rr(e.links,lr({},this.options,{renderer:new ir})),this.tokens=e.reverse();let t="";for(;this.next();)t+=this.tok();return t}next(){return this.token=this.tokens.pop(),this.token}peek(){return this.tokens[this.tokens.length-1]||0}parseText(){let e=this.token.text;for(;"text"===this.peek().type;)e+="\n"+this.next().text;return this.inline.output(e)}tok(){let e="";switch(this.token.type){case"space":return"";case"hr":return this.renderer.hr();case"heading":return this.renderer.heading(this.inline.output(this.token.text),this.token.depth,cr(this.inlineText.output(this.token.text)),this.slugger);case"code":return this.renderer.code(this.token.text,this.token.lang,this.token.escaped);case"table":{let t,o,a,n,r="";for(a="",t=0;t<this.token.header.length;t++)a+=this.renderer.tablecell(this.inline.output(this.token.header[t]),{header:!0,align:this.token.align[t]});for(r+=this.renderer.tablerow(a),t=0;t<this.token.cells.length;t++){for(o=this.token.cells[t],a="",n=0;n<o.length;n++)a+=this.renderer.tablecell(this.inline.output(o[n]),{header:!1,align:this.token.align[n]});e+=this.renderer.tablerow(a)}return this.renderer.table(r,e)}case"blockquote_start":for(e="";"blockquote_end"!==this.next().type;)e+=this.tok();return this.renderer.blockquote(e);case"list_start":{e="";const t=this.token.ordered,o=this.token.start;for(;"list_end"!==this.next().type;)e+=this.tok();return this.renderer.list(e,t,o)}case"list_item_start":{e="";const t=this.token.loose,o=this.token.checked,a=this.token.task;if(this.token.task)if(t)if("text"===this.peek().type){const e=this.peek();e.text=this.renderer.checkbox(o)+" "+e.text}else this.tokens.push({type:"text",text:this.renderer.checkbox(o)});else e+=this.renderer.checkbox(o);for(;"list_item_end"!==this.next().type;)e+=t||"text"!==this.token.type?this.tok():this.parseText();return this.renderer.listitem(e,a,o)}case"html":return this.renderer.html(this.token.text);case"paragraph":return this.renderer.paragraph(this.inline.output(this.token.text));case"text":return this.renderer.paragraph(this.parseText());default:{const e='Token with "'+this.token.type+'" type was not found.';if(!this.options.silent)throw new Error(e);console.log(e)}}}};const{merge:pr,checkSanitizeDeprecation:ur,escape:hr}=Mn,{getDefaults:gr,changeDefaults:mr,defaults:fr}=yn;function _r(e,t,o){if(null==e)throw new Error("marked(): input parameter is undefined or null");if("string"!=typeof e)throw new Error("marked(): input parameter is of type "+Object.prototype.toString.call(e)+", string expected");if(o||"function"==typeof t){o||(o=t,t=null),t=pr({},_r.defaults,t||{}),ur(t);const a=t.highlight;let n,r,i=0;try{n=Zn.lex(e,t)}catch(e){return o(e)}r=n.length;const s=function(e){if(e)return t.highlight=a,o(e);let r;try{r=dr.parse(n,t)}catch(t){e=t}return t.highlight=a,e?o(e):o(null,r)};if(!a||a.length<3)return s();if(delete t.highlight,!r)return s();for(;i<n.length;i++)!function(e){"code"!==e.type?--r||s():a(e.text,e.lang,(function(t,o){return t?s(t):null==o||o===e.text?--r||s():(e.text=o,e.escaped=!0,void(--r||s()))}))}(n[i])}else try{return t=pr({},_r.defaults,t||{}),ur(t),dr.parse(Zn.lex(e,t),t)}catch(e){if(e.message+="\nPlease report this to https://github.com/markedjs/marked.",(t||_r.defaults).silent)return"<p>An error occurred:</p><pre>"+hr(e.message+"",!0)+"</pre>";throw e}}_r.options=_r.setOptions=function(e){return pr(_r.defaults,e),mr(_r.defaults),_r},_r.getDefaults=gr,_r.defaults=fr,_r.Parser=dr,_r.parser=dr.parse,_r.Renderer=Qn,_r.TextRenderer=ir,_r.Lexer=Zn,_r.lexer=Zn.lex,_r.InlineLexer=rr,_r.inlineLexer=rr.output,_r.Slugger=er,_r.parse=_r;var br=_r;function yr(){var e={"align-content":!1,"align-items":!1,"align-self":!1,"alignment-adjust":!1,"alignment-baseline":!1,all:!1,"anchor-point":!1,animation:!1,"animation-delay":!1,"animation-direction":!1,"animation-duration":!1,"animation-fill-mode":!1,"animation-iteration-count":!1,"animation-name":!1,"animation-play-state":!1,"animation-timing-function":!1,azimuth:!1,"backface-visibility":!1,background:!0,"background-attachment":!0,"background-clip":!0,"background-color":!0,"background-image":!0,"background-origin":!0,"background-position":!0,"background-repeat":!0,"background-size":!0,"baseline-shift":!1,binding:!1,bleed:!1,"bookmark-label":!1,"bookmark-level":!1,"bookmark-state":!1,border:!0,"border-bottom":!0,"border-bottom-color":!0,"border-bottom-left-radius":!0,"border-bottom-right-radius":!0,"border-bottom-style":!0,"border-bottom-width":!0,"border-collapse":!0,"border-color":!0,"border-image":!0,"border-image-outset":!0,"border-image-repeat":!0,"border-image-slice":!0,"border-image-source":!0,"border-image-width":!0,"border-left":!0,"border-left-color":!0,"border-left-style":!0,"border-left-width":!0,"border-radius":!0,"border-right":!0,"border-right-color":!0,"border-right-style":!0,"border-right-width":!0,"border-spacing":!0,"border-style":!0,"border-top":!0,"border-top-color":!0,"border-top-left-radius":!0,"border-top-right-radius":!0,"border-top-style":!0,"border-top-width":!0,"border-width":!0,bottom:!1,"box-decoration-break":!0,"box-shadow":!0,"box-sizing":!0,"box-snap":!0,"box-suppress":!0,"break-after":!0,"break-before":!0,"break-inside":!0,"caption-side":!1,chains:!1,clear:!0,clip:!1,"clip-path":!1,"clip-rule":!1,color:!0,"color-interpolation-filters":!0,"column-count":!1,"column-fill":!1,"column-gap":!1,"column-rule":!1,"column-rule-color":!1,"column-rule-style":!1,"column-rule-width":!1,"column-span":!1,"column-width":!1,columns:!1,contain:!1,content:!1,"counter-increment":!1,"counter-reset":!1,"counter-set":!1,crop:!1,cue:!1,"cue-after":!1,"cue-before":!1,cursor:!1,direction:!1,display:!0,"display-inside":!0,"display-list":!0,"display-outside":!0,"dominant-baseline":!1,elevation:!1,"empty-cells":!1,filter:!1,flex:!1,"flex-basis":!1,"flex-direction":!1,"flex-flow":!1,"flex-grow":!1,"flex-shrink":!1,"flex-wrap":!1,float:!1,"float-offset":!1,"flood-color":!1,"flood-opacity":!1,"flow-from":!1,"flow-into":!1,font:!0,"font-family":!0,"font-feature-settings":!0,"font-kerning":!0,"font-language-override":!0,"font-size":!0,"font-size-adjust":!0,"font-stretch":!0,"font-style":!0,"font-synthesis":!0,"font-variant":!0,"font-variant-alternates":!0,"font-variant-caps":!0,"font-variant-east-asian":!0,"font-variant-ligatures":!0,"font-variant-numeric":!0,"font-variant-position":!0,"font-weight":!0,grid:!1,"grid-area":!1,"grid-auto-columns":!1,"grid-auto-flow":!1,"grid-auto-rows":!1,"grid-column":!1,"grid-column-end":!1,"grid-column-start":!1,"grid-row":!1,"grid-row-end":!1,"grid-row-start":!1,"grid-template":!1,"grid-template-areas":!1,"grid-template-columns":!1,"grid-template-rows":!1,"hanging-punctuation":!1,height:!0,hyphens:!1,icon:!1,"image-orientation":!1,"image-resolution":!1,"ime-mode":!1,"initial-letters":!1,"inline-box-align":!1,"justify-content":!1,"justify-items":!1,"justify-self":!1,left:!1,"letter-spacing":!0,"lighting-color":!0,"line-box-contain":!1,"line-break":!1,"line-grid":!1,"line-height":!1,"line-snap":!1,"line-stacking":!1,"line-stacking-ruby":!1,"line-stacking-shift":!1,"line-stacking-strategy":!1,"list-style":!0,"list-style-image":!0,"list-style-position":!0,"list-style-type":!0,margin:!0,"margin-bottom":!0,"margin-left":!0,"margin-right":!0,"margin-top":!0,"marker-offset":!1,"marker-side":!1,marks:!1,mask:!1,"mask-box":!1,"mask-box-outset":!1,"mask-box-repeat":!1,"mask-box-slice":!1,"mask-box-source":!1,"mask-box-width":!1,"mask-clip":!1,"mask-image":!1,"mask-origin":!1,"mask-position":!1,"mask-repeat":!1,"mask-size":!1,"mask-source-type":!1,"mask-type":!1,"max-height":!0,"max-lines":!1,"max-width":!0,"min-height":!0,"min-width":!0,"move-to":!1,"nav-down":!1,"nav-index":!1,"nav-left":!1,"nav-right":!1,"nav-up":!1,"object-fit":!1,"object-position":!1,opacity:!1,order:!1,orphans:!1,outline:!1,"outline-color":!1,"outline-offset":!1,"outline-style":!1,"outline-width":!1,overflow:!1,"overflow-wrap":!1,"overflow-x":!1,"overflow-y":!1,padding:!0,"padding-bottom":!0,"padding-left":!0,"padding-right":!0,"padding-top":!0,page:!1,"page-break-after":!1,"page-break-before":!1,"page-break-inside":!1,"page-policy":!1,pause:!1,"pause-after":!1,"pause-before":!1,perspective:!1,"perspective-origin":!1,pitch:!1,"pitch-range":!1,"play-during":!1,position:!1,"presentation-level":!1,quotes:!1,"region-fragment":!1,resize:!1,rest:!1,"rest-after":!1,"rest-before":!1,richness:!1,right:!1,rotation:!1,"rotation-point":!1,"ruby-align":!1,"ruby-merge":!1,"ruby-position":!1,"shape-image-threshold":!1,"shape-outside":!1,"shape-margin":!1,size:!1,speak:!1,"speak-as":!1,"speak-header":!1,"speak-numeral":!1,"speak-punctuation":!1,"speech-rate":!1,stress:!1,"string-set":!1,"tab-size":!1,"table-layout":!1,"text-align":!0,"text-align-last":!0,"text-combine-upright":!0,"text-decoration":!0,"text-decoration-color":!0,"text-decoration-line":!0,"text-decoration-skip":!0,"text-decoration-style":!0,"text-emphasis":!0,"text-emphasis-color":!0,"text-emphasis-position":!0,"text-emphasis-style":!0,"text-height":!0,"text-indent":!0,"text-justify":!0,"text-orientation":!0,"text-overflow":!0,"text-shadow":!0,"text-space-collapse":!0,"text-transform":!0,"text-underline-position":!0,"text-wrap":!0,top:!1,transform:!1,"transform-origin":!1,"transform-style":!1,transition:!1,"transition-delay":!1,"transition-duration":!1,"transition-property":!1,"transition-timing-function":!1,"unicode-bidi":!1,"vertical-align":!1,visibility:!1,"voice-balance":!1,"voice-duration":!1,"voice-family":!1,"voice-pitch":!1,"voice-range":!1,"voice-rate":!1,"voice-stress":!1,"voice-volume":!1,volume:!1,"white-space":!1,widows:!1,width:!0,"will-change":!1,"word-break":!0,"word-spacing":!0,"word-wrap":!0,"wrap-flow":!1,"wrap-through":!1,"writing-mode":!1,"z-index":!1};return e}var wr=/javascript\s*\:/gim;var vr={whiteList:yr(),getDefaultWhiteList:yr,onAttr:function(e,t,o){},onIgnoreAttr:function(e,t,o){},safeAttrValue:function(e,t){return wr.test(t)?"":t}},kr={indexOf:function(e,t){var o,a;if(Array.prototype.indexOf)return e.indexOf(t);for(o=0,a=e.length;o<a;o++)if(e[o]===t)return o;return-1},forEach:function(e,t,o){var a,n;if(Array.prototype.forEach)return e.forEach(t,o);for(a=0,n=e.length;a<n;a++)t.call(o,e[a],a,e)},trim:function(e){return String.prototype.trim?e.trim():e.replace(/(^\s*)|(\s*$)/g,"")},trimRight:function(e){return String.prototype.trimRight?e.trimRight():e.replace(/(\s*$)/g,"")}};var xr=function(e,t){";"!==(e=kr.trimRight(e))[e.length-1]&&(e+=";");var o=e.length,a=!1,n=0,r=0,i="";function s(){if(!a){var o=kr.trim(e.slice(n,r)),s=o.indexOf(":");if(-1!==s){var l=kr.trim(o.slice(0,s)),c=kr.trim(o.slice(s+1));if(l){var d=t(n,i.length,l,c,o);d&&(i+=d+"; ")}}}n=r+1}for(;r<o;r++){var l=e[r];if("/"===l&&"*"===e[r+1]){var c=e.indexOf("*/",r+2);if(-1===c)break;n=(r=c+1)+1,a=!1}else"("===l?a=!0:")"===l?a=!1:";"===l?a||s():"\n"===l&&s()}return kr.trim(i)};function Ar(e){return null==e}function Sr(e){(e=function(e){var t={};for(var o in e)t[o]=e[o];return t}(e||{})).whiteList=e.whiteList||vr.whiteList,e.onAttr=e.onAttr||vr.onAttr,e.onIgnoreAttr=e.onIgnoreAttr||vr.onIgnoreAttr,e.safeAttrValue=e.safeAttrValue||vr.safeAttrValue,this.options=e}Sr.prototype.process=function(e){if(!(e=(e=e||"").toString()))return"";var t=this.options,o=t.whiteList,a=t.onAttr,n=t.onIgnoreAttr,r=t.safeAttrValue;return xr(e,(function(e,t,i,s,l){var c=o[i],d=!1;if(!0===c?d=c:"function"==typeof c?d=c(s):c instanceof RegExp&&(d=c.test(s)),!0!==d&&(d=!1),s=r(i,s)){var p,u={position:t,sourcePosition:e,source:l,isWhite:d};return d?Ar(p=a(i,s,u))?i+":"+s:p:Ar(p=n(i,s,u))?void 0:p}}))};var jr=Sr,Er=Zo((function(e,t){for(var o in(t=e.exports=function(e,t){return new jr(t).process(e)}).FilterCSS=jr,vr)t[o]=vr[o];"undefined"!=typeof window&&(window.filterCSS=e.exports)})),Or=(Er.FilterCSS,{indexOf:function(e,t){var o,a;if(Array.prototype.indexOf)return e.indexOf(t);for(o=0,a=e.length;o<a;o++)if(e[o]===t)return o;return-1},forEach:function(e,t,o){var a,n;if(Array.prototype.forEach)return e.forEach(t,o);for(a=0,n=e.length;a<n;a++)t.call(o,e[a],a,e)},trim:function(e){return String.prototype.trim?e.trim():e.replace(/(^\s*)|(\s*$)/g,"")},spaceIndex:function(e){var t=/\s|\n|\t/.exec(e);return t?t.index:-1}}),Cr=Er.FilterCSS,zr=Er.getDefaultWhiteList;function Tr(){return{a:["target","href","title"],abbr:["title"],address:[],area:["shape","coords","href","alt"],article:[],aside:[],audio:["autoplay","controls","loop","preload","src"],b:[],bdi:["dir"],bdo:["dir"],big:[],blockquote:["cite"],br:[],caption:[],center:[],cite:[],code:[],col:["align","valign","span","width"],colgroup:["align","valign","span","width"],dd:[],del:["datetime"],details:["open"],div:[],dl:[],dt:[],em:[],font:["color","size","face"],footer:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],header:[],hr:[],i:[],img:["src","alt","title","width","height"],ins:["datetime"],li:[],mark:[],nav:[],ol:[],p:[],pre:[],s:[],section:[],small:[],span:[],sub:[],sup:[],strong:[],table:["width","border","align","valign"],tbody:["align","valign"],td:["width","rowspan","colspan","align","valign"],tfoot:["align","valign"],th:["width","rowspan","colspan","align","valign"],thead:["align","valign"],tr:["rowspan","align","valign"],tt:[],u:[],ul:[],video:["autoplay","controls","loop","preload","src","height","width"]}}var $r=new Cr;function Rr(e){return e.replace(Nr,"&lt;").replace(Ir,"&gt;")}var Nr=/</g,Ir=/>/g,Pr=/"/g,Mr=/&quot;/g,Lr=/&#([a-zA-Z0-9]*);?/gim,Dr=/&colon;?/gim,Hr=/&newline;?/gim,Br=/((j\s*a\s*v\s*a|v\s*b|l\s*i\s*v\s*e)\s*s\s*c\s*r\s*i\s*p\s*t\s*|m\s*o\s*c\s*h\s*a)\:/gi,Ur=/e\s*x\s*p\s*r\s*e\s*s\s*s\s*i\s*o\s*n\s*\(.*/gi,qr=/u\s*r\s*l\s*\(.*/gi;function Vr(e){return e.replace(Pr,"&quot;")}function Fr(e){return e.replace(Mr,'"')}function Gr(e){return e.replace(Lr,(function(e,t){return"x"===t[0]||"X"===t[0]?String.fromCharCode(parseInt(t.substr(1),16)):String.fromCharCode(parseInt(t,10))}))}function Wr(e){return e.replace(Dr,":").replace(Hr," ")}function Yr(e){for(var t="",o=0,a=e.length;o<a;o++)t+=e.charCodeAt(o)<32?" ":e.charAt(o);return Or.trim(t)}function Zr(e){return e=Yr(e=Wr(e=Gr(e=Fr(e))))}function Kr(e){return e=Rr(e=Vr(e))}var Xr=/<!--[\s\S]*?-->/g;var Jr={whiteList:{a:["target","href","title"],abbr:["title"],address:[],area:["shape","coords","href","alt"],article:[],aside:[],audio:["autoplay","controls","loop","preload","src"],b:[],bdi:["dir"],bdo:["dir"],big:[],blockquote:["cite"],br:[],caption:[],center:[],cite:[],code:[],col:["align","valign","span","width"],colgroup:["align","valign","span","width"],dd:[],del:["datetime"],details:["open"],div:[],dl:[],dt:[],em:[],font:["color","size","face"],footer:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],header:[],hr:[],i:[],img:["src","alt","title","width","height"],ins:["datetime"],li:[],mark:[],nav:[],ol:[],p:[],pre:[],s:[],section:[],small:[],span:[],sub:[],sup:[],strong:[],table:["width","border","align","valign"],tbody:["align","valign"],td:["width","rowspan","colspan","align","valign"],tfoot:["align","valign"],th:["width","rowspan","colspan","align","valign"],thead:["align","valign"],tr:["rowspan","align","valign"],tt:[],u:[],ul:[],video:["autoplay","controls","loop","preload","src","height","width"]},getDefaultWhiteList:Tr,onTag:function(e,t,o){},onIgnoreTag:function(e,t,o){},onTagAttr:function(e,t,o){},onIgnoreTagAttr:function(e,t,o){},safeAttrValue:function(e,t,o,a){if(o=Zr(o),"href"===t||"src"===t){if("#"===(o=Or.trim(o)))return"#";if("http://"!==o.substr(0,7)&&"https://"!==o.substr(0,8)&&"mailto:"!==o.substr(0,7)&&"tel:"!==o.substr(0,4)&&"#"!==o[0]&&"/"!==o[0])return""}else if("background"===t){if(Br.lastIndex=0,Br.test(o))return""}else if("style"===t){if(Ur.lastIndex=0,Ur.test(o))return"";if(qr.lastIndex=0,qr.test(o)&&(Br.lastIndex=0,Br.test(o)))return"";!1!==a&&(o=(a=a||$r).process(o))}return o=Kr(o)},escapeHtml:Rr,escapeQuote:Vr,unescapeQuote:Fr,escapeHtmlEntities:Gr,escapeDangerHtml5Entities:Wr,clearNonPrintableCharacter:Yr,friendlyAttrValue:Zr,escapeAttrValue:Kr,onIgnoreTagStripAll:function(){return""},StripTagBody:function(e,t){"function"!=typeof t&&(t=function(){});var o=!Array.isArray(e),a=[],n=!1;return{onIgnoreTag:function(r,i,s){if(function(t){return!!o||-1!==Or.indexOf(e,t)}(r)){if(s.isClosing){var l="[/removed]",c=s.position+l.length;return a.push([!1!==n?n:s.position,c]),n=!1,l}return n||(n=s.position),"[removed]"}return t(r,i,s)},remove:function(e){var t="",o=0;return Or.forEach(a,(function(a){t+=e.slice(o,a[0]),o=a[1]})),t+=e.slice(o)}}},stripCommentTag:function(e){return e.replace(Xr,"")},stripBlankChar:function(e){var t=e.split("");return(t=t.filter((function(e){var t=e.charCodeAt(0);return 127!==t&&(!(t<=31)||(10===t||13===t))}))).join("")},cssFilter:$r,getDefaultCSSWhiteList:zr};function Qr(e){var t=Or.spaceIndex(e);if(-1===t)var o=e.slice(1,-1);else o=e.slice(1,t+1);return"/"===(o=Or.trim(o).toLowerCase()).slice(0,1)&&(o=o.slice(1)),"/"===o.slice(-1)&&(o=o.slice(0,-1)),o}function ei(e){return"</"===e.slice(0,2)}var ti=/[^a-zA-Z0-9_:\.\-]/gim;function oi(e,t){for(;t<e.length;t++){var o=e[t];if(" "!==o)return"="===o?t:-1}}function ai(e,t){for(;t>0;t--){var o=e[t];if(" "!==o)return"="===o?t:-1}}function ni(e){return function(e){return'"'===e[0]&&'"'===e[e.length-1]||"'"===e[0]&&"'"===e[e.length-1]}(e)?e.substr(1,e.length-2):e}var ri={parseTag:function(e,t,o){var a="",n=0,r=!1,i=!1,s=0,l=e.length,c="",d="";for(s=0;s<l;s++){var p=e.charAt(s);if(!1===r){if("<"===p){r=s;continue}}else if(!1===i){if("<"===p){a+=o(e.slice(n,s)),r=s,n=s;continue}if(">"===p){a+=o(e.slice(n,r)),c=Qr(d=e.slice(r,s+1)),a+=t(r,a.length,c,d,ei(d)),n=s+1,r=!1;continue}if(('"'===p||"'"===p)&&"="===e.charAt(s-1)){i=p;continue}}else if(p===i){i=!1;continue}}return n<e.length&&(a+=o(e.substr(n))),a},parseAttr:function(e,t){var o=0,a=[],n=!1,r=e.length;function i(e,o){if(!((e=(e=Or.trim(e)).replace(ti,"").toLowerCase()).length<1)){var n=t(e,o||"");n&&a.push(n)}}for(var s=0;s<r;s++){var l,c=e.charAt(s);if(!1!==n||"="!==c)if(!1===n||s!==o||'"'!==c&&"'"!==c||"="!==e.charAt(s-1))if(/\s|\n|\t/.test(c)){if(e=e.replace(/\s|\n|\t/g," "),!1===n){if(-1===(l=oi(e,s))){i(Or.trim(e.slice(o,s))),n=!1,o=s+1;continue}s=l-1;continue}if(-1===(l=ai(e,s-1))){i(n,ni(Or.trim(e.slice(o,s)))),n=!1,o=s+1;continue}}else;else{if(-1===(l=e.indexOf(c,s+1)))break;i(n,Or.trim(e.slice(o+1,l))),n=!1,o=(s=l)+1}else n=e.slice(o,s),o=s+1}return o<e.length&&(!1===n?i(e.slice(o)):i(n,ni(Or.trim(e.slice(o))))),Or.trim(a.join(" "))}},ii=Er.FilterCSS,si=ri.parseTag,li=ri.parseAttr;function ci(e){return null==e}function di(e){(e=function(e){var t={};for(var o in e)t[o]=e[o];return t}(e||{})).stripIgnoreTag&&(e.onIgnoreTag&&console.error('Notes: cannot use these two options "stripIgnoreTag" and "onIgnoreTag" at the same time'),e.onIgnoreTag=Jr.onIgnoreTagStripAll),e.whiteList=e.whiteList||Jr.whiteList,e.onTag=e.onTag||Jr.onTag,e.onTagAttr=e.onTagAttr||Jr.onTagAttr,e.onIgnoreTag=e.onIgnoreTag||Jr.onIgnoreTag,e.onIgnoreTagAttr=e.onIgnoreTagAttr||Jr.onIgnoreTagAttr,e.safeAttrValue=e.safeAttrValue||Jr.safeAttrValue,e.escapeHtml=e.escapeHtml||Jr.escapeHtml,this.options=e,!1===e.css?this.cssFilter=!1:(e.css=e.css||{},this.cssFilter=new ii(e.css))}di.prototype.process=function(e){if(!(e=(e=e||"").toString()))return"";var t=this.options,o=t.whiteList,a=t.onTag,n=t.onIgnoreTag,r=t.onTagAttr,i=t.onIgnoreTagAttr,s=t.safeAttrValue,l=t.escapeHtml,c=this.cssFilter;t.stripBlankChar&&(e=Jr.stripBlankChar(e)),t.allowCommentTag||(e=Jr.stripCommentTag(e));var d=!1;if(t.stripIgnoreTagBody){d=Jr.StripTagBody(t.stripIgnoreTagBody,n);n=d.onIgnoreTag}var p=si(e,(function(e,t,d,p,u){var h,g={sourcePosition:e,position:t,isClosing:u,isWhite:o.hasOwnProperty(d)};if(!ci(h=a(d,p,g)))return h;if(g.isWhite){if(g.isClosing)return"</"+d+">";var m=function(e){var t=Or.spaceIndex(e);if(-1===t)return{html:"",closing:"/"===e[e.length-2]};var o="/"===(e=Or.trim(e.slice(t+1,-1)))[e.length-1];return o&&(e=Or.trim(e.slice(0,-1))),{html:e,closing:o}}(p),f=o[d],_=li(m.html,(function(e,t){var o,a=-1!==Or.indexOf(f,e);return ci(o=r(d,e,t,a))?a?(t=s(d,e,t,c))?e+'="'+t+'"':e:ci(o=i(d,e,t,a))?void 0:o:o}));p="<"+d;return _&&(p+=" "+_),m.closing&&(p+=" /"),p+=">"}return ci(h=n(d,p,g))?l(p):h}),l);return d&&(p=d.remove(p)),p};var pi=di,ui=Zo((function(e,t){function o(e,t){return new pi(t).process(e)}for(var a in(t=e.exports=o).filterXSS=o,t.FilterXSS=pi,Jr)t[a]=Jr[a];for(var a in ri)t[a]=ri[a];"undefined"!=typeof window&&(window.filterXSS=e.exports),"undefined"!=typeof self&&"undefined"!=typeof DedicatedWorkerGlobalScope&&self instanceof DedicatedWorkerGlobalScope&&(self.filterXSS=e.exports)})),hi=ui.filterXSS,gi=(ui.FilterXSS,Zo((function(e,t){!function(e){var o="object"==typeof window&&window||"object"==typeof self&&self;t.nodeType?o&&(o.hljs=e({})):e(t)}((function(e){var t=[],o=Object.keys,a={},n={},r=!0,i=/^(no-?highlight|plain|text)$/i,s=/\blang(?:uage)?-([\w-]+)\b/i,l=/((^(<[^>]+>|\t|)+|(?:\n)))/gm,c="</span>",d="Could not find the language '{}', did you forget to load/include a language module?",p={classPrefix:"hljs-",tabReplace:null,useBR:!1,languages:void 0},u="of and for in not or if then".split(" ");function h(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;")}function g(e){return e.nodeName.toLowerCase()}function m(e){return i.test(e)}function f(e){var t,o={},a=Array.prototype.slice.call(arguments,1);for(t in e)o[t]=e[t];return a.forEach((function(e){for(t in e)o[t]=e[t]})),o}function _(e){var t=[];return function e(o,a){for(var n=o.firstChild;n;n=n.nextSibling)3===n.nodeType?a+=n.nodeValue.length:1===n.nodeType&&(t.push({event:"start",offset:a,node:n}),a=e(n,a),g(n).match(/br|hr|img|input/)||t.push({event:"stop",offset:a,node:n}));return a}(e,0),t}function b(e){return e.variants&&!e.cached_variants&&(e.cached_variants=e.variants.map((function(t){return f(e,{variants:null},t)}))),e.cached_variants?e.cached_variants:function e(t){return!!t&&(t.endsWithParent||e(t.starts))}(e)?[f(e,{starts:e.starts?f(e.starts):null})]:Object.isFrozen(e)?[f(e)]:[e]}function y(e,t){return t?Number(t):(o=e,-1!=u.indexOf(o.toLowerCase())?0:1);var o}function w(e){function t(e){return e&&e.source||e}function a(o,a){return new RegExp(t(o),"m"+(e.case_insensitive?"i":"")+(a?"g":""))}function n(e){var o,n,r={},i=[],s={},l=1;function c(e,t){r[l]=e,i.push([e,t]),l+=function(e){return new RegExp(e.toString()+"|").exec("").length-1}(t)+1}for(var d=0;d<e.contains.length;d++){c(n=e.contains[d],n.beginKeywords?"\\.?(?:"+n.begin+")\\.?":n.begin)}e.terminator_end&&c("end",e.terminator_end),e.illegal&&c("illegal",e.illegal);var p=i.map((function(e){return e[1]}));return o=a(function(e,o){for(var a=/\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./,n=0,r="",i=0;i<e.length;i++){var s=n+=1,l=t(e[i]);for(i>0&&(r+=o),r+="(";l.length>0;){var c=a.exec(l);if(null==c){r+=l;break}r+=l.substring(0,c.index),l=l.substring(c.index+c[0].length),"\\"==c[0][0]&&c[1]?r+="\\"+String(Number(c[1])+s):(r+=c[0],"("==c[0]&&n++)}r+=")"}return r}(p,"|"),!0),s.lastIndex=0,s.exec=function(t){var a;if(0===i.length)return null;o.lastIndex=s.lastIndex;var n=o.exec(t);if(!n)return null;for(var l=0;l<n.length;l++)if(null!=n[l]&&null!=r[""+l]){a=r[""+l];break}return"string"==typeof a?(n.type=a,n.extra=[e.illegal,e.terminator_end]):(n.type="begin",n.rule=a),n},s}if(e.contains&&-1!=e.contains.indexOf("self")){if(!r)throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");e.contains=e.contains.filter((function(e){return"self"!=e}))}!function r(i,s){i.compiled||(i.compiled=!0,i.keywords=i.keywords||i.beginKeywords,i.keywords&&(i.keywords=function(e,t){var a={};return"string"==typeof e?n("keyword",e):o(e).forEach((function(t){n(t,e[t])})),a;function n(e,o){t&&(o=o.toLowerCase()),o.split(" ").forEach((function(t){var o=t.split("|");a[o[0]]=[e,y(o[0],o[1])]}))}}(i.keywords,e.case_insensitive)),i.lexemesRe=a(i.lexemes||/\w+/,!0),s&&(i.beginKeywords&&(i.begin="\\b("+i.beginKeywords.split(" ").join("|")+")\\b"),i.begin||(i.begin=/\B|\b/),i.beginRe=a(i.begin),i.endSameAsBegin&&(i.end=i.begin),i.end||i.endsWithParent||(i.end=/\B|\b/),i.end&&(i.endRe=a(i.end)),i.terminator_end=t(i.end)||"",i.endsWithParent&&s.terminator_end&&(i.terminator_end+=(i.end?"|":"")+s.terminator_end)),i.illegal&&(i.illegalRe=a(i.illegal)),null==i.relevance&&(i.relevance=1),i.contains||(i.contains=[]),i.contains=Array.prototype.concat.apply([],i.contains.map((function(e){return b("self"===e?i:e)}))),i.contains.forEach((function(e){r(e,i)})),i.starts&&r(i.starts,s),i.terminators=n(i))}(e)}function v(e,t,o,n){function i(e,t){var o=b.case_insensitive?t[0].toLowerCase():t[0];return e.keywords.hasOwnProperty(o)&&e.keywords[o]}function s(e,t,o,a){if(!o&&""===t)return"";if(!e)return t;var n='<span class="'+(a?"":p.classPrefix);return(n+=e+'">')+t+(o?"":c)}function l(){S+=null!=x.subLanguage?function(){var e="string"==typeof x.subLanguage;if(e&&!a[x.subLanguage])return h(j);var t=e?v(x.subLanguage,j,!0,A[x.subLanguage]):k(j,x.subLanguage.length?x.subLanguage:void 0);return x.relevance>0&&(O+=t.relevance),e&&(A[x.subLanguage]=t.top),s(t.language,t.value,!1,!0)}():function(){var e,t,o,a;if(!x.keywords)return h(j);for(a="",t=0,x.lexemesRe.lastIndex=0,o=x.lexemesRe.exec(j);o;)a+=h(j.substring(t,o.index)),(e=i(x,o))?(O+=e[1],a+=s(e[0],h(o[0]))):a+=h(o[0]),t=x.lexemesRe.lastIndex,o=x.lexemesRe.exec(j);return a+h(j.substr(t))}(),j=""}function u(e){S+=e.className?s(e.className,"",!0):"",x=Object.create(e,{parent:{value:x}})}function g(e){var t=e[0],o=e.rule;return o&&o.endSameAsBegin&&(o.endRe=function(e){return new RegExp(e.replace(/[-\/\\^$*+?.()|[\]{}]/g,"\\$&"),"m")}(t)),o.skip?j+=t:(o.excludeBegin&&(j+=t),l(),o.returnBegin||o.excludeBegin||(j=t)),u(o),o.returnBegin?0:t.length}function m(e){var o=e[0],a=t.substr(e.index),n=function e(t,o){if(function(e,t){var o=e&&e.exec(t);return o&&0===o.index}(t.endRe,o)){for(;t.endsParent&&t.parent;)t=t.parent;return t}if(t.endsWithParent)return e(t.parent,o)}(x,a);if(n){var r=x;r.skip?j+=o:(r.returnEnd||r.excludeEnd||(j+=o),l(),r.excludeEnd&&(j=o));do{x.className&&(S+=c),x.skip||x.subLanguage||(O+=x.relevance),x=x.parent}while(x!==n.parent);return n.starts&&(n.endSameAsBegin&&(n.starts.endRe=n.endRe),u(n.starts)),r.returnEnd?0:o.length}}var f={};function _(e,a){var n=a&&a[0];if(j+=e,null==n)return l(),0;if("begin"==f.type&&"end"==a.type&&f.index==a.index&&""===n)return j+=t.slice(a.index,a.index+1),1;if(f=a,"begin"===a.type)return g(a);if("illegal"===a.type&&!o)throw new Error('Illegal lexeme "'+n+'" for mode "'+(x.className||"<unnamed>")+'"');if("end"===a.type){var r=m(a);if(null!=r)return r}return j+=n,n.length}var b=E(e);if(!b)throw console.error(d.replace("{}",e)),new Error('Unknown language: "'+e+'"');w(b);var y,x=n||b,A={},S="";for(y=x;y!==b;y=y.parent)y.className&&(S=s(y.className,"",!0)+S);var j="",O=0;try{for(var C,z,T=0;x.terminators.lastIndex=T,C=x.terminators.exec(t);)z=_(t.substring(T,C.index),C),T=C.index+z;for(_(t.substr(T)),y=x;y.parent;y=y.parent)y.className&&(S+=c);return{relevance:O,value:S,illegal:!1,language:e,top:x}}catch(o){if(o.message&&-1!==o.message.indexOf("Illegal"))return{illegal:!0,relevance:0,value:h(t)};if(r)return{relevance:0,value:h(t),language:e,top:x,errorRaised:o};throw o}}function k(e,t){t=t||p.languages||o(a);var n={relevance:0,value:h(e)},r=n;return t.filter(E).filter(O).forEach((function(t){var o=v(t,e,!1);o.language=t,o.relevance>r.relevance&&(r=o),o.relevance>n.relevance&&(r=n,n=o)})),r.language&&(n.second_best=r),n}function x(e){return p.tabReplace||p.useBR?e.replace(l,(function(e,t){return p.useBR&&"\n"===e?"<br>":p.tabReplace?t.replace(/\t/g,p.tabReplace):""})):e}function A(e){var o,a,r,i,l,c=function(e){var t,o,a,n,r=e.className+" ";if(r+=e.parentNode?e.parentNode.className:"",o=s.exec(r)){var i=E(o[1]);return i||(console.warn(d.replace("{}",o[1])),console.warn("Falling back to no-highlight mode for this block.",e)),i?o[1]:"no-highlight"}for(t=0,a=(r=r.split(/\s+/)).length;t<a;t++)if(m(n=r[t])||E(n))return n}(e);m(c)||(p.useBR?(o=document.createElement("div")).innerHTML=e.innerHTML.replace(/\n/g,"").replace(/<br[ \/]*>/g,"\n"):o=e,l=o.textContent,r=c?v(c,l,!0):k(l),(a=_(o)).length&&((i=document.createElement("div")).innerHTML=r.value,r.value=function(e,o,a){var n=0,r="",i=[];function s(){return e.length&&o.length?e[0].offset!==o[0].offset?e[0].offset<o[0].offset?e:o:"start"===o[0].event?e:o:e.length?e:o}function l(e){r+="<"+g(e)+t.map.call(e.attributes,(function(e){return" "+e.nodeName+'="'+h(e.value).replace(/"/g,"&quot;")+'"'})).join("")+">"}function c(e){r+="</"+g(e)+">"}function d(e){("start"===e.event?l:c)(e.node)}for(;e.length||o.length;){var p=s();if(r+=h(a.substring(n,p[0].offset)),n=p[0].offset,p===e){i.reverse().forEach(c);do{d(p.splice(0,1)[0]),p=s()}while(p===e&&p.length&&p[0].offset===n);i.reverse().forEach(l)}else"start"===p[0].event?i.push(p[0].node):i.pop(),d(p.splice(0,1)[0])}return r+h(a.substr(n))}(a,_(i),l)),r.value=x(r.value),e.innerHTML=r.value,e.className=function(e,t,o){var a=t?n[t]:o,r=[e.trim()];return e.match(/\bhljs\b/)||r.push("hljs"),-1===e.indexOf(a)&&r.push(a),r.join(" ").trim()}(e.className,c,r.language),e.result={language:r.language,re:r.relevance},r.second_best&&(e.second_best={language:r.second_best.language,re:r.second_best.relevance}))}function S(){if(!S.called){S.called=!0;var e=document.querySelectorAll("pre code");t.forEach.call(e,A)}}var j={disableAutodetect:!0};function E(e){return e=(e||"").toLowerCase(),a[e]||a[n[e]]}function O(e){var t=E(e);return t&&!t.disableAutodetect}return e.highlight=v,e.highlightAuto=k,e.fixMarkup=x,e.highlightBlock=A,e.configure=function(e){p=f(p,e)},e.initHighlighting=S,e.initHighlightingOnLoad=function(){window.addEventListener("DOMContentLoaded",S,!1),window.addEventListener("load",S,!1)},e.registerLanguage=function(t,o){var i;try{i=o(e)}catch(e){if(console.error("Language definition for '{}' could not be registered.".replace("{}",t)),!r)throw e;console.error(e),i=j}a[t]=i,i.rawDefinition=o.bind(null,e),i.aliases&&i.aliases.forEach((function(e){n[e]=t}))},e.listLanguages=function(){return o(a)},e.getLanguage=E,e.requireLanguage=function(e){var t=E(e);if(t)return t;throw new Error("The '{}' language is required, but not loaded.".replace("{}",e))},e.autoDetection=O,e.inherit=f,e.debugMode=function(){r=!1},e.IDENT_RE="[a-zA-Z]\\w*",e.UNDERSCORE_IDENT_RE="[a-zA-Z_]\\w*",e.NUMBER_RE="\\b\\d+(\\.\\d+)?",e.C_NUMBER_RE="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",e.BINARY_NUMBER_RE="\\b(0b[01]+)",e.RE_STARTERS_RE="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",e.BACKSLASH_ESCAPE={begin:"\\\\[\\s\\S]",relevance:0},e.APOS_STRING_MODE={className:"string",begin:"'",end:"'",illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},e.QUOTE_STRING_MODE={className:"string",begin:'"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},e.PHRASAL_WORDS_MODE={begin:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},e.COMMENT=function(t,o,a){var n=e.inherit({className:"comment",begin:t,end:o,contains:[]},a||{});return n.contains.push(e.PHRASAL_WORDS_MODE),n.contains.push({className:"doctag",begin:"(?:TODO|FIXME|NOTE|BUG|XXX):",relevance:0}),n},e.C_LINE_COMMENT_MODE=e.COMMENT("//","$"),e.C_BLOCK_COMMENT_MODE=e.COMMENT("/\\*","\\*/"),e.HASH_COMMENT_MODE=e.COMMENT("#","$"),e.NUMBER_MODE={className:"number",begin:e.NUMBER_RE,relevance:0},e.C_NUMBER_MODE={className:"number",begin:e.C_NUMBER_RE,relevance:0},e.BINARY_NUMBER_MODE={className:"number",begin:e.BINARY_NUMBER_RE,relevance:0},e.CSS_NUMBER_MODE={className:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},e.REGEXP_MODE={className:"regexp",begin:/\//,end:/\/[gimuy]*/,illegal:/\n/,contains:[e.BACKSLASH_ESCAPE,{begin:/\[/,end:/\]/,relevance:0,contains:[e.BACKSLASH_ESCAPE]}]},e.TITLE_MODE={className:"title",begin:e.IDENT_RE,relevance:0},e.UNDERSCORE_TITLE_MODE={className:"title",begin:e.UNDERSCORE_IDENT_RE,relevance:0},e.METHOD_GUARD={begin:"\\.\\s*"+e.UNDERSCORE_IDENT_RE,relevance:0},[e.BACKSLASH_ESCAPE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,e.PHRASAL_WORDS_MODE,e.COMMENT,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.HASH_COMMENT_MODE,e.NUMBER_MODE,e.C_NUMBER_MODE,e.BINARY_NUMBER_MODE,e.CSS_NUMBER_MODE,e.REGEXP_MODE,e.TITLE_MODE,e.UNDERSCORE_TITLE_MODE,e.METHOD_GUARD].forEach((function(e){!function e(t){Object.freeze(t);var o="function"==typeof t;return Object.getOwnPropertyNames(t).forEach((function(a){!t.hasOwnProperty(a)||null===t[a]||"object"!=typeof t[a]&&"function"!=typeof t[a]||o&&("caller"===a||"callee"===a||"arguments"===a)||Object.isFrozen(t[a])||e(t[a])})),t}(e)})),e}))})));const mi=ce`
  /*

github.com style (c) Vasily Polovnyov <vast@whiteants.net>

*/

  .hljs {
    display: block;
    overflow-x: auto;
    padding: 0.5em;
    color: #333;
    background: #f8f8f8;
  }

  .hljs-comment,
  .hljs-quote {
    color: #998;
    font-style: italic;
  }

  .hljs-keyword,
  .hljs-selector-tag,
  .hljs-subst {
    color: #333;
    font-weight: bold;
  }

  .hljs-number,
  .hljs-literal,
  .hljs-variable,
  .hljs-template-variable,
  .hljs-tag .hljs-attr {
    color: #008080;
  }

  .hljs-string,
  .hljs-doctag {
    color: #d14;
  }

  .hljs-title,
  .hljs-section,
  .hljs-selector-id {
    color: #900;
    font-weight: bold;
  }

  .hljs-subst {
    font-weight: normal;
  }

  .hljs-type,
  .hljs-class .hljs-title {
    color: #458;
    font-weight: bold;
  }

  .hljs-tag,
  .hljs-name,
  .hljs-attribute {
    color: #000080;
    font-weight: normal;
  }

  .hljs-regexp,
  .hljs-link {
    color: #009926;
  }

  .hljs-symbol,
  .hljs-bullet {
    color: #990073;
  }

  .hljs-built_in,
  .hljs-builtin-name {
    color: #0086b3;
  }

  .hljs-meta {
    color: #999;
    font-weight: bold;
  }

  .hljs-deletion {
    background: #fdd;
  }

  .hljs-addition {
    background: #dfd;
  }

  .hljs-emphasis {
    font-style: italic;
  }

  .hljs-strong {
    font-weight: bold;
  }
`,fi=[ce`
  @font-face {
    font-family: octicons-link;
    src: url(data:font/woff;charset=utf-8;base64,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)
      format("woff");
  }
`,ce`
  .markdown-body .octicon {
    display: inline-block;
    fill: currentColor;
    vertical-align: text-bottom;
  }

  .markdown-body .anchor {
    float: left;
    line-height: 1;
    margin-left: -20px;
    padding-right: 4px;
  }

  .markdown-body .anchor:focus {
    outline: none;
  }

  .markdown-body h1 .octicon-link,
  .markdown-body h2 .octicon-link,
  .markdown-body h3 .octicon-link,
  .markdown-body h4 .octicon-link,
  .markdown-body h5 .octicon-link,
  .markdown-body h6 .octicon-link {
    color: #1b1f23;
    vertical-align: middle;
    visibility: hidden;
  }

  .markdown-body h1:hover .anchor,
  .markdown-body h2:hover .anchor,
  .markdown-body h3:hover .anchor,
  .markdown-body h4:hover .anchor,
  .markdown-body h5:hover .anchor,
  .markdown-body h6:hover .anchor {
    text-decoration: none;
  }

  .markdown-body h1:hover .anchor .octicon-link,
  .markdown-body h2:hover .anchor .octicon-link,
  .markdown-body h3:hover .anchor .octicon-link,
  .markdown-body h4:hover .anchor .octicon-link,
  .markdown-body h5:hover .anchor .octicon-link,
  .markdown-body h6:hover .anchor .octicon-link {
    visibility: visible;
  }
  .markdown-body {
    -ms-text-size-adjust: 100%;
    -webkit-text-size-adjust: 100%;
    line-height: 1.5;
    font-family: -apple-system, BlinkMacSystemFont, Segoe UI, Helvetica, Arial,
      sans-serif, Apple Color Emoji, Segoe UI Emoji;
    font-size: 16px;
    line-height: 1.5;
    word-wrap: break-word;
  }

  .markdown-body .pl-c {
    color: #6a737d;
  }

  .markdown-body .pl-c1,
  .markdown-body .pl-s .pl-v {
    color: #005cc5;
  }

  .markdown-body .pl-e,
  .markdown-body .pl-en {
    color: #6f42c1;
  }

  .markdown-body .pl-s .pl-s1,
  .markdown-body .pl-smi {
    color: #24292e;
  }

  .markdown-body .pl-ent {
    color: #22863a;
  }

  .markdown-body .pl-k {
    color: #d73a49;
  }

  .markdown-body .pl-pds,
  .markdown-body .pl-s,
  .markdown-body .pl-s .pl-pse .pl-s1,
  .markdown-body .pl-sr,
  .markdown-body .pl-sr .pl-cce,
  .markdown-body .pl-sr .pl-sra,
  .markdown-body .pl-sr .pl-sre {
    color: #032f62;
  }

  .markdown-body .pl-smw,
  .markdown-body .pl-v {
    color: #e36209;
  }

  .markdown-body .pl-bu {
    color: #b31d28;
  }

  .markdown-body .pl-ii {
    color: #fafbfc;
    background-color: #b31d28;
  }

  .markdown-body .pl-c2 {
    color: #fafbfc;
    background-color: #d73a49;
  }

  .markdown-body .pl-c2:before {
    content: "^M";
  }

  .markdown-body .pl-sr .pl-cce {
    font-weight: 700;
    color: #22863a;
  }

  .markdown-body .pl-ml {
    color: #735c0f;
  }

  .markdown-body .pl-mh,
  .markdown-body .pl-mh .pl-en,
  .markdown-body .pl-ms {
    font-weight: 700;
    color: #005cc5;
  }

  .markdown-body .pl-mi {
    font-style: italic;
    color: #24292e;
  }

  .markdown-body .pl-mb {
    font-weight: 700;
    color: #24292e;
  }

  .markdown-body .pl-md {
    color: #b31d28;
    background-color: #ffeef0;
  }

  .markdown-body .pl-mi1 {
    color: #22863a;
    background-color: #f0fff4;
  }

  .markdown-body .pl-mc {
    color: #e36209;
    background-color: #ffebda;
  }

  .markdown-body .pl-mi2 {
    color: #f6f8fa;
    background-color: #005cc5;
  }

  .markdown-body .pl-mdr {
    font-weight: 700;
    color: #6f42c1;
  }

  .markdown-body .pl-ba {
    color: #586069;
  }

  .markdown-body .pl-sg {
    color: #959da5;
  }

  .markdown-body .pl-corl {
    text-decoration: underline;
    color: #032f62;
  }

  .markdown-body details {
    display: block;
  }

  .markdown-body summary {
    display: list-item;
  }

  .markdown-body a {
    background-color: initial;
  }

  .markdown-body a:active,
  .markdown-body a:hover {
    outline-width: 0;
  }

  .markdown-body strong {
    font-weight: inherit;
    font-weight: bolder;
  }

  .markdown-body h1 {
    font-size: 2em;
    margin: 0.67em 0;
  }

  .markdown-body img {
    border-style: none;
  }

  .markdown-body code,
  .markdown-body kbd,
  .markdown-body pre {
    font-family: monospace, monospace;
    font-size: 1em;
  }

  .markdown-body hr {
    box-sizing: initial;
    height: 0;
    overflow: visible;
  }

  .markdown-body input {
    font: inherit;
    margin: 0;
  }

  .markdown-body input {
    overflow: visible;
  }

  .markdown-body [type="checkbox"] {
    box-sizing: border-box;
    padding: 0;
  }

  .markdown-body * {
    box-sizing: border-box;
  }

  .markdown-body input {
    font-family: inherit;
    font-size: inherit;
    line-height: inherit;
  }

  .markdown-body a {
    color: var(--link-text-color, var(--accent-color));
    font-weight: 600;
    text-decoration: none;
  }

  .markdown-body a:hover {
    text-decoration: underline;
  }

  .markdown-body strong {
    font-weight: 600;
  }

  .markdown-body hr {
    height: 0;
    margin: 15px 0;
    overflow: hidden;
    background: transparent;
    border: 0;
    border-bottom: 1px solid #dfe2e5;
  }

  .markdown-body hr:after,
  .markdown-body hr:before {
    display: table;
    content: "";
  }

  .markdown-body hr:after {
    clear: both;
  }

  .markdown-body table {
    border-spacing: 0;
    border-collapse: collapse;
  }

  .markdown-body td,
  .markdown-body th {
    padding: 0;
  }

  .markdown-body details summary {
    cursor: pointer;
  }

  .markdown-body kbd {
    display: inline-block;
    padding: 3px 5px;
    font: 11px SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
    line-height: 10px;
    color: #444d56;
    vertical-align: middle;
    background-color: #fafbfc;
    border: 1px solid #d1d5da;
    border-radius: 3px;
    box-shadow: inset 0 -1px 0 #d1d5da;
  }

  .markdown-body h1,
  .markdown-body h2,
  .markdown-body h3,
  .markdown-body h4,
  .markdown-body h5,
  .markdown-body h6 {
    margin-top: 0;
    margin-bottom: 0;
  }

  .markdown-body h1 {
    font-size: 32px;
  }

  .markdown-body h1,
  .markdown-body h2 {
    font-weight: 600;
  }

  .markdown-body h2 {
    font-size: 24px;
  }

  .markdown-body h3 {
    font-size: 20px;
  }

  .markdown-body h3,
  .markdown-body h4 {
    font-weight: 600;
  }

  .markdown-body h4 {
    font-size: 16px;
  }

  .markdown-body h5 {
    font-size: 14px;
  }

  .markdown-body h5,
  .markdown-body h6 {
    font-weight: 600;
  }

  .markdown-body h6 {
    font-size: 12px;
  }

  .markdown-body p {
    margin-top: 0;
    margin-bottom: 10px;
  }

  .markdown-body blockquote {
    margin: 0;
  }

  .markdown-body ol,
  .markdown-body ul {
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0;
  }

  .markdown-body ol ol,
  .markdown-body ul ol {
    list-style-type: lower-roman;
  }

  .markdown-body ol ol ol,
  .markdown-body ol ul ol,
  .markdown-body ul ol ol,
  .markdown-body ul ul ol {
    list-style-type: lower-alpha;
  }

  .markdown-body dd {
    margin-left: 0;
  }

  .markdown-body code,
  .markdown-body pre {
    font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
    font-size: 12px;
  }

  .markdown-body pre {
    margin-top: 0;
    margin-bottom: 0;
  }

  .markdown-body input::-webkit-inner-spin-button,
  .markdown-body input::-webkit-outer-spin-button {
    margin: 0;
    -webkit-appearance: none;
    appearance: none;
  }

  .markdown-body .border {
    border: 1px solid #e1e4e8 !important;
  }

  .markdown-body .border-0 {
    border: 0 !important;
  }

  .markdown-body .border-bottom {
    border-bottom: 1px solid #e1e4e8 !important;
  }

  .markdown-body .rounded-1 {
    border-radius: 3px !important;
  }

  .markdown-body .bg-white {
    background-color: #fff !important;
  }

  .markdown-body .bg-gray-light {
    background-color: #fafbfc !important;
  }

  .markdown-body .text-gray-light {
    color: #6a737d !important;
  }

  .markdown-body .mb-0 {
    margin-bottom: 0 !important;
  }

  .markdown-body .my-2 {
    margin-top: 8px !important;
    margin-bottom: 8px !important;
  }

  .markdown-body .pl-0 {
    padding-left: 0 !important;
  }

  .markdown-body .py-0 {
    padding-top: 0 !important;
    padding-bottom: 0 !important;
  }

  .markdown-body .pl-1 {
    padding-left: 4px !important;
  }

  .markdown-body .pl-2 {
    padding-left: 8px !important;
  }

  .markdown-body .py-2 {
    padding-top: 8px !important;
    padding-bottom: 8px !important;
  }

  .markdown-body .pl-3,
  .markdown-body .px-3 {
    padding-left: 16px !important;
  }

  .markdown-body .px-3 {
    padding-right: 16px !important;
  }

  .markdown-body .pl-4 {
    padding-left: 24px !important;
  }

  .markdown-body .pl-5 {
    padding-left: 32px !important;
  }

  .markdown-body .pl-6 {
    padding-left: 40px !important;
  }

  .markdown-body .f6 {
    font-size: 12px !important;
  }

  .markdown-body .lh-condensed {
    line-height: 1.25 !important;
  }

  .markdown-body .text-bold {
    font-weight: 600 !important;
  }

  .markdown-body .pl-7 {
    padding-left: 48px !important;
  }

  .markdown-body .pl-8 {
    padding-left: 64px !important;
  }

  .markdown-body .pl-9 {
    padding-left: 80px !important;
  }

  .markdown-body .pl-10 {
    padding-left: 96px !important;
  }

  .markdown-body .pl-11 {
    padding-left: 112px !important;
  }

  .markdown-body .pl-12 {
    padding-left: 128px !important;
  }

  .markdown-body hr {
    border-bottom-color: #eee;
  }

  .markdown-body kbd {
    display: inline-block;
    padding: 3px 5px;
    font: 11px SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
    line-height: 10px;
    color: #444d56;
    vertical-align: middle;
    background-color: #fafbfc;
    border: 1px solid #d1d5da;
    border-radius: 3px;
    box-shadow: inset 0 -1px 0 #d1d5da;
  }

  .markdown-body:after,
  .markdown-body:before {
    display: table;
    content: "";
  }

  .markdown-body:after {
    clear: both;
  }

  .markdown-body > :first-child {
    margin-top: 0 !important;
  }

  .markdown-body > :last-child {
    margin-bottom: 0 !important;
  }

  .markdown-body a:not([href]) {
    color: inherit;
    text-decoration: none;
  }
`,ce`
  .markdown-body blockquote,
  .markdown-body details,
  .markdown-body dl,
  .markdown-body ol,
  .markdown-body p,
  .markdown-body pre,
  .markdown-body table,
  .markdown-body ul {
    margin-top: 0;
    margin-bottom: 16px;
  }

  .markdown-body hr {
    height: 0.25em;
    padding: 0;
    margin: 24px 0;
    background-color: #e1e4e8;
    border: 0;
  }

  .markdown-body blockquote {
    padding: 0 1em;
    color: #6a737d;
    border-left: 0.25em solid #dfe2e5;
  }

  .markdown-body blockquote > :first-child {
    margin-top: 0;
  }

  .markdown-body blockquote > :last-child {
    margin-bottom: 0;
  }

  .markdown-body h1,
  .markdown-body h2,
  .markdown-body h3,
  .markdown-body h4,
  .markdown-body h5,
  .markdown-body h6 {
    margin-top: 24px;
    margin-bottom: 16px;
    font-weight: 600;
    line-height: 1.25;
  }

  .markdown-body h1 {
    font-size: 2em;
  }

  .markdown-body h1,
  .markdown-body h2 {
    padding-bottom: 0.3em;
    border-bottom: 1px solid #eaecef;
  }

  .markdown-body h2 {
    font-size: 1.5em;
  }

  .markdown-body h3 {
    font-size: 1.25em;
  }

  .markdown-body h4 {
    font-size: 1em;
  }

  .markdown-body h5 {
    font-size: 0.875em;
  }

  .markdown-body h6 {
    font-size: 0.85em;
    color: #6a737d;
  }

  .markdown-body ol,
  .markdown-body ul {
    padding-left: 2em;
  }

  .markdown-body ol ol,
  .markdown-body ol ul,
  .markdown-body ul ol,
  .markdown-body ul ul {
    margin-top: 0;
    margin-bottom: 0;
  }

  .markdown-body li {
    word-wrap: break-all;
  }

  .markdown-body li > p {
    margin-top: 16px;
  }

  .markdown-body li + li {
    margin-top: 0.25em;
  }

  .markdown-body dl {
    padding: 0;
  }

  .markdown-body dl dt {
    padding: 0;
    margin-top: 16px;
    font-size: 1em;
    font-style: italic;
    font-weight: 600;
  }

  .markdown-body dl dd {
    padding: 0 16px;
    margin-bottom: 16px;
  }

  .markdown-body table {
    display: block;
    width: 100%;
    overflow: auto;
  }

  .markdown-body table th {
    font-weight: 600;
  }

  .markdown-body table td,
  .markdown-body table th {
    padding: 6px 13px;
    border: 1px solid #dfe2e5;
  }

  .markdown-body table th {
    background-color: var(--primary-background-color, #fff);
  }

  .markdown-body table tr {
    background-color: hsla(var(--primary-background-color, #fff), 0.1);
    border-top: 1px solid #c6cbd1;
  }

  .markdown-body table tr:nth-child(2n) {
    background-color: var(--primary-background-color, #fff);
  }

  .markdown-body img {
    max-width: 100%;
    box-sizing: initial;
    background-color: #fff;
    border-radius: var(--ha-card-border-radius);
  }

  .markdown-body img[align="right"] {
    padding-left: 20px;
  }

  .markdown-body img[align="left"] {
    padding-right: 20px;
  }

  .markdown-body code {
    padding: 0.2em 0.4em;
    margin: 0;
    font-size: 85%;
    background-color: rgba(27, 31, 35, 0.05);
    border-radius: 3px;
  }

  .markdown-body pre {
    word-wrap: normal;
  }

  .markdown-body pre > code {
    padding: 0;
    margin: 0;
    font-size: 100%;
    word-break: normal;
    white-space: pre;
    background: transparent;
    border: 0;
  }

  .markdown-body .highlight {
    margin-bottom: 16px;
  }

  .markdown-body .highlight pre {
    margin-bottom: 0;
    word-break: normal;
  }

  .markdown-body .highlight pre,
  .markdown-body pre {
    padding: 16px;
    overflow: auto;
    font-size: 85%;
    line-height: 1.45;
    background-color: var(--primary-background-color, #f6f8fa);
    border-radius: var(--ha-card-border-radius, 3px);
  }

  .markdown-body pre code {
    display: inline;
    max-width: auto;
    padding: 0;
    margin: 0;
    overflow: visible;
    line-height: inherit;
    word-wrap: normal;
    background-color: initial;
    border: 0;
  }

  .markdown-body .commit-tease-sha {
    display: inline-block;
    font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
    font-size: 90%;
    color: #444d56;
  }

  .markdown-body .full-commit .btn-outline:not(:disabled):hover {
    color: #005cc5;
    border-color: #005cc5;
  }

  .markdown-body .blob-wrapper {
    overflow-x: auto;
    overflow-y: hidden;
  }

  .markdown-body .blob-wrapper-embedded {
    max-height: 240px;
    overflow-y: auto;
  }

  .markdown-body .blob-num {
    width: 1%;
    min-width: 50px;
    padding-right: 10px;
    padding-left: 10px;
    font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
    font-size: 12px;
    line-height: 20px;
    color: rgba(27, 31, 35, 0.3);
    text-align: right;
    white-space: nowrap;
    vertical-align: top;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
  }

  .markdown-body .blob-num:hover {
    color: rgba(27, 31, 35, 0.6);
  }

  .markdown-body .blob-num:before {
    content: attr(data-line-number);
  }

  .markdown-body .blob-code {
    position: relative;
    padding-right: 10px;
    padding-left: 10px;
    line-height: 20px;
    vertical-align: top;
  }

  .markdown-body .blob-code-inner {
    overflow: visible;
    font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
    font-size: 12px;
    color: #24292e;
    word-wrap: normal;
    white-space: pre;
  }

  .markdown-body .pl-token.active,
  .markdown-body .pl-token:hover {
    cursor: pointer;
    background: #ffea7f;
  }

  .markdown-body :checked + .radio-label {
    position: relative;
    z-index: 1;
    border-color: var(--link-text-color, var(--accent-color));
  }

  .markdown-body
    .select-menu-item
    input[type="radio"]:not(:checked)
    + .octicon-check,
  .markdown-body
    .select-menu-item
    input[type="radio"]:not(:checked)
    + .octicon-circle-slash {
    visibility: hidden;
  }

  .markdown-body .pl-7 {
    padding-left: 48px !important;
  }

  .markdown-body .pl-8 {
    padding-left: 64px !important;
  }

  .markdown-body .pl-9 {
    padding-left: 80px !important;
  }

  .markdown-body .pl-10 {
    padding-left: 96px !important;
  }

  .markdown-body .pl-11 {
    padding-left: 112px !important;
  }

  .markdown-body .pl-12 {
    padding-left: 128px !important;
  }

  .markdown-body .tab-size[data-tab-size="1"] {
    -moz-tab-size: 1;
    tab-size: 1;
  }

  .markdown-body .tab-size[data-tab-size="2"] {
    -moz-tab-size: 2;
    tab-size: 2;
  }

  .markdown-body .tab-size[data-tab-size="3"] {
    -moz-tab-size: 3;
    tab-size: 3;
  }

  .markdown-body .tab-size[data-tab-size="4"] {
    -moz-tab-size: 4;
    tab-size: 4;
  }

  .markdown-body .tab-size[data-tab-size="5"] {
    -moz-tab-size: 5;
    tab-size: 5;
  }

  .markdown-body .tab-size[data-tab-size="6"] {
    -moz-tab-size: 6;
    tab-size: 6;
  }

  .markdown-body .tab-size[data-tab-size="7"] {
    -moz-tab-size: 7;
    tab-size: 7;
  }

  .markdown-body .tab-size[data-tab-size="8"] {
    -moz-tab-size: 8;
    tab-size: 8;
  }

  .markdown-body .tab-size[data-tab-size="9"] {
    -moz-tab-size: 9;
    tab-size: 9;
  }

  .markdown-body .tab-size[data-tab-size="10"] {
    -moz-tab-size: 10;
    tab-size: 10;
  }

  .markdown-body .tab-size[data-tab-size="11"] {
    -moz-tab-size: 11;
    tab-size: 11;
  }

  .markdown-body .tab-size[data-tab-size="12"] {
    -moz-tab-size: 12;
    tab-size: 12;
  }

  .markdown-body .task-list-item {
    list-style-type: none;
  }

  .markdown-body .task-list-item + .task-list-item {
    margin-top: 3px;
  }

  .markdown-body .task-list-item input {
    margin: 0 0.2em 0.25em -1.6em;
    vertical-align: middle;
  }
`];gi.registerLanguage("yaml",(function(e){var t={className:"string",relevance:0,variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/\S+/}],contains:[e.BACKSLASH_ESCAPE,{className:"template-variable",variants:[{begin:"{{",end:"}}"},{begin:"%{",end:"}"}]}]};return{case_insensitive:!0,aliases:["yml","YAML","yaml"],contains:[{className:"attr",variants:[{begin:"\\w[\\w :\\/.-]*:(?=[ \t]|$)"},{begin:'"\\w[\\w :\\/.-]*":(?=[ \t]|$)'},{begin:"'\\w[\\w :\\/.-]*':(?=[ \t]|$)"}]},{className:"meta",begin:"^---s*$",relevance:10},{className:"string",begin:"[\\|>]([0-9]?[+-])?[ ]*\\n( *)[\\S ]+\\n(\\2[\\S ]+\\n?)*"},{begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:"!"+e.UNDERSCORE_IDENT_RE},{className:"type",begin:"!!"+e.UNDERSCORE_IDENT_RE},{className:"meta",begin:"&"+e.UNDERSCORE_IDENT_RE+"$"},{className:"meta",begin:"\\*"+e.UNDERSCORE_IDENT_RE+"$"},{className:"bullet",begin:"\\-(?=[ ]|$)",relevance:0},e.HASH_COMMENT_MODE,{beginKeywords:"true false yes no null",keywords:{literal:"true false yes no null"}},{className:"number",begin:e.C_NUMBER_RE+"\\b"},t]}}));const _i=gi,bi=br;bi.setOptions({highlight:function(e,t){return t&&_i.getLanguage(t)?_i.highlight(t,e,!0).value:_i.highlightAuto(e).value},breaks:!0,gfm:!0,tables:!0,langPrefix:""});let yi=class extends pe{render(){if("0"===String(this.authors.length))return N``;let e=[];const t=document.createElement("div");return t.className="seperator",t.innerText=",",this.authors.forEach(o=>{const a=document.createElement("a");a.href=`https://github.com/${o.replace("@","")}`,a.target="_blank",a.className="author",a.innerText=o.replace("@",""),e.push(a),e.push(t)}),e.pop(),N`
      <div>
        <p>
        <div class="authors">
          <b>${Wo("repository.authors")}: </b>
          ${e}
          </div>
        </p>
      </div>
    `}static get styles(){return[ge,ce`
        .author {
          color: var(--link-text-color, var(--accent-color));
          margin-left: 4px;
        }
        .authors {
          display: flex;
        }
      `]}};e([re({type:Object})],yi.prototype,"hass",void 0),e([re({type:Array})],yi.prototype,"authors",void 0),yi=e([oe("hacs-authors")],yi);let wi=class extends pe{render(){return N`
      <paper-menu-button
        no-animations
        horizontal-align="right"
        role="group"
        aria-haspopup="true"
        vertical-align="top"
        aria-disabled="false"
      >
        <paper-icon-button
          icon="hass:dots-vertical"
          slot="dropdown-trigger"
          role="button"
        ></paper-icon-button>
        <paper-listbox slot="dropdown-content" role="listbox" tabindex="0">
          <paper-item @click=${this.RepositoryReload}>
            ${Wo("repository.update_information")}
          </paper-item>

          ${"version"===this.repository.version_or_commit?N`
                <paper-item @click=${this.RepositoryBeta}>
                  ${this.repository.beta?Wo("repository.hide_beta"):Wo("repository.show_beta")}
                </paper-item>
              `:""}
          ${this.repository.custom||this.repository.installed?"":N`
                <paper-item @click=${this.RepositoryHide}>
                  ${Wo("repository.hide")}
                </paper-item>
              `}

          <a
            href="https://github.com/${this.repository.full_name}"
            rel="noreferrer"
            target="_blank"
          >
            <paper-item>
              <ha-icon class="link-icon" icon="mdi:open-in-new"></ha-icon>
              ${Wo("repository.open_issue")}
            </paper-item>
          </a>

          <a
            href="https://github.com/hacs/default/issues/new?assignees=ludeeus&labels=flag&template=flag.md&title=${this.repository.full_name}"
            rel="noreferrer"
            target="_blank"
          >
            <paper-item>
              <ha-icon class="link-icon" icon="mdi:open-in-new"></ha-icon>
              ${Wo("repository.flag_this")}
            </paper-item>
          </a>
        </paper-listbox>
      </paper-menu-button>
    `}static get styles(){return[ge,ce`
        paper-dropdown-menu {
          width: 250px;
          margin-top: -24px;
        }
        paper-menu-button {
          float: right;
          top: -68px;
        }
        paper-item {
          display: flex;
          background-color: var(
            --paper-listbox-background-color,
            var(--primary-background-color)
          );
        }
      `]}RepositoryReload(){me(this.hass,this.repository.id,"set_state","other"),me(this.hass,this.repository.id,"update")}RepositoryBeta(){me(this.hass,this.repository.id,"set_state","other"),this.repository.beta?me(this.hass,this.repository.id,"hide_beta"):me(this.hass,this.repository.id,"show_beta")}RepositoryHide(){me(this.hass,this.repository.id,"set_state","other"),this.repository.hide?me(this.hass,this.repository.id,"unhide"):me(this.hass,this.repository.id,"hide")}};e([re({type:Object})],wi.prototype,"hass",void 0),e([re({type:Object})],wi.prototype,"repository",void 0),wi=e([oe("hacs-repository-menu")],wi);class vi extends pe{static get styles(){return ge}}e([re({type:Object})],vi.prototype,"hass",void 0),e([re({type:Object})],vi.prototype,"repository",void 0),e([re({type:Object})],vi.prototype,"status",void 0);let ki=class extends vi{render(){if("plugin"!=this.repository.category)return N``;if(!this.repository.installed)return N``;const e=this.repository.local_path.split("/");return N`
      <a
        href="/community_plugin/${e.pop()}/${this.repository.file_name}"
        target="_blank"
      >
        <mwc-button>
          ${Wo("repository.open_plugin")}
        </mwc-button>
      </a>
    `}};ki=e([oe("hacs-button-open-plugin")],ki);let xi=class extends vi{render(){return N`
      <a
        href="https://github.com/${this.repository.full_name}"
        rel="noreferrer"
        target="_blank"
      >
        <mwc-button>
          ${Wo("repository.repository")}
        </mwc-button>
      </a>
    `}};xi=e([oe("hacs-button-open-repository")],xi);var Ai=Zo((function(e,t){e.exports=function(e){function t(a){if(o[a])return o[a].exports;var n=o[a]={i:a,l:!1,exports:{}};return e[a].call(n.exports,n,n.exports,t),n.l=!0,n.exports}var o={};return t.m=e,t.c=o,t.d=function(e,o,a){t.o(e,o)||Object.defineProperty(e,o,{configurable:!1,enumerable:!0,get:a})},t.n=function(e){var o=e&&e.__esModule?function(){return e.default}:function(){return e};return t.d(o,"a",o),o},t.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},t.p="",t(t.s=8)}([function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a="swal-button";t.CLASS_NAMES={MODAL:"swal-modal",OVERLAY:"swal-overlay",SHOW_MODAL:"swal-overlay--show-modal",MODAL_TITLE:"swal-title",MODAL_TEXT:"swal-text",ICON:"swal-icon",ICON_CUSTOM:"swal-icon--custom",CONTENT:"swal-content",FOOTER:"swal-footer",BUTTON_CONTAINER:"swal-button-container",BUTTON:a,CONFIRM_BUTTON:a+"--confirm",CANCEL_BUTTON:a+"--cancel",DANGER_BUTTON:a+"--danger",BUTTON_LOADING:a+"--loading",BUTTON_LOADER:a+"__loader"},t.default=t.CLASS_NAMES},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0}),t.getNode=function(e){var t="."+e;return document.querySelector(t)},t.stringToNode=function(e){var t=document.createElement("div");return t.innerHTML=e.trim(),t.firstChild},t.insertAfter=function(e,t){var o=t.nextSibling;t.parentNode.insertBefore(e,o)},t.removeNode=function(e){e.parentElement.removeChild(e)},t.throwErr=function(e){throw"SweetAlert: "+(e=e.replace(/ +(?= )/g,"")).trim()},t.isPlainObject=function(e){if("[object Object]"!==Object.prototype.toString.call(e))return!1;var t=Object.getPrototypeOf(e);return null===t||t===Object.prototype},t.ordinalSuffixOf=function(e){var t=e%10,o=e%100;return 1===t&&11!==o?e+"st":2===t&&12!==o?e+"nd":3===t&&13!==o?e+"rd":e+"th"}},function(e,t,o){function a(e){for(var o in e)t.hasOwnProperty(o)||(t[o]=e[o])}Object.defineProperty(t,"__esModule",{value:!0}),a(o(25));var n=o(26);t.overlayMarkup=n.default,a(o(27)),a(o(28)),a(o(29));var r=o(0),i=r.default.MODAL_TITLE,s=r.default.MODAL_TEXT,l=r.default.ICON,c=r.default.FOOTER;t.iconMarkup='\n  <div class="'+l+'"></div>',t.titleMarkup='\n  <div class="'+i+'"></div>\n',t.textMarkup='\n  <div class="'+s+'"></div>',t.footerMarkup='\n  <div class="'+c+'"></div>\n'},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1);t.CONFIRM_KEY="confirm",t.CANCEL_KEY="cancel";var n={visible:!0,text:null,value:null,className:"",closeModal:!0},r=Object.assign({},n,{visible:!1,text:"Cancel",value:null}),i=Object.assign({},n,{text:"OK",value:!0});t.defaultButtonList={cancel:r,confirm:i};var s=function(e){switch(e){case t.CONFIRM_KEY:return i;case t.CANCEL_KEY:return r;default:var o=e.charAt(0).toUpperCase()+e.slice(1);return Object.assign({},n,{text:o,value:e})}},l=function(e,t){var o=s(e);return!0===t?Object.assign({},o,{visible:!0}):"string"==typeof t?Object.assign({},o,{visible:!0,text:t}):a.isPlainObject(t)?Object.assign({visible:!0},o,t):Object.assign({},o,{visible:!1})},c=function(e){var o={};switch(e.length){case 1:o[t.CANCEL_KEY]=Object.assign({},r,{visible:!1});break;case 2:o[t.CANCEL_KEY]=l(t.CANCEL_KEY,e[0]),o[t.CONFIRM_KEY]=l(t.CONFIRM_KEY,e[1]);break;default:a.throwErr("Invalid number of 'buttons' in array ("+e.length+").\n      If you want more than 2 buttons, you need to use an object!")}return o};t.getButtonListOpts=function(e){var o=t.defaultButtonList;return"string"==typeof e?o[t.CONFIRM_KEY]=l(t.CONFIRM_KEY,e):Array.isArray(e)?o=c(e):a.isPlainObject(e)?o=function(e){for(var t={},o=0,a=Object.keys(e);o<a.length;o++){var n=a[o],i=e[n],s=l(n,i);t[n]=s}return t.cancel||(t.cancel=r),t}(e):!0===e?o=c([!0,!0]):!1===e?o=c([!1,!1]):void 0===e&&(o=t.defaultButtonList),o}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n=o(2),r=o(0),i=r.default.MODAL,s=r.default.OVERLAY,l=o(30),c=o(31),d=o(32),p=o(33);t.injectElIntoModal=function(e){var t=a.getNode(i),o=a.stringToNode(e);return t.appendChild(o),o};var u=function(e,t){!function(e){e.className=i,e.textContent=""}(e);var o=t.className;o&&e.classList.add(o)};t.initModalContent=function(e){var t=a.getNode(i);u(t,e),l.default(e.icon),c.initTitle(e.title),c.initText(e.text),p.default(e.content),d.default(e.buttons,e.dangerMode)},t.default=function(){var e=a.getNode(s),t=a.stringToNode(n.modalMarkup);e.appendChild(t)}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(3),n={isOpen:!1,promise:null,actions:{},timer:null},r=Object.assign({},n);t.resetState=function(){r=Object.assign({},n)},t.setActionValue=function(e){if("string"==typeof e)return i(a.CONFIRM_KEY,e);for(var t in e)i(t,e[t])};var i=function(e,t){r.actions[e]||(r.actions[e]={}),Object.assign(r.actions[e],{value:t})};t.setActionOptionsFor=function(e,t){var o=(void 0===t?{}:t).closeModal,a=void 0===o||o;Object.assign(r.actions[e],{closeModal:a})},t.default=r},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n=o(3),r=o(0),i=r.default.OVERLAY,s=r.default.SHOW_MODAL,l=r.default.BUTTON,c=r.default.BUTTON_LOADING,d=o(5);t.openModal=function(){a.getNode(i).classList.add(s),d.default.isOpen=!0},t.onAction=function(e){void 0===e&&(e=n.CANCEL_KEY);var t=d.default.actions[e],o=t.value;if(!1===t.closeModal){var r=l+"--"+e;a.getNode(r).classList.add(c)}else a.getNode(i).classList.remove(s),d.default.isOpen=!1;d.default.promise.resolve(o)},t.getState=function(){var e=Object.assign({},d.default);return delete e.promise,delete e.timer,e},t.stopLoading=function(){for(var e=document.querySelectorAll("."+l),t=0;t<e.length;t++)e[t].classList.remove(c)}},function(e,t){var o;o=function(){return this}();try{o=o||Function("return this")()||(0,eval)("this")}catch(e){"object"==typeof window&&(o=window)}e.exports=o},function(e,t,o){(function(t){e.exports=t.sweetAlert=o(9)}).call(t,o(7))},function(e,t,o){(function(t){e.exports=t.swal=o(10)}).call(t,o(7))},function(e,t,o){"undefined"!=typeof window&&o(11),o(16);var a=o(23).default;e.exports=a},function(e,t,o){var a=o(12);"string"==typeof a&&(a=[[e.i,a,""]]);var n={insertAt:"top",transform:void 0};o(14)(a,n),a.locals&&(e.exports=a.locals)},function(e,t,o){(e.exports=o(13)(void 0)).push([e.i,'.swal-icon--error{border-color:#f27474;-webkit-animation:animateErrorIcon .5s;animation:animateErrorIcon .5s}.swal-icon--error__x-mark{position:relative;display:block;-webkit-animation:animateXMark .5s;animation:animateXMark .5s}.swal-icon--error__line{position:absolute;height:5px;width:47px;background-color:#f27474;display:block;top:37px;border-radius:2px}.swal-icon--error__line--left{-webkit-transform:rotate(45deg);transform:rotate(45deg);left:17px}.swal-icon--error__line--right{-webkit-transform:rotate(-45deg);transform:rotate(-45deg);right:16px}@-webkit-keyframes animateErrorIcon{0%{-webkit-transform:rotateX(100deg);transform:rotateX(100deg);opacity:0}to{-webkit-transform:rotateX(0deg);transform:rotateX(0deg);opacity:1}}@keyframes animateErrorIcon{0%{-webkit-transform:rotateX(100deg);transform:rotateX(100deg);opacity:0}to{-webkit-transform:rotateX(0deg);transform:rotateX(0deg);opacity:1}}@-webkit-keyframes animateXMark{0%{-webkit-transform:scale(.4);transform:scale(.4);margin-top:26px;opacity:0}50%{-webkit-transform:scale(.4);transform:scale(.4);margin-top:26px;opacity:0}80%{-webkit-transform:scale(1.15);transform:scale(1.15);margin-top:-6px}to{-webkit-transform:scale(1);transform:scale(1);margin-top:0;opacity:1}}@keyframes animateXMark{0%{-webkit-transform:scale(.4);transform:scale(.4);margin-top:26px;opacity:0}50%{-webkit-transform:scale(.4);transform:scale(.4);margin-top:26px;opacity:0}80%{-webkit-transform:scale(1.15);transform:scale(1.15);margin-top:-6px}to{-webkit-transform:scale(1);transform:scale(1);margin-top:0;opacity:1}}.swal-icon--warning{border-color:#f8bb86;-webkit-animation:pulseWarning .75s infinite alternate;animation:pulseWarning .75s infinite alternate}.swal-icon--warning__body{width:5px;height:47px;top:10px;border-radius:2px;margin-left:-2px}.swal-icon--warning__body,.swal-icon--warning__dot{position:absolute;left:50%;background-color:#f8bb86}.swal-icon--warning__dot{width:7px;height:7px;border-radius:50%;margin-left:-4px;bottom:-11px}@-webkit-keyframes pulseWarning{0%{border-color:#f8d486}to{border-color:#f8bb86}}@keyframes pulseWarning{0%{border-color:#f8d486}to{border-color:#f8bb86}}.swal-icon--success{border-color:#a5dc86}.swal-icon--success:after,.swal-icon--success:before{content:"";border-radius:50%;position:absolute;width:60px;height:120px;background:#fff;-webkit-transform:rotate(45deg);transform:rotate(45deg)}.swal-icon--success:before{border-radius:120px 0 0 120px;top:-7px;left:-33px;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:60px 60px;transform-origin:60px 60px}.swal-icon--success:after{border-radius:0 120px 120px 0;top:-11px;left:30px;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:0 60px;transform-origin:0 60px;-webkit-animation:rotatePlaceholder 4.25s ease-in;animation:rotatePlaceholder 4.25s ease-in}.swal-icon--success__ring{width:80px;height:80px;border:4px solid hsla(98,55%,69%,.2);border-radius:50%;box-sizing:content-box;position:absolute;left:-4px;top:-4px;z-index:2}.swal-icon--success__hide-corners{width:5px;height:90px;background-color:#fff;padding:1px;position:absolute;left:28px;top:8px;z-index:1;-webkit-transform:rotate(-45deg);transform:rotate(-45deg)}.swal-icon--success__line{height:5px;background-color:#a5dc86;display:block;border-radius:2px;position:absolute;z-index:2}.swal-icon--success__line--tip{width:25px;left:14px;top:46px;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-animation:animateSuccessTip .75s;animation:animateSuccessTip .75s}.swal-icon--success__line--long{width:47px;right:8px;top:38px;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-animation:animateSuccessLong .75s;animation:animateSuccessLong .75s}@-webkit-keyframes rotatePlaceholder{0%{-webkit-transform:rotate(-45deg);transform:rotate(-45deg)}5%{-webkit-transform:rotate(-45deg);transform:rotate(-45deg)}12%{-webkit-transform:rotate(-405deg);transform:rotate(-405deg)}to{-webkit-transform:rotate(-405deg);transform:rotate(-405deg)}}@keyframes rotatePlaceholder{0%{-webkit-transform:rotate(-45deg);transform:rotate(-45deg)}5%{-webkit-transform:rotate(-45deg);transform:rotate(-45deg)}12%{-webkit-transform:rotate(-405deg);transform:rotate(-405deg)}to{-webkit-transform:rotate(-405deg);transform:rotate(-405deg)}}@-webkit-keyframes animateSuccessTip{0%{width:0;left:1px;top:19px}54%{width:0;left:1px;top:19px}70%{width:50px;left:-8px;top:37px}84%{width:17px;left:21px;top:48px}to{width:25px;left:14px;top:45px}}@keyframes animateSuccessTip{0%{width:0;left:1px;top:19px}54%{width:0;left:1px;top:19px}70%{width:50px;left:-8px;top:37px}84%{width:17px;left:21px;top:48px}to{width:25px;left:14px;top:45px}}@-webkit-keyframes animateSuccessLong{0%{width:0;right:46px;top:54px}65%{width:0;right:46px;top:54px}84%{width:55px;right:0;top:35px}to{width:47px;right:8px;top:38px}}@keyframes animateSuccessLong{0%{width:0;right:46px;top:54px}65%{width:0;right:46px;top:54px}84%{width:55px;right:0;top:35px}to{width:47px;right:8px;top:38px}}.swal-icon--info{border-color:#c9dae1}.swal-icon--info:before{width:5px;height:29px;bottom:17px;border-radius:2px;margin-left:-2px}.swal-icon--info:after,.swal-icon--info:before{content:"";position:absolute;left:50%;background-color:#c9dae1}.swal-icon--info:after{width:7px;height:7px;border-radius:50%;margin-left:-3px;top:19px}.swal-icon{width:80px;height:80px;border-width:4px;border-style:solid;border-radius:50%;padding:0;position:relative;box-sizing:content-box;margin:20px auto}.swal-icon:first-child{margin-top:32px}.swal-icon--custom{width:auto;height:auto;max-width:100%;border:none;border-radius:0}.swal-icon img{max-width:100%;max-height:100%}.swal-title{color:rgba(0,0,0,.65);font-weight:600;text-transform:none;position:relative;display:block;padding:13px 16px;font-size:27px;line-height:normal;text-align:center;margin-bottom:0}.swal-title:first-child{margin-top:26px}.swal-title:not(:first-child){padding-bottom:0}.swal-title:not(:last-child){margin-bottom:13px}.swal-text{font-size:16px;position:relative;float:none;line-height:normal;vertical-align:top;text-align:left;display:inline-block;margin:0;padding:0 10px;font-weight:400;color:rgba(0,0,0,.64);max-width:calc(100% - 20px);overflow-wrap:break-word;box-sizing:border-box}.swal-text:first-child{margin-top:45px}.swal-text:last-child{margin-bottom:45px}.swal-footer{text-align:right;padding-top:13px;margin-top:13px;padding:13px 16px;border-radius:inherit;border-top-left-radius:0;border-top-right-radius:0}.swal-button-container{margin:5px;display:inline-block;position:relative}.swal-button{background-color:#7cd1f9;color:#fff;border:none;box-shadow:none;border-radius:5px;font-weight:600;font-size:14px;padding:10px 24px;margin:0;cursor:pointer}.swal-button:not([disabled]):hover{background-color:#78cbf2}.swal-button:active{background-color:#70bce0}.swal-button:focus{outline:none;box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(43,114,165,.29)}.swal-button[disabled]{opacity:.5;cursor:default}.swal-button::-moz-focus-inner{border:0}.swal-button--cancel{color:#555;background-color:#efefef}.swal-button--cancel:not([disabled]):hover{background-color:#e8e8e8}.swal-button--cancel:active{background-color:#d7d7d7}.swal-button--cancel:focus{box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(116,136,150,.29)}.swal-button--danger{background-color:#e64942}.swal-button--danger:not([disabled]):hover{background-color:#df4740}.swal-button--danger:active{background-color:#cf423b}.swal-button--danger:focus{box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(165,43,43,.29)}.swal-content{padding:0 20px;margin-top:20px;font-size:medium}.swal-content:last-child{margin-bottom:20px}.swal-content__input,.swal-content__textarea{-webkit-appearance:none;background-color:#fff;border:none;font-size:14px;display:block;box-sizing:border-box;width:100%;border:1px solid rgba(0,0,0,.14);padding:10px 13px;border-radius:2px;transition:border-color .2s}.swal-content__input:focus,.swal-content__textarea:focus{outline:none;border-color:#6db8ff}.swal-content__textarea{resize:vertical}.swal-button--loading{color:transparent}.swal-button--loading~.swal-button__loader{opacity:1}.swal-button__loader{position:absolute;height:auto;width:43px;z-index:2;left:50%;top:50%;-webkit-transform:translateX(-50%) translateY(-50%);transform:translateX(-50%) translateY(-50%);text-align:center;pointer-events:none;opacity:0}.swal-button__loader div{display:inline-block;float:none;vertical-align:baseline;width:9px;height:9px;padding:0;border:none;margin:2px;opacity:.4;border-radius:7px;background-color:hsla(0,0%,100%,.9);transition:background .2s;-webkit-animation:swal-loading-anim 1s infinite;animation:swal-loading-anim 1s infinite}.swal-button__loader div:nth-child(3n+2){-webkit-animation-delay:.15s;animation-delay:.15s}.swal-button__loader div:nth-child(3n+3){-webkit-animation-delay:.3s;animation-delay:.3s}@-webkit-keyframes swal-loading-anim{0%{opacity:.4}20%{opacity:.4}50%{opacity:1}to{opacity:.4}}@keyframes swal-loading-anim{0%{opacity:.4}20%{opacity:.4}50%{opacity:1}to{opacity:.4}}.swal-overlay{position:fixed;top:0;bottom:0;left:0;right:0;text-align:center;font-size:0;overflow-y:auto;background-color:rgba(0,0,0,.4);z-index:10000;pointer-events:none;opacity:0;transition:opacity .3s}.swal-overlay:before{content:" ";display:inline-block;vertical-align:middle;height:100%}.swal-overlay--show-modal{opacity:1;pointer-events:auto}.swal-overlay--show-modal .swal-modal{opacity:1;pointer-events:auto;box-sizing:border-box;-webkit-animation:showSweetAlert .3s;animation:showSweetAlert .3s;will-change:transform}.swal-modal{width:478px;opacity:0;pointer-events:none;background-color:#fff;text-align:center;border-radius:5px;position:static;margin:20px auto;display:inline-block;vertical-align:middle;-webkit-transform:scale(1);transform:scale(1);-webkit-transform-origin:50% 50%;transform-origin:50% 50%;z-index:10001;transition:opacity .2s,-webkit-transform .3s;transition:transform .3s,opacity .2s;transition:transform .3s,opacity .2s,-webkit-transform .3s}@media (max-width:500px){.swal-modal{width:calc(100% - 20px)}}@-webkit-keyframes showSweetAlert{0%{-webkit-transform:scale(1);transform:scale(1)}1%{-webkit-transform:scale(.5);transform:scale(.5)}45%{-webkit-transform:scale(1.05);transform:scale(1.05)}80%{-webkit-transform:scale(.95);transform:scale(.95)}to{-webkit-transform:scale(1);transform:scale(1)}}@keyframes showSweetAlert{0%{-webkit-transform:scale(1);transform:scale(1)}1%{-webkit-transform:scale(.5);transform:scale(.5)}45%{-webkit-transform:scale(1.05);transform:scale(1.05)}80%{-webkit-transform:scale(.95);transform:scale(.95)}to{-webkit-transform:scale(1);transform:scale(1)}}',""])},function(e,t){function o(e,t){var o=e[1]||"",a=e[3];if(!a)return o;if(t&&"function"==typeof btoa){var n=function(e){return"/*# sourceMappingURL=data:application/json;charset=utf-8;base64,"+btoa(unescape(encodeURIComponent(JSON.stringify(e))))+" */"}(a);return[o].concat(a.sources.map((function(e){return"/*# sourceURL="+a.sourceRoot+e+" */"}))).concat([n]).join("\n")}return[o].join("\n")}e.exports=function(e){var t=[];return t.toString=function(){return this.map((function(t){var a=o(t,e);return t[2]?"@media "+t[2]+"{"+a+"}":a})).join("")},t.i=function(e,o){"string"==typeof e&&(e=[[null,e,""]]);for(var a={},n=0;n<this.length;n++){var r=this[n][0];"number"==typeof r&&(a[r]=!0)}for(n=0;n<e.length;n++){var i=e[n];"number"==typeof i[0]&&a[i[0]]||(o&&!i[2]?i[2]=o:o&&(i[2]="("+i[2]+") and ("+o+")"),t.push(i))}},t}},function(e,t,o){function a(e,t){for(var o=0;o<e.length;o++){var a=e[o],n=g[a.id];if(n){n.refs++;for(var r=0;r<n.parts.length;r++)n.parts[r](a.parts[r]);for(;r<a.parts.length;r++)n.parts.push(d(a.parts[r],t))}else{var i=[];for(r=0;r<a.parts.length;r++)i.push(d(a.parts[r],t));g[a.id]={id:a.id,refs:1,parts:i}}}}function n(e,t){for(var o=[],a={},n=0;n<e.length;n++){var r=e[n],i=t.base?r[0]+t.base:r[0],s={css:r[1],media:r[2],sourceMap:r[3]};a[i]?a[i].parts.push(s):o.push(a[i]={id:i,parts:[s]})}return o}function r(e,t){var o=f(e.insertInto);if(!o)throw new Error("Couldn't find a style target. This probably means that the value for the 'insertInto' parameter is invalid.");var a=y[y.length-1];if("top"===e.insertAt)a?a.nextSibling?o.insertBefore(t,a.nextSibling):o.appendChild(t):o.insertBefore(t,o.firstChild),y.push(t);else{if("bottom"!==e.insertAt)throw new Error("Invalid value for parameter 'insertAt'. Must be 'top' or 'bottom'.");o.appendChild(t)}}function i(e){if(null===e.parentNode)return!1;e.parentNode.removeChild(e);var t=y.indexOf(e);t>=0&&y.splice(t,1)}function s(e){var t=document.createElement("style");return e.attrs.type="text/css",c(t,e.attrs),r(e,t),t}function l(e){var t=document.createElement("link");return e.attrs.type="text/css",e.attrs.rel="stylesheet",c(t,e.attrs),r(e,t),t}function c(e,t){Object.keys(t).forEach((function(o){e.setAttribute(o,t[o])}))}function d(e,t){var o,a,n,r;if(t.transform&&e.css){if(!(r=t.transform(e.css)))return function(){};e.css=r}if(t.singleton){var c=b++;o=_||(_=s(t)),a=p.bind(null,o,c,!1),n=p.bind(null,o,c,!0)}else e.sourceMap&&"function"==typeof URL&&"function"==typeof URL.createObjectURL&&"function"==typeof URL.revokeObjectURL&&"function"==typeof Blob&&"function"==typeof btoa?(o=l(t),a=h.bind(null,o,t),n=function(){i(o),o.href&&URL.revokeObjectURL(o.href)}):(o=s(t),a=u.bind(null,o),n=function(){i(o)});return a(e),function(t){if(t){if(t.css===e.css&&t.media===e.media&&t.sourceMap===e.sourceMap)return;a(e=t)}else n()}}function p(e,t,o,a){var n=o?"":a.css;if(e.styleSheet)e.styleSheet.cssText=v(t,n);else{var r=document.createTextNode(n),i=e.childNodes;i[t]&&e.removeChild(i[t]),i.length?e.insertBefore(r,i[t]):e.appendChild(r)}}function u(e,t){var o=t.css,a=t.media;if(a&&e.setAttribute("media",a),e.styleSheet)e.styleSheet.cssText=o;else{for(;e.firstChild;)e.removeChild(e.firstChild);e.appendChild(document.createTextNode(o))}}function h(e,t,o){var a=o.css,n=o.sourceMap,r=void 0===t.convertToAbsoluteUrls&&n;(t.convertToAbsoluteUrls||r)&&(a=w(a)),n&&(a+="\n/*# sourceMappingURL=data:application/json;base64,"+btoa(unescape(encodeURIComponent(JSON.stringify(n))))+" */");var i=new Blob([a],{type:"text/css"}),s=e.href;e.href=URL.createObjectURL(i),s&&URL.revokeObjectURL(s)}var g={},m=function(e){var t;return function(){return void 0===t&&(t=e.apply(this,arguments)),t}}((function(){return window&&document&&document.all&&!window.atob})),f=function(e){var t={};return function(o){return void 0===t[o]&&(t[o]=e.call(this,o)),t[o]}}((function(e){return document.querySelector(e)})),_=null,b=0,y=[],w=o(15);e.exports=function(e,t){if("undefined"!=typeof DEBUG&&DEBUG&&"object"!=typeof document)throw new Error("The style-loader cannot be used in a non-browser environment");(t=t||{}).attrs="object"==typeof t.attrs?t.attrs:{},t.singleton||(t.singleton=m()),t.insertInto||(t.insertInto="head"),t.insertAt||(t.insertAt="bottom");var o=n(e,t);return a(o,t),function(e){for(var r=[],i=0;i<o.length;i++){var s=o[i];(l=g[s.id]).refs--,r.push(l)}for(e&&a(n(e,t),t),i=0;i<r.length;i++){var l;if(0===(l=r[i]).refs){for(var c=0;c<l.parts.length;c++)l.parts[c]();delete g[l.id]}}}};var v=function(){var e=[];return function(t,o){return e[t]=o,e.filter(Boolean).join("\n")}}()},function(e,t){e.exports=function(e){var t="undefined"!=typeof window&&window.location;if(!t)throw new Error("fixUrls requires window.location");if(!e||"string"!=typeof e)return e;var o=t.protocol+"//"+t.host,a=o+t.pathname.replace(/\/[^\/]*$/,"/");return e.replace(/url\s*\(((?:[^)(]|\((?:[^)(]+|\([^)(]*\))*\))*)\)/gi,(function(e,t){var n,r=t.trim().replace(/^"(.*)"$/,(function(e,t){return t})).replace(/^'(.*)'$/,(function(e,t){return t}));return/^(#|data:|http:\/\/|https:\/\/|file:\/\/\/)/i.test(r)?e:(n=0===r.indexOf("//")?r:0===r.indexOf("/")?o+r:a+r.replace(/^\.\//,""),"url("+JSON.stringify(n)+")")}))}},function(e,t,o){var a=o(17);"undefined"==typeof window||window.Promise||(window.Promise=a),o(21),String.prototype.includes||(String.prototype.includes=function(e,t){return"number"!=typeof t&&(t=0),!(t+e.length>this.length)&&-1!==this.indexOf(e,t)}),Array.prototype.includes||Object.defineProperty(Array.prototype,"includes",{value:function(e,t){if(null==this)throw new TypeError('"this" is null or not defined');var o=Object(this),a=o.length>>>0;if(0===a)return!1;for(var n=0|t,r=Math.max(n>=0?n:a-Math.abs(n),0);r<a;){if(function(e,t){return e===t||"number"==typeof e&&"number"==typeof t&&isNaN(e)&&isNaN(t)}(o[r],e))return!0;r++}return!1}}),"undefined"!=typeof window&&[Element.prototype,CharacterData.prototype,DocumentType.prototype].forEach((function(e){e.hasOwnProperty("remove")||Object.defineProperty(e,"remove",{configurable:!0,enumerable:!0,writable:!0,value:function(){this.parentNode.removeChild(this)}})}))},function(e,t,o){(function(t){!function(o){function a(){}function n(e){if("object"!=typeof this)throw new TypeError("Promises must be constructed via new");if("function"!=typeof e)throw new TypeError("not a function");this._state=0,this._handled=!1,this._value=void 0,this._deferreds=[],d(e,this)}function r(e,t){for(;3===e._state;)e=e._value;0!==e._state?(e._handled=!0,n._immediateFn((function(){var o=1===e._state?t.onFulfilled:t.onRejected;if(null!==o){var a;try{a=o(e._value)}catch(e){return void s(t.promise,e)}i(t.promise,a)}else(1===e._state?i:s)(t.promise,e._value)}))):e._deferreds.push(t)}function i(e,t){try{if(t===e)throw new TypeError("A promise cannot be resolved with itself.");if(t&&("object"==typeof t||"function"==typeof t)){var o=t.then;if(t instanceof n)return e._state=3,e._value=t,void l(e);if("function"==typeof o)return void d(function(e,t){return function(){e.apply(t,arguments)}}(o,t),e)}e._state=1,e._value=t,l(e)}catch(t){s(e,t)}}function s(e,t){e._state=2,e._value=t,l(e)}function l(e){2===e._state&&0===e._deferreds.length&&n._immediateFn((function(){e._handled||n._unhandledRejectionFn(e._value)}));for(var t=0,o=e._deferreds.length;t<o;t++)r(e,e._deferreds[t]);e._deferreds=null}function c(e,t,o){this.onFulfilled="function"==typeof e?e:null,this.onRejected="function"==typeof t?t:null,this.promise=o}function d(e,t){var o=!1;try{e((function(e){o||(o=!0,i(t,e))}),(function(e){o||(o=!0,s(t,e))}))}catch(e){if(o)return;o=!0,s(t,e)}}var p=setTimeout;n.prototype.catch=function(e){return this.then(null,e)},n.prototype.then=function(e,t){var o=new this.constructor(a);return r(this,new c(e,t,o)),o},n.all=function(e){var t=Array.prototype.slice.call(e);return new n((function(e,o){function a(r,i){try{if(i&&("object"==typeof i||"function"==typeof i)){var s=i.then;if("function"==typeof s)return void s.call(i,(function(e){a(r,e)}),o)}t[r]=i,0==--n&&e(t)}catch(e){o(e)}}if(0===t.length)return e([]);for(var n=t.length,r=0;r<t.length;r++)a(r,t[r])}))},n.resolve=function(e){return e&&"object"==typeof e&&e.constructor===n?e:new n((function(t){t(e)}))},n.reject=function(e){return new n((function(t,o){o(e)}))},n.race=function(e){return new n((function(t,o){for(var a=0,n=e.length;a<n;a++)e[a].then(t,o)}))},n._immediateFn="function"==typeof t&&function(e){t(e)}||function(e){p(e,0)},n._unhandledRejectionFn=function(e){"undefined"!=typeof console&&console&&console.warn("Possible Unhandled Promise Rejection:",e)},n._setImmediateFn=function(e){n._immediateFn=e},n._setUnhandledRejectionFn=function(e){n._unhandledRejectionFn=e},void 0!==e&&e.exports?e.exports=n:o.Promise||(o.Promise=n)}(this)}).call(t,o(18).setImmediate)},function(e,t,o){function a(e,t){this._id=e,this._clearFn=t}var n=Function.prototype.apply;t.setTimeout=function(){return new a(n.call(setTimeout,window,arguments),clearTimeout)},t.setInterval=function(){return new a(n.call(setInterval,window,arguments),clearInterval)},t.clearTimeout=t.clearInterval=function(e){e&&e.close()},a.prototype.unref=a.prototype.ref=function(){},a.prototype.close=function(){this._clearFn.call(window,this._id)},t.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},t.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},t._unrefActive=t.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;t>=0&&(e._idleTimeoutId=setTimeout((function(){e._onTimeout&&e._onTimeout()}),t))},o(19),t.setImmediate=setImmediate,t.clearImmediate=clearImmediate},function(e,t,o){(function(e,t){!function(e,o){function a(e){delete s[e]}function n(e){if(l)setTimeout(n,0,e);else{var t=s[e];if(t){l=!0;try{!function(e){var t=e.callback,a=e.args;switch(a.length){case 0:t();break;case 1:t(a[0]);break;case 2:t(a[0],a[1]);break;case 3:t(a[0],a[1],a[2]);break;default:t.apply(o,a)}}(t)}finally{a(e),l=!1}}}}if(!e.setImmediate){var r,i=1,s={},l=!1,c=e.document,d=Object.getPrototypeOf&&Object.getPrototypeOf(e);d=d&&d.setTimeout?d:e,"[object process]"==={}.toString.call(e.process)?r=function(e){t.nextTick((function(){n(e)}))}:function(){if(e.postMessage&&!e.importScripts){var t=!0,o=e.onmessage;return e.onmessage=function(){t=!1},e.postMessage("","*"),e.onmessage=o,t}}()?function(){var t="setImmediate$"+Math.random()+"$",o=function(o){o.source===e&&"string"==typeof o.data&&0===o.data.indexOf(t)&&n(+o.data.slice(t.length))};e.addEventListener?e.addEventListener("message",o,!1):e.attachEvent("onmessage",o),r=function(o){e.postMessage(t+o,"*")}}():e.MessageChannel?function(){var e=new MessageChannel;e.port1.onmessage=function(e){n(e.data)},r=function(t){e.port2.postMessage(t)}}():c&&"onreadystatechange"in c.createElement("script")?function(){var e=c.documentElement;r=function(t){var o=c.createElement("script");o.onreadystatechange=function(){n(t),o.onreadystatechange=null,e.removeChild(o),o=null},e.appendChild(o)}}():r=function(e){setTimeout(n,0,e)},d.setImmediate=function(e){"function"!=typeof e&&(e=new Function(""+e));for(var t=new Array(arguments.length-1),o=0;o<t.length;o++)t[o]=arguments[o+1];var a={callback:e,args:t};return s[i]=a,r(i),i++},d.clearImmediate=a}}("undefined"==typeof self?void 0===e?this:e:self)}).call(t,o(7),o(20))},function(e,t){function o(){throw new Error("setTimeout has not been defined")}function a(){throw new Error("clearTimeout has not been defined")}function n(e){if(c===setTimeout)return setTimeout(e,0);if((c===o||!c)&&setTimeout)return c=setTimeout,setTimeout(e,0);try{return c(e,0)}catch(t){try{return c.call(null,e,0)}catch(t){return c.call(this,e,0)}}}function r(){g&&u&&(g=!1,u.length?h=u.concat(h):m=-1,h.length&&i())}function i(){if(!g){var e=n(r);g=!0;for(var t=h.length;t;){for(u=h,h=[];++m<t;)u&&u[m].run();m=-1,t=h.length}u=null,g=!1,function(e){if(d===clearTimeout)return clearTimeout(e);if((d===a||!d)&&clearTimeout)return d=clearTimeout,clearTimeout(e);try{d(e)}catch(t){try{return d.call(null,e)}catch(t){return d.call(this,e)}}}(e)}}function s(e,t){this.fun=e,this.array=t}function l(){}var c,d,p=e.exports={};!function(){try{c="function"==typeof setTimeout?setTimeout:o}catch(e){c=o}try{d="function"==typeof clearTimeout?clearTimeout:a}catch(e){d=a}}();var u,h=[],g=!1,m=-1;p.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var o=1;o<arguments.length;o++)t[o-1]=arguments[o];h.push(new s(e,t)),1!==h.length||g||n(i)},s.prototype.run=function(){this.fun.apply(null,this.array)},p.title="browser",p.browser=!0,p.env={},p.argv=[],p.version="",p.versions={},p.on=l,p.addListener=l,p.once=l,p.off=l,p.removeListener=l,p.removeAllListeners=l,p.emit=l,p.prependListener=l,p.prependOnceListener=l,p.listeners=function(e){return[]},p.binding=function(e){throw new Error("process.binding is not supported")},p.cwd=function(){return"/"},p.chdir=function(e){throw new Error("process.chdir is not supported")},p.umask=function(){return 0}},function(e,t,o){o(22).polyfill()},function(e,t,o){function a(e,t){if(null==e)throw new TypeError("Cannot convert first argument to object");for(var o=Object(e),a=1;a<arguments.length;a++){var n=arguments[a];if(null!=n)for(var r=Object.keys(Object(n)),i=0,s=r.length;i<s;i++){var l=r[i],c=Object.getOwnPropertyDescriptor(n,l);void 0!==c&&c.enumerable&&(o[l]=n[l])}}return o}e.exports={assign:a,polyfill:function(){Object.assign||Object.defineProperty(Object,"assign",{enumerable:!1,configurable:!0,writable:!0,value:a})}}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(24),n=o(6),r=o(5),i=o(36),s=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if("undefined"!=typeof window){var o=i.getOpts.apply(void 0,e);return new Promise((function(e,t){r.default.promise={resolve:e,reject:t},a.default(o),setTimeout((function(){n.openModal()}))}))}};s.close=n.onAction,s.getState=n.getState,s.setActionValue=r.setActionValue,s.stopLoading=n.stopLoading,s.setDefaults=i.setDefaults,t.default=s},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n=o(0).default.MODAL,r=o(4),i=o(34),s=o(35),l=o(1);t.init=function(e){a.getNode(n)||(document.body||l.throwErr("You can only use SweetAlert AFTER the DOM has loaded!"),i.default(),r.default()),r.initModalContent(e),s.default(e)},t.default=t.init},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(0).default.MODAL;t.modalMarkup='\n  <div class="'+a+'" role="dialog" aria-modal="true"></div>',t.default=t.modalMarkup},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a='<div \n    class="'+o(0).default.OVERLAY+'"\n    tabIndex="-1">\n  </div>';t.default=a},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(0).default.ICON;t.errorIconMarkup=function(){var e=a+"--error",t=e+"__line";return'\n    <div class="'+e+'__x-mark">\n      <span class="'+t+" "+t+'--left"></span>\n      <span class="'+t+" "+t+'--right"></span>\n    </div>\n  '},t.warningIconMarkup=function(){var e=a+"--warning";return'\n    <span class="'+e+'__body">\n      <span class="'+e+'__dot"></span>\n    </span>\n  '},t.successIconMarkup=function(){var e=a+"--success";return'\n    <span class="'+e+"__line "+e+'__line--long"></span>\n    <span class="'+e+"__line "+e+'__line--tip"></span>\n\n    <div class="'+e+'__ring"></div>\n    <div class="'+e+'__hide-corners"></div>\n  '}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(0).default.CONTENT;t.contentMarkup='\n  <div class="'+a+'">\n\n  </div>\n'},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(0),n=a.default.BUTTON_CONTAINER,r=a.default.BUTTON,i=a.default.BUTTON_LOADER;t.buttonMarkup='\n  <div class="'+n+'">\n\n    <button\n      class="'+r+'"\n    ></button>\n\n    <div class="'+i+'">\n      <div></div>\n      <div></div>\n      <div></div>\n    </div>\n\n  </div>\n'},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(4),n=o(2),r=o(0),i=r.default.ICON,s=r.default.ICON_CUSTOM,l=["error","warning","success","info"],c={error:n.errorIconMarkup(),warning:n.warningIconMarkup(),success:n.successIconMarkup()};t.default=function(e){if(e){var t=a.injectElIntoModal(n.iconMarkup);l.includes(e)?function(e,t){var o=i+"--"+e;t.classList.add(o);var a=c[e];a&&(t.innerHTML=a)}(e,t):function(e,t){t.classList.add(s);var o=document.createElement("img");o.src=e,t.appendChild(o)}(e,t)}}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(2),n=o(4),r=function(e){navigator.userAgent.includes("AppleWebKit")&&(e.style.display="none",e.offsetHeight,e.style.display="")};t.initTitle=function(e){if(e){var t=n.injectElIntoModal(a.titleMarkup);t.textContent=e,r(t)}},t.initText=function(e){if(e){var t=document.createDocumentFragment();e.split("\n").forEach((function(e,o,a){t.appendChild(document.createTextNode(e)),o<a.length-1&&t.appendChild(document.createElement("br"))}));var o=n.injectElIntoModal(a.textMarkup);o.appendChild(t),r(o)}}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n=o(4),r=o(0),i=r.default.BUTTON,s=r.default.DANGER_BUTTON,l=o(3),c=o(2),d=o(6),p=o(5),u=function(e,t,o){var n=t.text,r=t.value,u=t.className,h=t.closeModal,g=a.stringToNode(c.buttonMarkup),m=g.querySelector("."+i),f=i+"--"+e;m.classList.add(f),u&&(Array.isArray(u)?u:u.split(" ")).filter((function(e){return e.length>0})).forEach((function(e){m.classList.add(e)})),o&&e===l.CONFIRM_KEY&&m.classList.add(s),m.textContent=n;var _={};return _[e]=r,p.setActionValue(_),p.setActionOptionsFor(e,{closeModal:h}),m.addEventListener("click",(function(){return d.onAction(e)})),g};t.default=function(e,t){var o=n.injectElIntoModal(c.footerMarkup);for(var a in e){var r=e[a],i=u(a,r,t);r.visible&&o.appendChild(i)}0===o.children.length&&o.remove()}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(3),n=o(4),r=o(2),i=o(5),s=o(6),l=o(0).default.CONTENT,c=function(e){e.addEventListener("input",(function(e){var t=e.target.value;i.setActionValue(t)})),e.addEventListener("keyup",(function(e){if("Enter"===e.key)return s.onAction(a.CONFIRM_KEY)})),setTimeout((function(){e.focus(),i.setActionValue("")}),0)};t.default=function(e){if(e){var t=n.injectElIntoModal(r.contentMarkup),o=e.element,a=e.attributes;"string"==typeof o?function(e,t,o){var a=document.createElement(t),n=l+"__"+t;for(var r in a.classList.add(n),o){var i=o[r];a[r]=i}"input"===t&&c(a),e.appendChild(a)}(t,o,a):t.appendChild(o)}}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n=o(2);t.default=function(){var e=a.stringToNode(n.overlayMarkup);document.body.appendChild(e)}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(5),n=o(6),r=o(1),i=o(3),s=o(0),l=s.default.MODAL,c=s.default.BUTTON,d=s.default.OVERLAY,p=function(e){if(a.default.isOpen)switch(e.key){case"Escape":return n.onAction(i.CANCEL_KEY)}},u=function(e){if(a.default.isOpen)switch(e.key){case"Tab":return function(e){e.preventDefault(),g()}(e)}},h=function(e){if(a.default.isOpen)return"Tab"===e.key&&e.shiftKey?function(e){e.preventDefault(),m()}(e):void 0},g=function(){var e=r.getNode(c);e&&(e.tabIndex=0,e.focus())},m=function(){var e=r.getNode(l).querySelectorAll("."+c),t=e[e.length-1];t&&t.focus()},f=function(){var e=r.getNode(l).querySelectorAll("."+c);e.length&&(function(e){e[e.length-1].addEventListener("keydown",u)}(e),function(e){e[0].addEventListener("keydown",h)}(e))},_=function(e){if(r.getNode(d)===e.target)return n.onAction(i.CANCEL_KEY)};t.default=function(e){e.closeOnEsc?document.addEventListener("keyup",p):document.removeEventListener("keyup",p),e.dangerMode?g():m(),f(),function(e){var t=r.getNode(d);t.removeEventListener("click",_),e&&t.addEventListener("click",_)}(e.closeOnClickOutside),function(e){a.default.timer&&clearTimeout(a.default.timer),e&&(a.default.timer=window.setTimeout((function(){return n.onAction(i.CANCEL_KEY)}),e))}(e.timer)}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n=o(3),r=o(37),i=o(38),s={title:null,text:null,icon:null,buttons:n.defaultButtonList,content:null,className:null,closeOnClickOutside:!0,closeOnEsc:!0,dangerMode:!1,timer:null},l=Object.assign({},s);t.setDefaults=function(e){l=Object.assign({},s,e)};var c=function(e){var t=e&&e.button,o=e&&e.buttons;return void 0!==t&&void 0!==o&&a.throwErr("Cannot set both 'button' and 'buttons' options!"),void 0!==t?{confirm:t}:o},d=function(e){return a.ordinalSuffixOf(e+1)},p=function(e,t){a.throwErr(d(t)+" argument ('"+e+"') is invalid")},u=function(e,t){var o=e+1,n=t[o];a.isPlainObject(n)||void 0===n||a.throwErr("Expected "+d(o)+" argument ('"+n+"') to be a plain object")},h=function(e,t,o,n){var r=t instanceof Element;if("string"==typeof t){if(0===o)return{text:t};if(1===o)return{text:t,title:n[0]};if(2===o)return u(o,n),{icon:t};p(t,o)}else{if(r&&0===o)return u(o,n),{content:t};if(a.isPlainObject(t))return function(e,t){var o=e+1,n=t[o];void 0!==n&&a.throwErr("Unexpected "+d(o)+" argument ("+n+")")}(o,n),t;p(t,o)}};t.getOpts=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var o={};e.forEach((function(t,a){var n=h(0,t,a,e);Object.assign(o,n)}));var a=c(o);o.buttons=n.getButtonListOpts(a),delete o.button,o.content=r.getContentOpts(o.content);var d=Object.assign({},s,l,o);return Object.keys(d).forEach((function(e){i.DEPRECATED_OPTS[e]&&i.logDeprecation(e)})),d}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0});var a=o(1),n={element:"input",attributes:{placeholder:""}};t.getContentOpts=function(e){return a.isPlainObject(e)?Object.assign({},e):e instanceof Element?{element:e}:"input"===e?n:null}},function(e,t,o){Object.defineProperty(t,"__esModule",{value:!0}),t.logDeprecation=function(e){var o=t.DEPRECATED_OPTS[e],a=o.onlyRename,n=o.replacement,r=o.subOption,i=o.link,s='SweetAlert warning: "'+e+'" option has been '+(a?"renamed":"deprecated")+".";n&&(s+=" Please use"+(r?' "'+r+'" in ':" ")+'"'+n+'" instead.');var l="https://sweetalert.js.org";s+=i?" More details: "+l+i:" More details: "+l+"/guides/#upgrading-from-1x",console.warn(s)},t.DEPRECATED_OPTS={type:{replacement:"icon",link:"/docs/#icon"},imageUrl:{replacement:"icon",link:"/docs/#icon"},customClass:{replacement:"className",onlyRename:!0,link:"/docs/#classname"},imageSize:{},showCancelButton:{replacement:"buttons",link:"/docs/#buttons"},showConfirmButton:{replacement:"button",link:"/docs/#button"},confirmButtonText:{replacement:"button",link:"/docs/#button"},confirmButtonColor:{},cancelButtonText:{replacement:"buttons",link:"/docs/#buttons"},closeOnConfirm:{replacement:"button",subOption:"closeModal",link:"/docs/#button"},closeOnCancel:{replacement:"buttons",subOption:"closeModal",link:"/docs/#buttons"},showLoaderOnConfirm:{replacement:"buttons"},animation:{},inputType:{replacement:"content",link:"/docs/#content"},inputValue:{replacement:"content",link:"/docs/#content"},inputPlaceholder:{replacement:"content",link:"/docs/#content"},html:{replacement:"content",link:"/docs/#content"},allowEscapeKey:{replacement:"closeOnEsc",onlyRename:!0,link:"/docs/#closeonesc"},allowClickOutside:{replacement:"closeOnClickOutside",onlyRename:!0,link:"/docs/#closeonclickoutside"}}}])})),Si=function(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}(Ai);Ai.swal;let ji=class extends vi{render(){if(!this.repository.installed)return N``;const e=Wo("repository.uninstall");return this.status.background_task?N`
        <mwc-button
          class="disabled-button"
          title="${Wo("confirm.bg_task")}"
          @click=${this.disabledAction}
        >
          ${e}
        </mwc-button>
      `:N`
            <mwc-button @click=${this.RepositoryUnInstall}">
                ${"uninstalling"==this.repository.state?N`
                        <paper-spinner active></paper-spinner>
                      `:N`
                        ${e}
                      `}
            </mwc-button>
        `}static get styles(){return[ge,ce`
        mwc-button {
          --mdc-theme-primary: var(--google-red-500);
        }
      `]}disabledAction(){Si(Wo("confirm.bg_task"))}RepositoryUnInstall(){Si(Wo("confirm.uninstall","{item}",this.repository.name),{buttons:[Wo("confirm.cancel"),Wo("confirm.yes")]}).then(e=>{null!==e&&this.ExecuteAction()})}ExecuteAction(){me(this.hass,this.repository.id,"set_state","uninstalling"),me(this.hass,this.repository.id,"uninstall")}};ji=e([oe("hacs-button-uninstall")],ji);let Ei=class extends vi{constructor(){super(...arguments),this.pathExists=!1}firstUpdated(){let e=this.repository.local_path;"theme"===this.repository.category&&(e=`${e}/${this.repository.file_name}`),this.hass.connection.sendMessagePromise({type:"hacs/check_path",path:e}).then(e=>{this.pathExists=e.exist},e=>{console.error("[hacs/check_path] Message failed!",e)})}render(){const e=Wo(`repository.${this.repository.main_action.toLowerCase()}`);return this.status.background_task?N`
        <mwc-button
          class="disabled-button"
          title="${Wo("confirm.bg_task")}"
          @click=${this.disabledAction}
        >
          ${e}
        </mwc-button>
      `:N`
      <mwc-button @click=${this.RepositoryInstall}>
        ${"installing"==this.repository.state?N`
              <paper-spinner active></paper-spinner>
            `:N`
              ${e}
            `}
      </mwc-button>
    `}disabledAction(){Si(Wo("confirm.bg_task"))}RepositoryInstall(){if(this.pathExists&&!this.repository.installed){let e=this.repository.local_path;"theme"===this.repository.category&&(e=`${e}/${this.repository.file_name}`),Si(Wo("confirm.exist","{item}",e)+"\n"+Wo("confirm.overwrite")+"\n"+Wo("confirm.continue"),{buttons:[Wo("confirm.cancel"),Wo("confirm.yes")]}).then(e=>{null!==e&&this.ExecuteAction()})}else this.ExecuteAction()}ExecuteAction(){me(this.hass,this.repository.id,"set_state","installing"),me(this.hass,this.repository.id,"install")}};e([re()],Ei.prototype,"pathExists",void 0),Ei=e([oe("hacs-button-main-action")],Ei);let Oi=class extends vi{render(){if(!this.repository.pending_upgrade)return N``;var e=`https://github.com/${this.repository.full_name}/releases`;return"commit"===this.repository.version_or_commit&&(e=`https://github.com/${this.repository.full_name}/compare/${this.repository.installed_version}...${this.repository.available_version}`),N`
      <a href="${String(e)}" rel="noreferrer" target="_blank">
        <mwc-button>
          ${Wo("repository.changelog")}
        </mwc-button>
      </a>
    `}RepositoryInstall(){me(this.hass,this.repository.id,"set_state","installing"),me(this.hass,this.repository.id,"uninstall")}};Oi=e([oe("hacs-button-changelog")],Oi);let Ci=class extends pe{render(){return N`
      <div class="hacs-body">
        <slot></slot>
      </div>
    `}static get styles(){return[ge,ce`
        .hacs-body {
          width: 95%;
          margin-left: 2.5%;
          margin-top: 2.5%;
          margin-bottom: 2.5%;
        }
      `]}};Ci=e([oe("hacs-body")],Ci);let zi=class extends pe{render(){const e=`${this.repository.full_name.split("/")[1]}/${this.repository.file_name}`,t=`${void 0!==this.repository.javascript_type?this.repository.javascript_type:Wo("repository.lovelace_no_js_type")}`;return N`
      <div class="lovelace-hint markdown-body">
        <p class="example-title">
          ${Wo("repository.lovelace_instruction")}:
        </p>
        <pre id="LovelaceExample" class="yaml">
  - url: /community_plugin/${e}
    type: ${t}</pre
        >

        <paper-icon-button
          title="${Wo("repository.lovelace_copy_example")}"
          icon="mdi:content-copy"
          @click="${this.CopyToLovelaceExampleToClipboard}"
          role="button"
        ></paper-icon-button>
      </div>
    `}CopyToLovelaceExampleToClipboard(e){var t=e.composedPath()[4].children[0].children[1].innerText;document.addEventListener("copy",e=>{e.clipboardData.setData("text/plain",t),e.preventDefault(),document.removeEventListener("copy",null)}),document.execCommand("copy")}static get styles(){return[ge,fi,ce`
        .example-title {
          margin-block-end: 0em;
        }
        .yaml {
          display: inline-flex;
          width: calc(100% - 46px);
        }
      `]}};e([re({type:Object})],zi.prototype,"configuration",void 0),e([re({type:Object})],zi.prototype,"hass",void 0),e([re({type:Object})],zi.prototype,"repository",void 0),zi=e([oe("hacs-lovelace-hint")],zi);let Ti=class extends pe{render(){let e=this.repository.local_path;return"theme"===this.repository.category&&(e=`${e}/${this.repository.file_name}`),N`
      <div class="repository-note">
        <p>
          ${Wo("repository.note_installed")} '${e}'
          ${"appdaemon"===this.repository.category?N`
                , ${Wo(`repository.note_${this.repository.category}`)}
              `:""}
          ${"integration"===this.repository.category?N`
                , ${Wo(`repository.note_${this.repository.category}`)}
              `:""}
          ${"plugin"===this.repository.category?N`
                , ${Wo(`repository.note_${this.repository.category}`)}
              `:""}
          .
        </p>

        ${"plugin"===this.repository.category?N`
              <hacs-lovelace-hint
                .hass=${this.hass}
                .configuration=${this.configuration}
                .repository=${this.repository}
              ></hacs-lovelace-hint>
            `:""}
      </div>
    `}static get styles(){return[ge,ce`
        .repository-note {
          border-top: 1px solid var(--primary-text-color);
        }
        p {
          font-style: italic;
        }
      `]}};function $i(e,t,o){if("yaml"===o.lovelace_mode)return!0;if(void 0!==t){var a=!1,n=`/community_plugin/${e.full_name.split("/")[1]}/${e.file_name}`;return void 0!==t.resources&&t.resources.forEach(e=>{a||e.url===n&&(a=!0)}),a}return!0}e([re({type:Object})],Ti.prototype,"configuration",void 0),e([re({type:Object})],Ti.prototype,"hass",void 0),e([re({type:Object})],Ti.prototype,"repository",void 0),Ti=e([oe("hacs-repository-note")],Ti);let Ri=class extends vi{render(){return this.repository.installed?null===this.repository.javascript_type?N``:N`
      <mwc-button @click=${this.RepositoryAddToLovelace}>
        Add to Lovelace
      </mwc-button>
    `:N``}RepositoryAddToLovelace(){Si(Wo("confirm.add_to_lovelace"),{buttons:[Wo("confirm.cancel"),Wo("confirm.yes")]}).then(e=>{null!==e&&this.hass.connection.sendMessagePromise({type:"lovelace/config",force:!1}).then(e=>{var t=e;const o={type:this.repository.javascript_type,url:`/community_plugin/${this.repository.full_name.split("/")[1]}/${this.repository.file_name}`};t.resources?t.resources.push(o):t.resources=[o],this.hass.callWS({type:"lovelace/config/save",config:t})},e=>{console.error(e)})})}};e([re({type:Object})],Ri.prototype,"configuration",void 0),e([re({type:Object})],Ri.prototype,"lovelaceconfig",void 0),Ri=e([oe("hacs-button-add-to-lovelace")],Ri);let Ni=class extends pe{render(){if(!this.repository.installed)return N``;var e="",t="",o="";if("pending-restart"==this.repository.status)o="alert",t=Wo("repository_banner.restart_pending"),e=Wo("repository_banner.restart");else if("plugin"==this.repository.category){if(void 0!==this.lovelaceconfig&&!this.status.background_task)$i(this.repository,this.lovelaceconfig,this.status)||(o="warning",t=Wo("repository_banner.not_loaded"),e=Wo("repository_banner.plugin_not_loaded"))}return 0==e.length?N``:"plugin"!==this.repository.category?N`
        <ha-card header="${t}" class="${o}">
          <div class="card-content">
            ${e}
          </div>
        </ha-card>
      `:N`
      <ha-card header="${t}" class="${o}">
        <div class="card-content">
          ${e}
        </div>
        <div class="card-actions">
          <hacs-button-add-to-lovelace
            .hass=${this.hass}
            .configuration=${this.configuration}
            .repository=${this.repository}
            .lovelaceconfig=${this.lovelaceconfig}
          >
          </hacs-button-add-to-lovelace>
        </div>
      </ha-card>
    `}static get styles(){return[ge,ce`
        ha-card {
          width: 90%;
          margin-left: 5%;
        }
        .alert {
          background-color: var(
            --hacs-status-pending-restart,
            var(--google-red-500)
          );
          color: var(--text-primary-color);
        }
        .warning {
          background-color: var(--hacs-status-pending-update);
          color: var(--primary-text-color);
        }
        .info {
          background-color: var(--primary-background-color);
          color: var(--primary-text-color);
        }
      `]}};e([re({type:Object})],Ni.prototype,"configuration",void 0),e([re({type:Object})],Ni.prototype,"hass",void 0),e([re({type:Object})],Ni.prototype,"lovelaceconfig",void 0),e([re({type:Object})],Ni.prototype,"repository",void 0),e([re({type:Object})],Ni.prototype,"status",void 0),Ni=e([oe("hacs-repository-banner-note")],Ni);let Ii=class extends pe{constructor(){super(...arguments),this.repository_view=!1}firstUpdated(){void 0!==this.repo&&this.repo.updated_info||(me(this.hass,this.repository,"set_state","other"),me(this.hass,this.repository,"update"))}render(){var e=this.repository,t=this.repositories.filter((function(t){return t.id===e}));if(this.repo=t[0],void 0===this.repo)return N`
        <div class="loader"><paper-spinner active></paper-spinner></div>
      `;if(this.repo.installed)var o=Wo("common.installed");else{if("appdaemon"===this.repo.category)var a="appdaemon_apps";else a=`${this.repo.category}s`;o=Wo(`common.${a}`)}return N`
      <hacs-body>
        <div class="getBack">
          <mwc-button @click=${this.GoBackToStore} title="${o}">
            <ha-icon icon="mdi:arrow-left"></ha-icon>
            ${Wo("repository.back_to")} ${o}
          </mwc-button>
          ${"other"===this.repo.state?N`
                <div class="loader"><paper-spinner active></paper-spinner></div>
              `:""}
        </div>

        <hacs-repository-banner-note
          .hass=${this.hass}
          .status=${this.status}
          .repository=${this.repo}
          .lovelaceconfig=${this.lovelaceconfig}
          .configuration=${this.configuration}
        >
        </hacs-repository-banner-note>

        <ha-card>
          <div class="repotitle">
            ${bn.emojify(this.repo.name||"")}
          </div>
          <hacs-repository-menu
            .hass=${this.hass}
            .repository=${this.repo}
          ></hacs-repository-menu>

          <div class="card-content">
            <div class="description">
              ${bn.emojify(this.repo.description||"")}
            </div>

            <div class="information">
              <hacs-authors
                .hass=${this.hass}
                .authors=${this.repo.authors}
              ></hacs-authors>
              ${this.repo.installed?N`
                    <div class="version-installed">
                      <b>${Wo("repository.installed")}: </b> ${this.repo.installed_version}
                    </div>
                  `:""}
              ${"0"===String(this.repo.releases.length)?N`
                    <div class="version-available">
                      <b>${Wo("repository.available")}: </b> ${this.repo.available_version}
                    </div>
                  `:N`
                    <div class="version-available">
                      <paper-dropdown-menu
                        @value-changed="${this.SetVersion}"
                        label="${Wo("repository.available")}:
                     (${Wo("repository.newest")}: ${this.repo.releases[0]})"
                      >
                        <paper-listbox
                          slot="dropdown-content"
                          selected="${this.repo.selected_tag}"
                          attr-for-selected="value"
                        >
                          ${this.repo.releases.map(e=>N`
                                <paper-item value="${e}"
                                  >${e}</paper-item
                                >
                              `)}
                          ${"hacs/integration"!==this.repo.full_name?N`
                                <paper-item value="${this.repo.default_branch}"
                                  >${this.repo.default_branch}</paper-item
                                >
                              `:""}
                        </paper-listbox>
                      </paper-dropdown-menu>
                    </div>
                  `}
            </div>
          </div>

          <div class="card-actions MobileGrid">
            <hacs-button-main-action
              .hass=${this.hass}
              .repository=${this.repo}
              .status=${this.status}
            ></hacs-button-main-action>
            <hacs-button-changelog
              .hass=${this.hass}
              .repository=${this.repo}
            ></hacs-button-changelog>
            <hacs-button-open-repository
              .hass=${this.hass}
              .repository=${this.repo}
            ></hacs-button-open-repository>
            ${"plugin"===this.repo.category?N`
                  <hacs-button-open-plugin
                    .hass=${this.hass}
                    .repository=${this.repo}
                  ></hacs-button-open-plugin>
                `:""}
            <hacs-button-uninstall
              class="right"
              .hass=${this.hass}
              .repository=${this.repo}
              .status=${this.status}
            ></hacs-button-uninstall>
          </div>
        </ha-card>
        ${this.repo.updated_info?N`
              <ha-card class="additional">
                <div class="card-content">
                  <div class="more_info markdown-body">
                    <style>
                      ${fi} ${mi}
                    </style>
                    ${class{static html(e,t){e=(e=(e=bn.emojify(e)).replace(/(https:\/\/github\.com\/.*.\/blob*.[^\s]+)/g,(function(e){return e.replace("https://github.com/","https://raw.githubusercontent.com/").replace("/blob/","/")}))).replace(/\!\[*.*\]\(\w*\.\w*\)/g,(function(e){return e.replace("(",`(https://raw.githubusercontent.com/${t.full_name}/master/`).replace("/blob/","/")}));const o=document.createElement("div");return o.innerHTML=hi(bi(e)),o.style.cssText=`${fi} ${mi}`,N`
      ${o}
    `}}.html(this.repo.additional_info||"",this.repo)}
                  </div>
                  <hacs-repository-note
                    .hass=${this.hass}
                    .configuration=${this.configuration}
                    .repository=${this.repo}
                  ></hacs-repository-note>
                </div>
              </ha-card>
            `:""}
      </hacs-body>
    `}SetVersion(e){e.detail.value.length>0&&(me(this.hass,this.repo.id,"set_state","other"),me(this.hass,this.repo.id,"set_version",e.detail.value))}GoBackToStore(){this.repository=void 0,this.repo.installed?this.panel="installed":this.panel=this.repo.category,this.route.path=`/${this.panel}`,this.dispatchEvent(new CustomEvent("hacs-location-change",{detail:{value:this.route},bubbles:!0,composed:!0}))}static get styles(){return[ge,ce`
        .loader {
          background-color: var(--primary-background-color);
          height: 100%;
          width: 100%;
        }
        paper-spinner {
          position: absolute;
          top: 30%;
          left: 50%;
          transform: translate(-50%, -50%);
          z-index: 99;
          width: 150px;
          height: 150px;
        }
        paper-dropdown-menu {
          width: 50%;
        }
        @media screen and (max-width: 600px) and (min-width: 0) {
          paper-dropdown-menu {
            width: 100%;
          }
          .getBack {
            margin-top: 0px !important;
          }
        }
        paper-item {
          display: flex;
          background-color: var(
            --paper-listbox-background-color,
            var(--primary-background-color)
          );
        }
        .description {
          width: 100%;
          margin-bottom: 8px;
          color: var(--secondary-text-color);
          text-align: left !important;
        }
        .version {
          padding-bottom: 8px;
        }
        .options {
          float: right;
          width: 40%;
        }
        .information {
          width: 100%;
        }
        .additional {
          margin-bottom: 108px;
        }
        .getBack {
          margin-top: -12px;
          margin-bottom: 4px;
          margin-left: 5%;
        }
        .right {
          float: right;
        }
        .loading {
          text-align: center;
          width: 100%;
        }
        ha-card {
          width: 90%;
          margin-left: 5%;
        }
        .link-icon {
          color: var(--dark-primary-color);
          margin-right: 8px;
        }
        .repotitle {
          padding: 24px 24px 24px 18px;
          width: calc(100% - (24px + 4px + 24px + 56px));
          font-size: 1.5em;
          white-space: nowrap;
          text-overflow: ellipsis;
          overflow: hidden;
        }
      `]}};e([re({type:Array})],Ii.prototype,"repositories",void 0),e([re({type:Boolean})],Ii.prototype,"repository_view",void 0),e([re({type:Object})],Ii.prototype,"repo",void 0),e([re({type:Object})],Ii.prototype,"configuration",void 0),e([re({type:Object})],Ii.prototype,"hass",void 0),e([re({type:Object})],Ii.prototype,"lovelaceconfig",void 0),e([re({type:Object})],Ii.prototype,"route",void 0),e([re({type:Object})],Ii.prototype,"status",void 0),e([re()],Ii.prototype,"panel",void 0),e([re()],Ii.prototype,"repository",void 0),Ii=e([oe("hacs-repository")],Ii);let Pi=class extends pe{Delete(e){let t,o;e.composedPath().forEach(e=>{e.RepoID&&(t=e.RepoID,o=e.RepoFullName)}),Si(Wo("confirm.delete","{item}",o),{buttons:[Wo("confirm.cancel"),Wo("confirm.yes")]}).then(e=>{me(this.hass,t,"delete")})}DeleteInstalled(e){let t;e.composedPath().forEach(e=>{e.RepoFullName&&(t=e.RepoFullName)}),Si(Wo("confirm.delete_installed","{item}",t))}Save(e){var t=e.composedPath()[2].children[1].selectedItem;if(void 0!==t){var o=t.category,a=e.composedPath()[2].children[0].value;me(this.hass,a,"add",o),Si(Wo("settings.adding_new_repo","{repo}",a)+"\n"+Wo("settings.adding_new_repo_category","{category}",o))}else Si(Wo("settings.missing_category"))}ShowRepository(e){let t;e.composedPath().forEach(e=>{e.RepoID&&(t=e.RepoID)}),this.route.path=`/repository/${t}`,this.dispatchEvent(new CustomEvent("hacs-location-change",{detail:{value:this.route},bubbles:!0,composed:!0}))}render(){return this.custom=this.repositories.filter((function(e){return!!e.custom})),N`
      <ha-card header="${Wo("settings.custom_repositories")}">
        <div class="card-content">
          <div class="custom-repositories-list">
            ${this.status.background_task?N`
                  <i class="addition">${Wo("settings.bg_task_custom")}</i>
                `:N`
                  ${this.custom.sort((e,t)=>e.full_name>t.full_name?1:-1).map(e=>N`
                          <div
                            class="row"
                            .RepoID=${e.id}
                            .RepoFullName=${e.full_name}
                          >
                            <paper-item class="customlistitem">
                              <div
                                @click=${this.ShowRepository}
                                class="link flexy"
                              >
                                <div class="MobileHide">
                                  [${e.category}]&nbsp;
                                </div>
                                ${e.full_name}
                              </div>
                              ${e.installed?N`
                                    <ha-icon
                                      title="${Wo("settings.delete")}"
                                      class="listicon disabled"
                                      icon="mdi:delete"
                                      @click=${this.DeleteInstalled}
                                    ></ha-icon>
                                  `:N`
                                    <ha-icon
                                      title="${Wo("settings.delete")}"
                                      class="listicon"
                                      icon="mdi:delete"
                                      @click=${this.Delete}
                                    ></ha-icon>
                                  `}
                            </paper-item>
                          </div>
                        `)}
                `}
          </div>
        </div>
        ${this.status.background_task?"":N`
              <div class="card-actions">
                <paper-input
                  class="inputfield MobileGrid"
                  placeholder=${Wo("settings.add_custom_repository")}
                  type="text"
                ></paper-input>
                <paper-dropdown-menu
                  class="category MobileGrid"
                  label="${Wo("settings.category")}"
                >
                  <paper-listbox slot="dropdown-content" selected="-1">
                    ${this.configuration.categories.map(e=>N`
                        <paper-item class="categoryitem" .category=${e}>
                          ${Wo(`common.${e}`)}
                        </paper-item>
                      `)}
                  </paper-listbox>
                </paper-dropdown-menu>

                <div class="save">
                  <ha-icon
                    title="${Wo("settings.save")}"
                    icon="mdi:content-save"
                    class="saveicon MobileGrid"
                    @click=${this.Save}
                  >
                  </ha-icon>
                </div>
              </div>
            `}
      </ha-card>
    `}static get styles(){return[ge,ce`
        .inputfield {
          width: 60%;
        }
        .category {
          position: absolute;
          width: 30%;
          right: 54px;
          bottom: 5px;
        }
        .saveicon {
          color: var(--primary-color);
          position: absolute;
          right: 0;
          bottom: 24px;
          cursor: pointer;
        }
        .listicon {
          color: var(--primary-color);
          right: 0px;
          position: absolute;
          cursor: pointer;
        }
        .loading {
          position: absolute;
          right: 10px;
          bottom: 22px;
        }

        @media screen and (max-width: 600px) and (min-width: 0) {
          .saveicon {
            height: 64px;
          }
          .save {
            padding-bottom: 64px;
          }
        }
        paper-item.categoryitem {
          display: flex;
          background-color: var(
            --paper-listbox-background-color,
            var(--primary-background-color)
          );
        }

        paper-item.customlistitem {
          display: flex;
        }
      `]}};e([re({type:Array})],Pi.prototype,"custom",void 0),e([re({type:Array})],Pi.prototype,"repositories",void 0),e([re({type:Object})],Pi.prototype,"configuration",void 0),e([re({type:Object})],Pi.prototype,"hass",void 0),e([re({type:Object})],Pi.prototype,"status",void 0),e([re({type:Object})],Pi.prototype,"route",void 0),Pi=e([oe("hacs-custom-repositories")],Pi);let Mi=class extends pe{UnHide(e){var t=e.composedPath()[4].repoID;me(this.hass,t,"unhide")}render(){return this._hidden=this.repositories.filter((function(e){return e.hide})),0===this._hidden.length?N``:N`
      <ha-card
        header="${Wo("settings.hidden_repositories").toUpperCase()}"
      >
        <div class="card-content">
          <div class="custom-repositories-list">
            ${this._hidden.sort((e,t)=>e.full_name>t.full_name?1:-1).map(e=>N`
                    <div class="row" .repoID=${e.id}>
                      <paper-item>
                        <ha-icon
                          title="${Wo("settings.unhide")}"
                          class="listicon"
                          icon="mdi:restore"
                          @click=${this.UnHide}
                        ></ha-icon>
                        ${e.full_name}
                      </paper-item>
                    </div>
                  `)}
          </div>
        </div>
      </ha-card>
    `}static get styles(){return[ge,ce`
        ha-card {
          width: 90%;
          margin-left: 5%;
        }
        .listicon {
          color: var(--primary-color);
          left: 0px;
        }
      `]}};e([re({type:Array})],Mi.prototype,"repositories",void 0),e([re({type:Array})],Mi.prototype,"_hidden",void 0),e([re({type:Object})],Mi.prototype,"hass",void 0),Mi=e([oe("hacs-hidden-repositories")],Mi);let Li=class extends pe{constructor(){super(...arguments),this.active=!0}render(){return this.active?N`
      <paper-progress indeterminate></paper-progress>
    `:N``}static get styles(){return[ge,ce`
        paper-progress {
          width: 100%;
          --paper-progress-active-color: var(--accent-color);
        }
      `]}};e([re({type:Boolean})],Li.prototype,"active",void 0),Li=e([oe("hacs-progressbar")],Li);let Di=class extends pe{render(){return void 0===this.hass||void 0===this.repositories||void 0===this.configuration||void 0===this.status?N`
        <hacs-progressbar></hacs-progressbar>
      `:N`
      <hacs-body>
        <ha-card header="HACS (Home Assistant Community Store)">
          <div class="card-content">
            <p>
              <b>${Wo("common.version")}:</b> ${this.configuration.version}
            </p>
            <p>
              <b>${Wo("common.repositories")}:</b> ${this.repositories.length}
            </p>
            <div class="version-available">
              <ha-switch
                .checked=${"Table"===this.configuration.frontend_mode}
                @change=${this.SetFeStyle}
                >${Wo("settings.table_view")}</ha-switch
              >
              <ha-switch
                .checked=${this.configuration.frontend_compact}
                @change=${this.SetFeCompact}
                >${Wo("settings.compact_mode")}</ha-switch
              >
            </div>
          </div>
          <div class="card-actions MobileGrid">
            ${this.status.reloading_data?N`
                  <mwc-button
                    class="disabled-button"
                    title="${Wo("confirm.bg_task")}"
                    @click=${this.disabledAction}
                  >
                    <paper-spinner active></paper-spinner>
                  </mwc-button>
                `:N`
                  ${this.status.background_task?N`
                        <mwc-button
                          class="disabled-button"
                          title="${Wo("confirm.bg_task")}"
                          @click=${this.disabledAction}
                        >
                          ${Wo("settings.reload_data")}
                        </mwc-button>
                      `:N`
                        <mwc-button @click=${this.ReloadData}>
                          ${Wo("settings.reload_data")}
                        </mwc-button>
                      `}
                `}
            ${this.status.upgrading_all?N`
                  <mwc-button
                    class="disabled-button"
                    title="${Wo("confirm.bg_task")}"
                    @click=${this.disabledAction}
                  >
                    <paper-spinner active></paper-spinner>
                  </mwc-button>
                `:N`
                  ${this.status.background_task?N`
                        <mwc-button
                          class="disabled-button"
                          title="${Wo("confirm.bg_task")}"
                          @click=${this.disabledAction}
                        >
                          ${Wo("settings.upgrade_all")}
                        </mwc-button>
                      `:N`
                        <mwc-button @click=${this.UpgradeAll}>
                          ${Wo("settings.upgrade_all")}
                        </mwc-button>
                      `}
                `}

            <a href="https://github.com/hacs" target="_blank" rel="noreferrer">
              <mwc-button>
                ${Wo("settings.hacs_repo")}
              </mwc-button>
            </a>

            <a
              href="https://hacs.xyz/docs/issues"
              target="_blank"
              rel="noreferrer"
            >
              <mwc-button>
                ${Wo("repository.open_issue")}
              </mwc-button>
            </a>
          </div>
        </ha-card>
        <hacs-custom-repositories
          .hass=${this.hass}
          .status=${this.status}
          .route=${this.route}
          .configuration=${this.configuration}
          .repositories=${this.repositories}
        >
        </hacs-custom-repositories>
        <hacs-hidden-repositories
          .hass=${this.hass}
          .status=${this.status}
          .configuration=${this.configuration}
          .repositories=${this.repositories}
        >
        </hacs-hidden-repositories>
      </hacs-body>
    `}disabledAction(){Si(Wo("confirm.bg_task"))}SetFeStyle(){this.hass.connection.sendMessage({type:"hacs/settings",action:`set_fe_${"Table"!==this.configuration.frontend_mode?"table":"grid"}`})}SetFeCompact(){this.hass.connection.sendMessage({type:"hacs/settings",action:`set_fe_compact_${String(this.configuration.frontend_compact).toLocaleLowerCase()}`})}ReloadData(){this.hass.connection.sendMessage({type:"hacs/settings",action:"reload_data"})}UpgradeAll(){var e=[];if(this.repositories.forEach(t=>{t.pending_upgrade&&e.push(t)}),e.length>0){var t=Wo("confirm.upgrade_all")+"\n\n";e.forEach(e=>{t+=`${e.name}: ${e.installed_version} -> ${e.available_version}\n`}),t+=`\n${Wo("confirm.continue")}`,Si(t,{buttons:[Wo("confirm.cancel"),Wo("confirm.yes")]}).then(e=>{null!==e&&this.hass.connection.sendMessage({type:"hacs/settings",action:"upgrade_all"})})}else Si(Wo("confirm.no_upgrades"),{buttons:[Wo("confirm.ok")]})}static get styles(){return[ge,ce`
        ha-switch {
          margin-bottom: 8px;
        }
        mwc-button {
          margin: 0 8px 0 8px;
        }
      `]}};e([re({type:Array})],Di.prototype,"repositories",void 0),e([re({type:Object})],Di.prototype,"configuration",void 0),e([re({type:Object})],Di.prototype,"hass",void 0),e([re({type:Object})],Di.prototype,"status",void 0),e([re({type:Object})],Di.prototype,"route",void 0),Di=e([oe("hacs-settings")],Di);const Hi=["integrations","plugins","appdaemon_apps","python_scripts","themes"];class Bi{constructor(e,t,o,a){this.configuration=e,this.lovelaceconfig=t,this.status=o,this.route=a}render_card(e){return N`
      <ha-card
        @click="${this.ShowRepository}"
        .RepoID="${e.id}"
        class="${this.configuration.frontend_compact?"compact":""}"
      >
        <div class="card-content">
          <div>
            <ha-icon
              icon=${e.new?"mdi:new-box":"mdi:cube"}
              class="${this.StatusAndDescription(e).status}"
              title="${this.StatusAndDescription(e).description}"
            >
            </ha-icon>
            <div class="title">${bn.emojify(e.name||"")}</div>
            <div class="addition">
              ${bn.emojify(e.description||"")}
            </div>
          </div>
        </div>
      </ha-card>
    `}render_list_line(e){return N`
      <paper-item
        .RepoID=${e.id}
        @click="${this.ShowRepository}"
        class="${this.configuration.frontend_compact?"compact":""}"
      >
        <div class="icon">
          <ha-icon
            icon="mdi:new-box"
            class="${this.StatusAndDescription(e).status}"
            title="${this.StatusAndDescription(e).description}"
          >
          </ha-icon>
        </div>
        <paper-item-body two-line>
          <div>
            ${bn.emojify(e.name||"")}
            ${"/installed"===this.route.path?N`
                  <div class="MobileHide right flexy">
                    <div>${e.installed_version}</div>
                    &nbsp; (
                    <div
                      class="${e.pending_upgrade?this.StatusAndDescription(e).status:""}"
                    >
                      ${e.available_version}
                    </div>
                    )
                  </div>
                `:""}
          </div>
          <div class="addition">
            ${bn.emojify(e.description||"")}
          </div>
        </paper-item-body>
      </paper-item>
    `}render(e){return"Grid"===this.configuration.frontend_mode?this.render_card(e):this.render_list_line(e)}ShowRepository(e){var t;e.composedPath().forEach(e=>{e.RepoID&&(t=e.RepoID)}),this.route.path=`/repository/${t}`,this.dispatchEvent(new CustomEvent("hacs-location-change",{detail:{value:this.route},bubbles:!0,composed:!0}))}StatusAndDescription(e){var t=e.status,o=e.status_description;return e.installed&&!this.status.background_task&&("plugin"!==e.category||$i(e,this.lovelaceconfig,this.status)||(t="not-loaded",o="Not loaded in lovelace")),{status:t,description:o}}}let Ui=class extends pe{render(){if(void 0===this.repositories)return N`
        <hacs-progressbar></hacs-progressbar>
      `;const e=new Bi(this.configuration,this.lovelaceconfig,this.status,this.route);var t={integrations:[],plugins:[],appdaemon_apps:[],python_scripts:[],themes:[]},o=this.repositories.filter((function(e){return!!e.installed&&("integration"===e.category&&t.integrations.push(e),"plugin"===e.category&&t.plugins.push(e),"appdaemon"===e.category&&t.appdaemon_apps.push(e),"python_script"===e.category&&t.python_scripts.push(e),"theme"===e.category&&t.themes.push(e),!0)})).filter((function(e){return!!e.pending_upgrade}));return N`
      <hacs-body>
        ${0!==o.length?N`
              <div class="card-group">
                <div class="leftspace grouptitle">
                  ${Wo("store.pending_upgrades")}
                </div>
                ${o.sort((e,t)=>(e.name,t.name?1:-1)).map(t=>e.render(t))}
              </div>
              <hr noshade />
            `:""}
        ${Hi.map(o=>void 0===t[o]||0===t[o].length?N``:N`
            <div class="card-group">
              <div class="leftspace grouptitle">
                ${Wo(`common.${o}`)}
              </div>
              ${t[o].sort((e,t)=>(e.name,t.name?1:-1)).map(t=>e.render(t))}
            </div>
          `)}
      </hacs-body>
    `}static get styles(){return[ge,ce`
        .loader {
          background-color: var(--primary-background-color);
          height: 100%;
          width: 100%;
        }
        ha-card {
          display: inline-flex;
          cursor: pointer;
        }
        .grouptitle {
          margin-bottom: 12px;
          font-size: larger;
        }
      `]}};e([re({type:Array})],Ui.prototype,"repositories",void 0),e([re({type:Object})],Ui.prototype,"configuration",void 0),e([re({type:Object})],Ui.prototype,"hass",void 0),e([re({type:Object})],Ui.prototype,"lovelaceconfig",void 0),e([re({type:Object})],Ui.prototype,"route",void 0),e([re({type:Object})],Ui.prototype,"status",void 0),Ui=e([oe("hacs-installed")],Ui);let qi=class extends vi{render(){return N`
      <mwc-button @click=${this.ExecuteAction}>
        ${Wo("store.clear_new")}
      </mwc-button>
    `}ExecuteAction(){var e={type:"hacs/settings",action:"clear_new",category:this.category};this.hass.connection.sendMessage(e)}};e([re()],qi.prototype,"category",void 0),qi=e([oe("hacs-button-clear-new")],qi);let Vi=class extends pe{constructor(){super(...arguments),this.search="",this.sort="name"}SortRepo(e,t){return"stars"===this.sort?e.stars<t.stars:"status"===this.sort?e.status<t.status:e[this.sort]>t[this.sort]}SetSortKey(e){0!==e.detail.value.length&&(this.sort=e.detail.value.replace(" ","_").toLowerCase(),localStorage.setItem("hacs-sort",this.sort))}DoSearch(e){this.search=e.composedPath()[0].value,localStorage.setItem("hacs-search",this.search)}clearSearch(){this.search="",localStorage.setItem("hacs-search",this.search)}render(){if(void 0===this.repositories)return N`
        <hacs-progressbar></hacs-progressbar>
      `;const e=new Bi(this.configuration,this.lovelaceconfig,this.status,this.route);var t=[];this.search=localStorage.getItem("hacs-search"),this.sort=localStorage.getItem("hacs-sort");var o=this.repositories.filter(e=>!e.hide&&(("ALL"===this.configuration.country||void 0===e.country||this.configuration.country===e.country)&&(e.category===this.store&&("172733314"!==e.id&&(""!==this.search?!!e.name.toLowerCase().includes(this.search.toLowerCase())||(!!e.description.toLowerCase().includes(this.search.toLowerCase())||(!!e.full_name.toLowerCase().includes(this.search.toLowerCase())||(!!String(e.authors).toLowerCase().includes(this.search.toLowerCase())||!!String(e.topics).toLowerCase().includes(this.search.toLowerCase())))):(e.new&&t.push(e),!0))))));return N`
      <hacs-body>
        <div class="store-top">
          <paper-input
            class="search-bar padder"
            type="text"
            id="Search"
            @input=${this.DoSearch}
            placeholder="  ${Wo("store.placeholder_search")}."
            autofocus
            .value=${this.search}
          >
            ${this.search.length>0?N`
                  <ha-icon
                    slot="suffix"
                    icon="mdi:close"
                    @click="${this.clearSearch}"
                  ></ha-icon>
                `:""}
          </paper-input>
          <paper-dropdown-menu
            @value-changed="${this.SetSortKey}"
            class="sort padder"
            label="Sort"
          >
            <paper-listbox
              slot="dropdown-content"
              selected="${this.sort}"
              attr-for-selected="key"
            >
              <paper-item key="name">${Wo("store.name")}</paper-item>
              <paper-item key="stars">${Wo("store.stars")}</paper-item>
              <paper-item key="status">${Wo("store.status")}</paper-item>
            </paper-listbox>
          </paper-dropdown-menu>
        </div>

        ${0!==t.length?N`
              <div class="card-group">
                <div class="leftspace grouptitle">
                  ${Wo("store.new_repositories")}
                </div>
                ${t.map(t=>e.render(t))}
                <div class="card-group">
                  <hacs-button-clear-new
                    .hass=${this.hass}
                    .category=${this.store}
                  ></hacs-button-clear-new>
                </div>
              </div>
              <hr noshade />
            `:""}

        <div class="card-group">
          ${o.sort((e,t)=>this.SortRepo(e,t)?1:-1).map(t=>e.render(t))}
        </div>
      </hacs-body>
    `}static get styles(){return[ge,ce`
        .loader {
          background-color: var(--primary-background-color);
          height: 100%;
          width: 100%;
        }
        ha-card {
          display: inline-flex;
          cursor: pointer;
        }
        .padder {
          padding-left: 8px;
          padding-right: 8px;
        }
        .search-bar {
          display: block;
          width: 60%;
          background-color: var(--primary-background-color);
          color: var(--primary-text-color);
          line-height: 32px;
          border-color: var(--dark-primary-color);
          border-width: inherit;
          border-bottom-width: thin;
          border-radius: var(--ha-card-border-radius);
        }

        .sort {
          display: block;
          width: 30%;
          margin-left: 10%;
          background-color: var(--primary-background-color);
          color: var(--primary-text-color);
          line-height: 32px;
          border-color: var(--dark-primary-color);
          border-width: inherit;
          border-bottom-width: thin;
          border-radius: var(--ha-card-border-radius);
        }

        .store-top {
          display: flex;
          margin-top: -12px;
          max-width: 100%;
        }
        .card-content {
          width: calc(100% - 32px) !important;
        }
        paper-item {
          display: flex;
          background-color: var(
            --paper-listbox-background-color,
            var(--primary-background-color)
          );
        }
      `]}};e([re({type:Array})],Vi.prototype,"repositories",void 0),e([re({type:Object})],Vi.prototype,"configuration",void 0),e([re({type:Object})],Vi.prototype,"hass",void 0),e([re({type:Object})],Vi.prototype,"lovelaceconfig",void 0),e([re({type:Object})],Vi.prototype,"route",void 0),e([re({type:Object})],Vi.prototype,"status",void 0),e([re()],Vi.prototype,"store",void 0),e([re()],Vi.prototype,"search",void 0),e([re()],Vi.prototype,"sort",void 0),Vi=e([oe("hacs-store")],Vi);let Fi=class extends pe{render(){return N`
      <a href="#">
        <ha-icon
          title="Documentation"
          class="float"
          icon="mdi:help"
          @click=${this.openHelp}
        >
        </ha-icon>
      </a>
    `}openHelp(){var e=window.location.pathname.split("/")[2];"integration"===e&&(e="stores"),"plugin"===e&&(e="stores"),"appdaemon"===e&&(e="stores"),"python_script"===e&&(e="stores"),"theme"===e&&(e="stores"),window.open(`https://hacs.xyz/docs/navigation/${e}`,"Help","noreferrer")}static get styles(){return[ge,ce`
        .float {
          position: fixed;
          width: 36px;
          height: 36px;
          bottom: 24px;
          right: 24px;
          border-radius: 50px;
          border: 4px solid var(--accent-color);
          text-align: center;
          color: var(--primary-background-color);
          background-color: var(--accent-color);
        }
      `]}};Fi=e([oe("hacs-help-button")],Fi);let Gi=class extends pe{constructor(){super(...arguments),this.error=void 0}clearError(){this.error=void 0}firstUpdated(){this.hass.connection.subscribeEvents(e=>this.error=e.data,"hacs/error")}render(){if(void 0===this.error)return N``;var e=this.error.message,t="";return"add_repository"===this.error.action&&(t="Could not add this repository, make sure it is compliant with HACS."),N`
            <ha-card header="An error ocoured while prosessing" class="alert">
                <div class="card-content">
                    ${e} </br>
                    ${t}
                </div>
            <div class="card-actions">
                <mwc-button @click=${this.clearError}>
                    Acknowledge
                </mwc-button>
            ${"add_repository"===this.error.action?N`
                    <a
                      href="https://hacs.xyz/docs/publish/start"
                      rel="noreferrer"
                      target="_blank"
                    >
                      <mwc-button>
                        Documentation
                      </mwc-button>
                    </a>
                  `:""}
            </div>
            </ha-card>
            `}static get styles(){return[ge,ce`
        ha-card {
          width: 90%;
          margin-left: 5%;
        }
        .alert {
          background-color: var(
            --hacs-status-pending-restart,
            var(--google-red-500)
          );
          color: var(--text-primary-color);
        }
      `]}};e([re({type:Object})],Gi.prototype,"hass",void 0),e([re({type:Object})],Gi.prototype,"error",void 0),Gi=e([oe("hacs-error")],Gi);let Wi=class extends pe{async Acknowledge(e){var t=e.composedPath()[3].repository;const o=await this.hass.connection.sendMessagePromise({type:"hacs/critical",repository:t});this.critical=o.data}render(){if(void 0===this.critical)return N``;var e=[];return this.critical.forEach(t=>{t.acknowledged||e.push(t)}),N`
      ${e.map(e=>N`
            <ha-card header="Critical Issue!" class="alert">
                <div class="card-content">
                    The repository "${e.repository}" has been flagged as a critical repository.</br>
                    The repository has now been uninstalled and removed.</br>
                    For information about how and why these are handled, see
                    <a href="https://hacs.xyz/docs/developer/maintaner#critical-repositories">
                        https://hacs.xyz/docs/developer/maintaner#critical-repositories
                    </a></br>
                    As a result of this Home Assistant was also restarted.</br></br>

                    <b>Reason: </b>${e.reason}
                </div>
                <div class="card-actions">
                    <mwc-button @click=${this.Acknowledge} .repository=${e.repository}>
                        Acknowledge
                    </mwc-button>
                    <a href="${e.link}" rel='noreferrer' target="_blank">
                        <mwc-button>
                            More information about this incident
                        </mwc-button>
                    </a>
                </div>
            </ha-card>`)}
    `}static get styles(){return[ge,ce`
        ha-card {
          width: 90%;
          margin-left: 5%;
        }
        .alert {
          background-color: var(
            --hacs-status-pending-restart,
            var(--google-red-500)
          );
          color: var(--text-primary-color);
        }
      `]}};e([re({type:Array})],Wi.prototype,"critical",void 0),e([re({type:Object})],Wi.prototype,"hass",void 0),Wi=e([oe("hacs-critical")],Wi);let Yi=class extends pe{constructor(){super(...arguments),this.repository_view=!1}getRepositories(){this.hass.connection.sendMessagePromise({type:"hacs/repositories"}).then(e=>{this.repositories=e,this.requestUpdate()},e=>{console.error("[hacs/repositories] Message failed!",e)})}getConfig(){this.hass.connection.sendMessagePromise({type:"hacs/config"}).then(e=>{this.configuration=e,this.requestUpdate()},e=>{console.error("[hacs/config] Message failed!",e)})}getCritical(){this.hass.connection.sendMessagePromise({type:"hacs/get_critical"}).then(e=>{this.critical=e,this.requestUpdate()},e=>{console.error("[hacs/get_critical] Message failed!",e)})}getStatus(){this.hass.connection.sendMessagePromise({type:"hacs/status"}).then(e=>{this.status=e,this.requestUpdate()},e=>{console.error("[hacs/status] Message failed!",e)})}getLovelaceConfig(){this.hass.connection.sendMessagePromise({type:"lovelace/config",force:!1}).then(e=>{this.lovelaceconfig=e},()=>{this.lovelaceconfig=void 0})}firstUpdated(){this.addEventListener("hacs-location-change",this.locationChanged),window.onpopstate=function(){window.location.reload()},localStorage.setItem("hacs-search",""),localStorage.setItem("hacs-sort","name"),this.panel=this._page,this.getRepositories(),this.getConfig(),this.getStatus(),this.getCritical(),this.getLovelaceConfig(),/repository\//i.test(this.route.path)?(this.repository_view=!0,this.repository=this.route.path.split("/")[2]):this.repository_view=!1,ue(),this.hass.connection.subscribeEvents(()=>this.getRepositories(),"hacs/repository"),this.hass.connection.subscribeEvents(()=>this.getConfig(),"hacs/config"),this.hass.connection.subscribeEvents(()=>this.getStatus(),"hacs/status"),this.hass.connection.subscribeEvents(e=>this._reload(e),"hacs/reload"),this.hass.connection.subscribeEvents(()=>this.getLovelaceConfig(),"lovelace_updated")}_reload(e){window.location.reload(e.data.force)}render(){if(""!==this.route.path&&void 0!==this.route.path||(he(0,`${this.route.prefix}/installed`),this.route.path="/installed",this.panel=this.route.path.split("/")[1]),""!==this.panel&&void 0!==this.panel||(he(0,`${this.route.prefix}${this.route.path}`),this.panel=this.route.path.split("/")[1]),void 0===this.repositories||void 0===this.configuration||void 0===this.status)return N`
        <div class="loader"><paper-spinner active></paper-spinner></div>
      `;/repository\//i.test(this.route.path)?(this.repository_view=!0,this.repository=this.route.path.split("/")[2],this.panel="repository"):this.repository_view=!1;const e=this.panel;return N`
      <app-header-layout has-scrolling-region>
        <app-header slot="header" fixed>
          <app-toolbar>
            <ha-menu-button
              .hass="${this.hass}"
              .narrow="${this.narrow}"
            ></ha-menu-button>
            <div main-title class="fulltitle">
              Home Assistant Community Store
              ${"hacs_dev"===this._rootPath?N`
                    (DEVELOPMENT)
                  `:""}
            </div>
            <div main-title class="mobiletitle">
              HACS
              ${"hacs_dev"===this._rootPath?N`
                    (DEVELOPMENT)
                  `:""}
            </div>
          </app-toolbar>
          <paper-tabs
            scrollable
            attr-for-selected="page-name"
            .selected=${e}
            @iron-activate=${this.handlePageSelected}
          >
            <paper-tab page-name="installed"
              >${Wo("common.installed")}</paper-tab
            >

            <paper-tab page-name="integration"
              >${Wo("common.integrations")}</paper-tab
            >

            <paper-tab page-name="plugin"
              >${Wo("common.plugins")}</paper-tab
            >

            ${this.configuration.appdaemon?N`
                  <paper-tab page-name="appdaemon">
                    ${Wo("common.appdaemon_apps")}
                  </paper-tab>
                `:""}
            ${this.configuration.python_script?N`
                  <paper-tab page-name="python_script">
                    ${Wo("common.python_scripts")}
                  </paper-tab>
                `:""}
            ${this.configuration.theme?N`
                  <paper-tab page-name="theme">
                    ${Wo("common.themes")}
                  </paper-tab>
                `:""}

            <paper-tab page-name="settings"
              >${Wo("common.settings")}</paper-tab
            >
          </paper-tabs>
        </app-header>

        <hacs-progressbar
          .active=${this.status.background_task}
        ></hacs-progressbar>
        <slot></slot>

        <hacs-critical
          .hass=${this.hass}
          .critical=${this.critical}
        ></hacs-critical>
        <hacs-error .hass=${this.hass}></hacs-error>

        ${"/installed"===this.route.path?N`
              <hacs-installed
                .hass=${this.hass}
                .route=${this.route}
                .repositories=${this.repositories}
                .configuration=${this.configuration}
                .status=${this.status}
              ></hacs-installed>
            `:"/settings"===this.route.path?N`
              <hacs-settings
                .hass=${this.hass}
                .route=${this.route}
                .repositories=${this.repositories}
                .configuration=${this.configuration}
                .status=${this.status}
              >
              </hacs-settings>
            `:this.route.path.includes("/repository")?N`
              <hacs-repository
                .repository=${this._get_repository}
                .hass=${this.hass}
                .route=${this.route}
                .lovelaceconfig=${this.lovelaceconfig}
                .repositories=${this.repositories}
                .configuration=${this.configuration}
                .status=${this.status}
              ></hacs-repository>
            `:N`
              <hacs-store
                .store=${this._get_store}
                .hass=${this.hass}
                .route=${this.route}
                .repositories=${this.repositories}
                .configuration=${this.configuration}
                .status=${this.status}
              ></hacs-store>
            `}

        <hacs-help-button></hacs-help-button>
      </app-header-layout>
    `}get _get_store(){return this.route.path.split("/")[1]}get _get_repository(){return this.route.path.split("/")[2]}locationChanged(e){this.route=e.detail.value,he(0,`${this.route.prefix}${this.route.path}`),this.requestUpdate()}handlePageSelected(e){this.repository_view=!1;const t=e.detail.selected;this.panel=t,this.route.path=`/${t}`,he(0,`${this.route.prefix}${this.route.path}`),function(e,t){const o=t,a=Math.random(),n=Date.now(),r=o.scrollTop,i=0-r;e._currentAnimationId=a,function t(){const s=Date.now()-n;s>200?o.scrollTop=0:e._currentAnimationId===a&&(o.scrollTop=function(e,t,o,a){return-o*(e/=a)*(e-2)+t}(s,r,i,200),requestAnimationFrame(t.bind(e)))}.call(e)}(this,this.shadowRoot.querySelector("app-header-layout").header.scrollTarget)}get _page(){return void 0===this.route.path.split("/")[1]?"installed":this.route.path.split("/")[1]}get _rootPath(){return void 0===this.route.prefix.split("/")[1]?"hacs":this.route.prefix.split("/")[1]}static get styles(){return[ge,ce`
        app-header-layout {
          background: var(
            --lovelace-background,
            var(--primary-background-color)
          );
        }
        .loader {
          background-color: var(--primary-background-color);
          height: 100%;
          width: 100%;
        }
        paper-spinner {
          position: absolute;
          top: 30%;
          left: 50%;
          transform: translate(-50%, -50%);
          z-index: 99;
          width: 150px;
          height: 150px;
        }
        hacs-progressbar {
          top: 0;
          position: sticky;
          display: block;
          z-index: 1337;
        }
        .fulltitle {
          display: block;
        }
        .mobiletitle {
          display: none;
        }
        @media screen and (max-width: 612px) and (min-width: 0) {
          .fulltitle {
            display: none;
          }
          .mobiletitle {
            display: block;
            margin-left: 24px;
          }
        }
      `]}};e([re({type:Array})],Yi.prototype,"critical",void 0),e([re({type:Array})],Yi.prototype,"repositories",void 0),e([re({type:Boolean})],Yi.prototype,"narrow",void 0),e([re({type:Boolean})],Yi.prototype,"repository_view",void 0),e([re({type:Object})],Yi.prototype,"configuration",void 0),e([re({type:Object})],Yi.prototype,"hass",void 0),e([re({type:Object})],Yi.prototype,"lovelaceconfig",void 0),e([re({type:Object})],Yi.prototype,"route",void 0),e([re({type:Object})],Yi.prototype,"status",void 0),e([re()],Yi.prototype,"panel",void 0),e([re()],Yi.prototype,"repository",void 0),Yi=e([oe("hacs-frontendbase")],Yi);let Zi=class extends pe{setModalCSS(){if(!document.getElementById("modal-style")){var e=document.body,t=document.createElement("style");t.id="modal-style",t.innerHTML="\n            .swal-modal {\n                background-color: var(--primary-background-color) !important;\n            }\n            .swal-text {\n                color: var(--primary-text-color) !important;\n            }\n            .swal-button {\n                background-color: var(--primary-color) !important;\n                color: var(--primary-text-color) !important;\n            }\n          ",e.appendChild(t)}}render(){return this.setModalCSS(),N`
      <hacs-frontendbase
        .hass=${this.hass}
        .route=${this.route}
        .narrow=${this.narrow}
      >
      </hacs-frontendbase>
    `}};e([re({type:Boolean})],Zi.prototype,"narrow",void 0),e([re({type:Object})],Zi.prototype,"hass",void 0),e([re({type:Object})],Zi.prototype,"route",void 0),Zi=e([oe("hacs-frontend")],Zi);
